@@ -83,7 +83,7 @@ static void checkTrackAutoRange (FormantModeler me, integer *fromTrack, integer
 }
 
 static autoINTVEC newINTVECasNumbers (integer size, integer number) {
-	autoINTVEC target = newINTVECraw (size);
+	autoINTVEC target = raw_INTVEC (size);
 	for (integer i = 1; i <= size; i++)
 		target [i] = number;
 	return target;
@@ -279,7 +279,7 @@ static autoVEC FormantModeler_getSumOfVariancesBetweenShiftedAndEstimatedTracks
 			*toTrack = ( *toTrack == numberOfTracks ? numberOfTracks - 1 : *toTrack );
 		}
 		const integer numberOfDataPoints = FormantModeler_getNumberOfDataPoints (me);
-		autoVEC sumOfVariances = newVECzero (numberOfDataPoints);
+		autoVEC sumOfVariances = zero_VEC (numberOfDataPoints);
 		for (integer itrack = *fromTrack; itrack <= *toTrack; itrack ++) {
 			autoVEC vari = FormantModeler_getVariancesBetweenTrackAndEstimatedTrack (me, formantTrack, estimatedTrack);
 			for (integer ipoint = 1; ipoint <= numberOfDataPoints; ipoint ++) {
@@ -347,7 +347,7 @@ void FormantModeler_drawCumulativeChiScores (FormantModeler me, Graphics g, doub
 		Melder_require (FormantModeler_drawingSpecifiers_x (me, & xmin, & xmax, & ixmin, & ixmax) > 0,
 			U"Not enough data points in drawing range.");
 		const integer numberOfDataPoints = FormantModeler_getNumberOfDataPoints (me);
-		autoVEC chisq = newVECzero (numberOfDataPoints);
+		autoVEC chisq = zero_VEC (numberOfDataPoints);
 		FormantModeler_getCumulativeChiScores (me, chisq.get());
 		if (ymax <= ymin)
 			NUMextrema (chisq.part (ixmin, ixmax), & ymin, & ymax);
@@ -368,7 +368,7 @@ void FormantModeler_drawCumulativeChiScores (FormantModeler me, Graphics g, doub
 }
 
 void FormantModeler_drawOutliersMarked (FormantModeler me, Graphics g, double tmin, double tmax, double fmax, integer fromTrack, integer toTrack,
-	double numberOfSigmas, conststring32 mark, double marksFontSize, double horizontalOffset_wc, bool garnish)
+	double numberOfSigmas, conststring32 mark, double marksFontSize, MelderColour oddTracks, MelderColour evenTracks, bool garnish)
 {
 	Function_unidirectionalAutowindow (me, & tmin, & tmax);
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
@@ -376,8 +376,8 @@ void FormantModeler_drawOutliersMarked (FormantModeler me, Graphics g, double tm
 	double currectFontSize = Graphics_inqFontSize (g);
 	for (integer itrack = fromTrack; itrack <= toTrack; itrack ++) {
 		const DataModeler ffi = my trackmodelers.at [itrack];
-		const double xOffset_wc = ( itrack % 2 == 1 ? horizontalOffset_wc : -horizontalOffset_wc );
-		DataModeler_drawOutliersMarked_inside (ffi, g, tmin, tmax, 0.0, fmax, numberOfSigmas, mark, marksFontSize, xOffset_wc);
+		Graphics_setColour (g, itrack %2  == 1 ? oddTracks : evenTracks );
+		DataModeler_drawOutliersMarked_inside (ffi, g, tmin, tmax, 0.0, fmax, numberOfSigmas, mark, marksFontSize);
 	}
 	Graphics_setFontSize (g, currectFontSize);
 	Graphics_unsetInner (g);
@@ -398,22 +398,32 @@ void FormantModeler_normalProbabilityPlot (FormantModeler me, Graphics g, intege
 	}
 }
 
-void FormantModeler_drawTracks_inside (FormantModeler me, Graphics g, double xmin, double xmax, double fmax, integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters, double horizontalOffset_wc) {
+void FormantModeler_drawModel_inside (FormantModeler me, Graphics g, double tmin, double tmax, double fmax,
+	integer fromTrack, integer toTrack, MelderColour oddTracks, MelderColour evenTracks, integer numberOfPoints) {
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
 	for (integer itrack = fromTrack; itrack <= toTrack; itrack ++) {
 		DataModeler ffi = my trackmodelers.at [itrack];
-		double xOffset_wc = ( itrack % 2 == 0 ? horizontalOffset_wc : 0.0 );
-		DataModeler_drawTrack_inside (ffi, g, xmin, xmax, 0.0, fmax, useEstimatedTrack, numberOfParameters, xOffset_wc);
+		Graphics_setColour (g, itrack % 2 == 1 ? oddTracks : evenTracks );
+		DataModeler_drawModel_inside (ffi, g, tmin, tmax, 0.0, fmax, numberOfPoints);
+	}
+}
+
+void FormantModeler_drawTracks_inside (FormantModeler me, Graphics g, double xmin, double xmax, double fmax, integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters, MelderColour oddTracks, MelderColour evenTracks) {
+	checkTrackAutoRange (me, & fromTrack, & toTrack);
+	for (integer itrack = fromTrack; itrack <= toTrack; itrack ++) {
+		DataModeler ffi = my trackmodelers.at [itrack];
+		Graphics_setColour (g, itrack % 2 == 1 ? oddTracks : evenTracks );
+		DataModeler_drawTrack_inside (ffi, g, xmin, xmax, 0.0, fmax, useEstimatedTrack, numberOfParameters);
 	}
 }
 
 void FormantModeler_drawTracks (FormantModeler me, Graphics g, double tmin, double tmax, double fmax,
-	integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters, double horizontalOffset_wc, bool garnish)
+	integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters, MelderColour oddTracks, MelderColour evenTracks, bool garnish)
 {
 	Function_unidirectionalAutowindow (me, & tmin, & tmax);
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
 	Graphics_setInner (g);
-	FormantModeler_drawTracks_inside (me, g, tmin, tmax, fmax, fromTrack, toTrack, useEstimatedTrack, numberOfParameters, horizontalOffset_wc);
+	FormantModeler_drawTracks_inside (me, g, tmin, tmax, fmax, fromTrack, toTrack, useEstimatedTrack, numberOfParameters, oddTracks, evenTracks);
 	Graphics_unsetInner (g);
 	if (garnish) {
 		Graphics_drawInnerBox (g);
@@ -425,23 +435,23 @@ void FormantModeler_drawTracks (FormantModeler me, Graphics g, double tmin, doub
 }
 
 void FormantModeler_speckle_inside (FormantModeler me, Graphics g, double xmin, double xmax, double fmax,
-	integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters, bool errorBars, double barWidth_wc, double horizontalOffset_wc) {
+	integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters, bool errorBars, MelderColour oddTracks, MelderColour evenTracks) {
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
 	for (integer itrack = fromTrack; itrack <= toTrack; itrack ++) {
 		const DataModeler ffi = my trackmodelers.at [itrack];
-		const double xOffset_wc = ( itrack % 2 == 1 ? horizontalOffset_wc : -horizontalOffset_wc );
-		DataModeler_speckle_inside (ffi, g, xmin, xmax, 0, fmax, useEstimatedTrack, numberOfParameters, errorBars, barWidth_wc, xOffset_wc);
+		Graphics_setColour (g, itrack % 2 == 1 ? oddTracks : evenTracks);
+		DataModeler_speckle_inside (ffi, g, xmin, xmax, 0, fmax, useEstimatedTrack, numberOfParameters, errorBars, 0.0);
 	}
 }
 
 void FormantModeler_speckle (FormantModeler me, Graphics g, double tmin, double tmax, double fmax,
 	integer fromTrack, integer toTrack, bool useEstimatedTrack, integer numberOfParameters,
-	bool errorBars, double barWidth_wc, double horizontalOffset_wc, bool garnish)
+	bool errorBars, MelderColour oddTracks, MelderColour evenTracks, bool garnish)
 {
 	Function_unidirectionalAutowindow (me, & tmin, & tmax);
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
 	Graphics_setInner (g);
-	FormantModeler_speckle_inside (me, g, tmin, tmax, fmax, fromTrack, toTrack, useEstimatedTrack, numberOfParameters, errorBars, barWidth_wc, horizontalOffset_wc);
+	FormantModeler_speckle_inside (me, g, tmin, tmax, fmax, fromTrack, toTrack, useEstimatedTrack, numberOfParameters, errorBars, oddTracks, evenTracks);
 	Graphics_unsetInner (g);
 	if (garnish) {
 		Graphics_drawInnerBox (g);
@@ -664,10 +674,6 @@ autoFormantModeler Formant_to_FormantModeler (Formant me, double tmin, double tm
 		integer ifmin, ifmax, posInCollection = 0;
 		Function_unidirectionalAutowindow (me, & tmin, & tmax);
 		const integer numberOfDataPoints = Sampled_getWindowSamples (me, tmin, tmax, & ifmin, & ifmax);
-		const integer maximumNumberOfParameters = NUMmax (numberOfParametersPerTrack);
-		Melder_require (numberOfDataPoints >= maximumNumberOfParameters,
-			U"There are not enough data points, please reduce the number of parameters or extend the selection.");
-		
 		autoFormantModeler thee = FormantModeler_create (tmin, tmax, numberOfDataPoints, numberOfParametersPerTrack);
 		Thing_setName (thee.get(), my name.get());
 		for (integer iformant = 1; iformant <= numberOfParametersPerTrack.size; iformant ++) {
@@ -691,13 +697,7 @@ autoFormantModeler Formant_to_FormantModeler (Formant me, double tmin, double tm
 			}
 			ffi -> weighData = kDataModelerWeights::ONE_OVER_SIGMA;
 			ffi -> tolerance = 1e-5;
-			if (validData < numberOfParametersPerTrack [iformant]) {   // remove don't throw exception
-				thy trackmodelers. removeItem (posInCollection);
-				posInCollection --;
-			}
 		}
-		Melder_require (posInCollection > 0,
-			U"Not enough data points in all the formants.");
 		FormantModeler_fit (thee.get());
 		return thee;
 	} catch (MelderError) {
@@ -712,7 +712,7 @@ autoFormant FormantModeler_to_Formant (FormantModeler me, bool useEstimates, boo
 		const integer numberOfFrames = ff -> numberOfDataPoints;
 		const double t1 = ff -> data [1] .x, dt = ff -> data [2] .x - t1;
 		autoFormant thee = Formant_create (my xmin, my xmax, numberOfFrames, dt, t1, numberOfFormants);
-		autoVEC sigma = newVECraw (numberOfFormants);
+		autoVEC sigma = raw_VEC (numberOfFormants);
 		if (useEstimates || estimateUndefineds) {
 			for (integer itrack = 1; itrack <= numberOfFormants; itrack ++)
 				sigma [itrack] = FormantModeler_getStandardDeviation (me, itrack);
@@ -746,9 +746,9 @@ autoFormant FormantModeler_to_Formant (FormantModeler me, bool useEstimates, boo
 }
 
 double FormantModeler_getChiSquaredQ (FormantModeler me, integer fromTrack, integer toTrack, double *out_probability, double *out_ndf) {
-	double chisq = undefined, ndfTotal = 0.0;
+	double ndfTotal = 0.0;
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
-	chisq = 0.0;
+	double chisq = 0.0;
 	integer numberOfDefined = 0;
 	for (integer itrack = fromTrack; itrack <= toTrack; itrack ++) {
 		const DataModeler ffi = my trackmodelers.at [itrack];
@@ -766,7 +766,8 @@ double FormantModeler_getChiSquaredQ (FormantModeler me, integer fromTrack, inte
 			*out_ndf = ndfTotal;
 		if (out_probability)
 			*out_probability = NUMchiSquareQ (chisq, ndfTotal);
-	}
+	} else
+		chisq = undefined;
 	return chisq;
 }
 
@@ -813,8 +814,8 @@ autoFormantModeler FormantModeler_processOutliers (FormantModeler me, double num
 			U"We need at least three formants to process outliers.");
 		
 		const integer numberOfDataPoints = FormantModeler_getNumberOfDataPoints (me);
-		autoVEC x = newVECraw (numberOfDataPoints); // also store x-values
-		autoMAT z = newMATraw (numberOfFormants, numberOfDataPoints);
+		autoVEC x = raw_VEC (numberOfDataPoints); // also store x-values
+		autoMAT z = raw_MAT (numberOfFormants, numberOfDataPoints);
 		// maybe some of the formants had NUMundefind's.
 
 		// 1. calculate z-scores for each formant and sort them in descending order
@@ -824,7 +825,7 @@ autoFormantModeler FormantModeler_processOutliers (FormantModeler me, double num
 		for (integer itrack = 1; itrack <= numberOfFormants; itrack ++) {
 			const DataModeler ffi = my trackmodelers.at [itrack];
 			autoVEC zscores = DataModeler_getZScores (ffi);
-			z.row (itrack) <<= zscores.get ();
+			z.row (itrack) <<= zscores.get();
 		}
 		// 2. Do the manipulation in a copy
 		autoFormantModeler thee = Data_copy (me);
@@ -850,15 +851,14 @@ autoFormantModeler FormantModeler_processOutliers (FormantModeler me, double num
 	}
 }
 
-
-double FormantModeler_getSmoothnessValue (FormantModeler me, integer fromTrack, integer toTrack, integer numberOfParametersPerTrack, double power) {
+double FormantModeler_getStress (FormantModeler me, integer fromTrack, integer toTrack, integer numberOfParametersPerTrack, double power) {
 	checkTrackAutoRange (me, & fromTrack, & toTrack);
 	integer numberOfFreeParameters;
 	const double var = FormantModeler_getVarianceOfParameters (me, fromTrack, toTrack, 1, numberOfParametersPerTrack, & numberOfFreeParameters);
 	double degreesOfFreedom;
 	const double chisq = FormantModeler_getChiSquaredQ (me, fromTrack, toTrack, nullptr, & degreesOfFreedom);
-	return ( isdefined (var) && isdefined (chisq) && numberOfFreeParameters > 0 ? 
-		power * log10 ((var / numberOfFreeParameters) * (chisq / degreesOfFreedom)) :
+	return ( isdefined (var) && isdefined (chisq) && numberOfFreeParameters > 0 && degreesOfFreedom >= 0.0 ? 
+		( sqrt (pow (var / numberOfFreeParameters, power) * (chisq / degreesOfFreedom))) :
 		undefined );
 }
 
@@ -932,8 +932,8 @@ integer Formants_getSmoothestInInterval (CollectionOf<structFormant>* me, double
 		integer minNumberOfFormants = 1000000;
 		if (numberOfFormantObjects == 1)
 			return 1;
-		autoINTVEC numberOfFormants = newINTVECraw (numberOfFormantObjects);
-		autoINTVEC invalid = newINTVECzero (numberOfFormantObjects);
+		autoINTVEC numberOfFormants = raw_INTVEC (numberOfFormantObjects);
+		autoINTVEC invalid = zero_INTVEC (numberOfFormantObjects);
 		double tminf = 0.0, tmaxf = 0.0;
 		for (integer iobject = 1; iobject <= numberOfFormantObjects; iobject ++) {
 			// Check that all Formants have the same domain
@@ -984,7 +984,7 @@ integer Formants_getSmoothestInInterval (CollectionOf<structFormant>* me, double
 				autoFormantModeler fs = Formant_to_FormantModeler (fi, tmin, tmax, numberOfFormantTracks, numberOfParametersPerTrack);
 				FormantModeler_setParameterValuesToZero (fs.get(), 1, numberOfFormantTracks, numberOfSigmas);
 				const double cf = ( useConstraints ? FormantModeler_getFormantsConstraintsFactor (fs.get(), minF1, maxF1, minF2, maxF2, minF3) : 1.0 );
-				const double chiVar = FormantModeler_getSmoothnessValue (fs.get(), 1, numberOfFormantTracks, numberOfParametersPerTrack, power);
+				const double chiVar = FormantModeler_getStress (fs.get(), 1, numberOfFormantTracks, numberOfParametersPerTrack, power);
 				if (isdefined (chiVar) && cf * chiVar < minChiVar) {
 					minChiVar = cf * chiVar;
 					index = iobject;
@@ -1093,7 +1093,7 @@ autoFormant Sound_to_Formant_interval (Sound me, double startTime, double endTim
 			FormantModeler_setParameterValuesToZero (fm.get(), 1, numberOfFormantTracks, numberOfSigmas);
 			formants. addItem_move (formant.move());
 			const double cf = ( useConstraints ? FormantModeler_getFormantsConstraintsFactor (fm.get(), minF1, maxF1, minF2, maxF2, minF3) : 1.0 );
-			const double chiVar = FormantModeler_getSmoothnessValue (fm.get(), 1, numberOfFormantTracks, numberOfParametersPerTrack, power);
+			const double chiVar = FormantModeler_getStress (fm.get(), 1, numberOfFormantTracks, numberOfParametersPerTrack, power);
 			const double criterium = chiVar * cf;
 			if (isdefined (chiVar) && criterium < mincriterium) {
 				mincriterium = criterium;
@@ -1159,7 +1159,7 @@ autoFormant Sound_to_Formant_interval_robust (Sound me, double startTime, double
 			FormantModeler_setParameterValuesToZero (fm.get(), 1, numberOfFormantTracks, numberOfSigmas);
 			formants. addItem_move (formant.move());
 			const double cf = ( useConstraints ? FormantModeler_getFormantsConstraintsFactor (fm.get(), minF1, maxF1, minF2, maxF2, minF3) : 1.0 );
-			const double chiVar = FormantModeler_getSmoothnessValue (fm.get(), 1, numberOfFormantTracks, numberOfParametersPerTrack, power);
+			const double chiVar = FormantModeler_getStress (fm.get(), 1, numberOfFormantTracks, numberOfParametersPerTrack, power);
 			const double criterium = chiVar * cf;
 			if (isdefined (chiVar) && criterium < mincriterium) {
 				mincriterium = criterium;
@@ -1204,11 +1204,11 @@ autoOptimalCeilingTier Sound_to_OptimalCeilingTier (Sound me,
 		}
 		integer numberOfFrames;
 		double firstTime;
-		const double modelingTimeStep = timeStep;
+		const double modellingTimeStep = timeStep;
 		autoOptimalCeilingTier octier = OptimalCeilingTier_create (my xmin, my xmax);
-		Sampled_shortTermAnalysis (me, smoothingWindow, modelingTimeStep, & numberOfFrames, & firstTime);
+		Sampled_shortTermAnalysis (me, smoothingWindow, modellingTimeStep, & numberOfFrames, & firstTime);
 		for (integer iframe = 1; iframe <= numberOfFrames; iframe ++) {
-			const double time = firstTime + (iframe - 1) * modelingTimeStep;
+			const double time = firstTime + (iframe - 1) * modellingTimeStep;
 			const double tmin = time - smoothingWindow / 2.0;
 			const double tmax = tmin + smoothingWindow;
 			const integer index = Formants_getSmoothestInInterval (& formants, tmin, tmax, numberOfFormantTracks, numberOfParametersPerTrack,	weighFormants,
