@@ -74,7 +74,7 @@ static integer getLPCAnalysisWorkspaceSize (integer numberOfSamples, integer num
 
 static autoVEC getLPCAnalysisWorkspace (integer numberOfSamples, integer numberOfCoefficients, kLPC_Analysis method) {
 	integer size = getLPCAnalysisWorkspaceSize (numberOfSamples, numberOfCoefficients, method);
-	autoVEC result = newVECraw (size);
+	autoVEC result = raw_VEC (size);
 	return result;
 }
 
@@ -82,10 +82,10 @@ static int Sound_into_LPC_Frame_auto (Sound me, LPC_Frame thee, VEC const& works
 	Melder_assert (thy nCoefficients == thy a.size); // check invariant
 	const integer numberOfCoefficients = thy nCoefficients, np1 = numberOfCoefficients + 1;
 
-	//workspace <<= 0.0; not necessary !
-	VEC r = workspace. part (1, np1); // autoVEC r = newVECzero (numberOfCoefficients + 1);
-	VEC a = workspace. part (np1 + 1, 2 * np1); // autoVEC a = newVECzero (numberOfCoefficients + 1);
-	VEC rc = workspace. part (2 * np1 + 1, 2 * np1 + numberOfCoefficients); // autoVEC rc = newVECzero (numberOfCoefficients);
+	//workspace  <<=  0.0; not necessary !
+	VEC r = workspace. part (1, np1); // autoVEC r = zero_VEC (numberOfCoefficients + 1);
+	VEC a = workspace. part (np1 + 1, 2 * np1); // autoVEC a = zero_VEC (numberOfCoefficients + 1);
+	VEC rc = workspace. part (2 * np1 + 1, 2 * np1 + numberOfCoefficients); // autoVEC rc = zero_VEC (numberOfCoefficients);
 	const VECVU x = my z.row (1);
 	integer i = 1; // For error condition at end
 	for (i = 1; i <= numberOfCoefficients + 1; i ++)
@@ -113,7 +113,7 @@ static int Sound_into_LPC_Frame_auto (Sound me, LPC_Frame thee, VEC const& works
 			goto end;
 	}
 end:
-	i--;
+	i --;
 	for (integer j = 1; j <= i; j ++)
 		thy a [j] = a [j + 1];
 	if (i == numberOfCoefficients)
@@ -132,17 +132,17 @@ static int Sound_into_LPC_Frame_covar (Sound me, LPC_Frame thee, VEC const& work
 	const integer n = my nx, m = thy nCoefficients;
 	constVEC x = my z.row (1);
 	
-	workspace <<= 0.0;
+	workspace  <<=  0.0;
 	integer start = 1, end = m * (m + 1) / 2;
-	VEC b = workspace. part (start, end); // autoVEC b = newVECzero (m * (m + 1) / 2);
+	VEC b = workspace. part (start, end); // autoVEC b = zero_VEC (m * (m + 1) / 2);
 	start = end + 1; end += m;
-	VEC grc = workspace. part (start, end); //autoVEC grc = newVECzero (m);
+	VEC grc = workspace. part (start, end); //autoVEC grc = zero_VEC (m);
 	start = end + 1; end += m;
-	VEC beta = workspace. part (start, end); // autoVEC beta = newVECzero (m);
+	VEC beta = workspace. part (start, end); // autoVEC beta = zero_VEC (m);
 	start = end + 1; end += m + 1;
-	VEC a = workspace. part (start, end); // autoVEC a = newVECzero (m + 1);
+	VEC a = workspace. part (start, end); // autoVEC a = zero_VEC (m + 1);
 	start = end + 1; end += m + 1;
-	VEC cc = workspace. part (start, end); // autoVEC cc = newVECzero (m + 1);
+	VEC cc = workspace. part (start, end); // autoVEC cc = zero_VEC (m + 1);
 
 	thy gain = 0.0;
 	integer i;
@@ -207,7 +207,7 @@ static int Sound_into_LPC_Frame_covar (Sound me, LPC_Frame thee, VEC const& work
 			goto end;
 	}
 end:
-	i--;
+	i --;
 	for (integer j = 1; j <= i; j ++)
 		thy a [j] = a [j + 1];
 	if (i == m)
@@ -222,9 +222,9 @@ static double VECburg_buffered (VEC const& a, constVEC const& x, VEC const& work
 	for (integer j = 1; j <= m; j ++)
 		a [j] = 0.0;
 
-	VEC b1 = workspace. part (1, n); // autoVEC b1 = newVECzero (n);
-	VEC b2 = workspace. part (n + 1, 2 * n); // autoVEC b2 = newVECzero (n);
-	VEC aa = workspace. part (2 * n + 1, 2 * n + m); // autoVEC aa = newVECzero (m);
+	VEC b1 = workspace. part (1, n); // autoVEC b1 = zero_VEC (n);
+	VEC b2 = workspace. part (n + 1, 2 * n); // autoVEC b2 = zero_VEC (n);
+	VEC aa = workspace. part (2 * n + 1, 2 * n + m); // autoVEC aa = zero_VEC (m);
 
 	// (3)
 
@@ -234,7 +234,7 @@ static double VECburg_buffered (VEC const& a, constVEC const& x, VEC const& work
 
 	longdouble xms = p / n;
 	if (xms <= 0.0) {
-		return xms;	// warning empty
+		return double (xms);	// warning empty
 	}
 	// (9)
 
@@ -255,7 +255,7 @@ static double VECburg_buffered (VEC const& a, constVEC const& x, VEC const& work
 		if (denum <= 0.0)
 			return 0.0;	// warning ill-conditioned
 
-		a [i] = 2.0 * num / denum;
+		a [i] = 2.0 * double (num / denum);
 
 		// (10)
 
@@ -278,7 +278,7 @@ static double VECburg_buffered (VEC const& a, constVEC const& x, VEC const& work
 			}
 		}
 	}
-	return xms;
+	return double (xms);
 }
 
 static int Sound_into_LPC_Frame_burg (Sound me, LPC_Frame thee, VEC const& workspace) {
@@ -300,9 +300,9 @@ static int Sound_into_LPC_Frame_marple (Sound me, LPC_Frame thee, double tol1, d
 	int status = 1;
 	// workspace.all () << 0.0 not necessary
 	constVEC x = my z.row (1);
-	VEC c = workspace .part (1, mmaxp1); // autoVEC c = newVECzero (mmax + 1);
-	VEC d = workspace .part (mmaxp1 + 1, 2 * mmaxp1); // autoVEC d = newVECzero (mmax + 1);
-	VEC r = workspace .part (2 * mmaxp1 + 1, 3 * mmaxp1); // autoVEC r = newVECzero (mmax + 1);
+	VEC c = workspace .part (1, mmaxp1); // autoVEC c = zero_VEC (mmax + 1);
+	VEC d = workspace .part (mmaxp1 + 1, 2 * mmaxp1); // autoVEC d = zero_VEC (mmax + 1);
+	VEC r = workspace .part (2 * mmaxp1 + 1, 3 * mmaxp1); // autoVEC r = zero_VEC (mmax + 1);
 	double e0 = 2.0 * NUMsum2 (x);
 	integer m = 1;
 	if (e0 == 0.0) {
@@ -428,30 +428,31 @@ static int Sound_into_LPC_Frame_marple (Sound me, LPC_Frame thee, double tol1, d
 		}
 	}
 end:
-	thy gain *= 0.5; // because e0 is twice the energy
+	thy gain *= 0.5;   // because e0 is twice the energy
 	thy a.resize (m);
-	thy nCoefficients = thy a.size; // maintain invariant
+	thy nCoefficients = thy a.size;   // maintain invariant
 	return status == 1 || status == 4 || status == 5;
 }
 
-static autoLPC Sound_to_LPC_noThreads (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency, kLPC_Analysis method, double tol1, double tol2) {
+static void Sound_into_LPC_noThreads (Sound me, LPC thee, double analysisWidth, double preEmphasisFrequency, kLPC_Analysis method, double tol1, double tol2) {
+	Melder_require (my xmin == thy xmin && my xmax == thy xmax, 
+		U"The Sound and the LPC should have the same domain.");
 	const double samplingFrequency = 1.0 / my dx;
 	double windowDuration = 2.0 * analysisWidth; // Gaussian window
+	const integer predictionOrder = thy maxnCoefficients;
 	Melder_require (Melder_roundDown (windowDuration / my dx) > predictionOrder,
 		U"Analysis window duration too short.\n For a prediction order of ", predictionOrder,
-		U" the analysis window duration should be greater than ", my dx * (predictionOrder + 1), U"Please increase the analysis window duration or lower the prediction order.");
-	
-	// Convenience: analyse the whole sound into one LPC_frame
-	if (windowDuration > my dx * my nx) {
+		U" the analysis window duration should be greater than ", my dx * (predictionOrder + 1),
+		U" s. Please increase the analysis window duration.");
+	/*
+		Convenience: analyse the whole sound into one LPC_frame.
+	*/
+	if (windowDuration > my dx * my nx)
 		windowDuration = my dx * my nx;
-	}
-	double t1;
-	integer numberOfFrames;
-	Sampled_shortTermAnalysis (me, windowDuration, dt, & numberOfFrames, & t1);
+	integer numberOfFrames = thy nx;
 	autoSound sound = Data_copy (me);
 	autoSound sframe = Sound_createSimple (1, windowDuration, samplingFrequency);
 	autoSound window = Sound_createGaussian (windowDuration, samplingFrequency);
-	autoLPC thee = LPC_create (my xmin, my xmax, numberOfFrames, dt, t1, predictionOrder, my dx);
 	for (integer iframe = 1; iframe <= numberOfFrames; iframe ++) {
 		const LPC_Frame lpcFrame = & thy d_frames [iframe];
 		LPC_Frame_init (lpcFrame, predictionOrder);
@@ -465,8 +466,8 @@ static autoLPC Sound_to_LPC_noThreads (Sound me, int predictionOrder, double ana
 	integer frameErrorCount = 0;
 	for (integer iframe = 1; iframe <= numberOfFrames; iframe ++) {
 		const LPC_Frame lpcframe = & thy d_frames [iframe];
-		const double t = Sampled_indexToX (thee.get(), iframe);
-		Sound_into_Sound (sound.get(), sframe.get(), t - windowDuration / 2.0);
+		const double t = Sampled_indexToX (thee, iframe);
+		Sound_into_Sound (sound.get(), sframe.get(), t - 0.5 * windowDuration);
 		Vector_subtractMean (sframe.get());
 		Sounds_multiply (sframe.get(), window.get());
 		integer status = 1;
@@ -480,36 +481,36 @@ static autoLPC Sound_to_LPC_noThreads (Sound me, int predictionOrder, double ana
 			status = Sound_into_LPC_Frame_marple (sframe.get(), lpcframe, tol1, tol2, workspace.get());
 		if (status != 0)
 			frameErrorCount ++;
-	
 		if (iframe % 10 == 1)
-			Melder_progress ( (double) iframe / numberOfFrames, U"LPC analysis of frame ", iframe, U" out of ", numberOfFrames, U".");
+			Melder_progress (double (iframe) / numberOfFrames, U"LPC analysis of frame ", iframe, U" out of ", numberOfFrames, U".");
 	}
-	return thee;
 }
 
-static autoLPC Sound_to_LPC (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency, kLPC_Analysis method, double tol1, double tol2) {
+void Sound_into_LPC (Sound me, LPC thee, double analysisWidth, double preEmphasisFrequency, kLPC_Analysis method, double tol1, double tol2) {
 	const integer numberOfProcessors = std::thread::hardware_concurrency ();
 	if (numberOfProcessors <= 1) {
 		/*
 			We cannot use multithreading.
 		*/
-		return Sound_to_LPC_noThreads (me, predictionOrder, analysisWidth, dt, preEmphasisFrequency, method, tol1, tol2);
+		Sound_into_LPC_noThreads (me, thee, analysisWidth, preEmphasisFrequency, method, tol1, tol2);
 	}
 	const double samplingFrequency = 1.0 / my dx;
+	Melder_require (my xmin == thy xmin && my xmax == thy xmax, 
+		U"The Sound and the LPC should have the same domain.");
+	const integer predictionOrder = thy maxnCoefficients;
 	double windowDuration = 2.0 * analysisWidth; // Gaussian window
 	Melder_require (Melder_roundDown (windowDuration / my dx) > predictionOrder,
 		U"Analysis window duration too short.\n For a prediction order of ", predictionOrder,
-		U" the analysis window duration should be greater than ", my dx * (predictionOrder + 1), U"Please increase the analysis window duration or lower the prediction order.");
-	
-	if (windowDuration > my dx * my nx) {
+		U" the analysis window duration should be greater than ", my dx * (predictionOrder + 1),
+		U" s. Please increase the analysis window duration.");
+	/*
+		Convenience: analyse the whole sound into one LPC_frame.
+	*/
+	if (windowDuration > my dx * my nx)
 		windowDuration = my dx * my nx;
-	}
-	double t1;
-	integer numberOfFrames;
-	Sampled_shortTermAnalysis (me, windowDuration, dt, & numberOfFrames, & t1);
+	integer numberOfFrames = thy nx;
 	autoSound sound = Data_copy (me);
 	autoSound window = Sound_createGaussian (windowDuration, samplingFrequency);
-	autoLPC thee = LPC_create (my xmin, my xmax, numberOfFrames, dt, t1, predictionOrder, my dx);
 	/*
 		Because of threading we initialise the frames beforehand.
 		We initialize the coefficient vector with a size equal to the prediction order.
@@ -531,10 +532,10 @@ static autoLPC Sound_to_LPC (Sound me, int predictionOrder, double analysisWidth
 	for (integer ithread = 1; ithread <= numberOfThreads; ithread ++)
 		sframe [ithread] = Sound_createSimple (1, windowDuration, samplingFrequency);
 	
-	const integer worspaceSize = getLPCAnalysisWorkspaceSize (sframe [1] -> nx, predictionOrder, method);
-	Melder_require (worspaceSize > 0,
+	const integer workspaceSize = getLPCAnalysisWorkspaceSize (sframe [1] -> nx, predictionOrder, method);
+	Melder_require (workspaceSize > 0,
 		U"The workspace size is not properly defined.");
-	autoMAT workspace = newMATraw (numberOfThreads, worspaceSize);
+	autoMAT workspace = raw_MAT (numberOfThreads, workspaceSize);
 
 	std::vector <std::thread> thread (numberOfThreads);
 	std::atomic<integer> frameErrorCount (0);
@@ -543,15 +544,14 @@ static autoLPC Sound_to_LPC (Sound me, int predictionOrder, double analysisWidth
 		for (integer ithread = 1; ithread <= numberOfThreads; ithread ++) {
 			Sound soundFrame = sframe [ithread]. get(), fullsound = sound.get(), windowFrame = window.get();
 			VEC threadWorkspace = workspace. row (ithread);
-			LPC lpc = thee.get();
 			const integer firstFrame = 1 + (ithread - 1) * numberOfFramesPerThread;
 			const integer lastFrame = ( ithread == numberOfThreads ? numberOfFrames : firstFrame + numberOfFramesPerThread - 1 );
 			
 			thread [ithread - 1] = std::thread ([=, & frameErrorCount]() {
 				for (integer iframe = firstFrame; iframe <= lastFrame; iframe ++) {
-					const LPC_Frame lpcframe = & lpc -> d_frames [iframe];
-					const double t = Sampled_indexToX (lpc, iframe);
-					Sound_into_Sound (fullsound, soundFrame, t - windowDuration / 2.0);
+					const LPC_Frame lpcframe = & thy d_frames [iframe];
+					const double t = Sampled_indexToX (thee, iframe);
+					Sound_into_Sound (fullsound, soundFrame, t - 0.5 * windowDuration);
 					Vector_subtractMean (soundFrame);
 					Sounds_multiply (soundFrame, windowFrame);
 					integer status = 1;
@@ -577,7 +577,24 @@ static autoLPC Sound_to_LPC (Sound me, int predictionOrder, double analysisWidth
 	}
 	for (integer ithread = 1; ithread <= numberOfThreads; ithread ++)
 		thread [ithread - 1]. join ();
+
+}
+
+static autoLPC Sound_to_LPC (Sound me, int predictionOrder, double analysisWidth, double dt, double preEmphasisFrequency, kLPC_Analysis method, double tol1, double tol2) {
+	double windowDuration = 2.0 * analysisWidth; // Gaussian window
+	Melder_require (Melder_roundDown (windowDuration / my dx) > predictionOrder,
+		U"Analysis window duration too short.\n For a prediction order of ", predictionOrder,
+		U" the analysis window duration should be greater than ", my dx * (predictionOrder + 1),
+		U"Please increase the analysis window duration or lower the prediction order."
+	);
 	
+	if (windowDuration > my dx * my nx)
+		windowDuration = my dx * my nx;
+	double t1;
+	integer numberOfFrames;
+	Sampled_shortTermAnalysis (me, windowDuration, dt, & numberOfFrames, & t1);
+	autoLPC thee = LPC_create (my xmin, my xmax, numberOfFrames, dt, t1, predictionOrder, my dx);
+	Sound_into_LPC (me, thee.get(), analysisWidth, preEmphasisFrequency, method, tol1, tol2);
 	return thee;
 }
 
@@ -648,7 +665,7 @@ autoSound LPC_Sound_filterInverse (LPC me, Sound thee) {
 }
 
 /*
-	gain used as a constant amplitude multiplier within a frame of duration my dx.
+	Gain used as a constant amplitude multiplier within a frame of duration my dx.
 	future alternative: convolve gain with a smoother.
 */
 autoSound LPC_Sound_filter (LPC me, Sound thee, bool useGain) {
@@ -665,7 +682,7 @@ autoSound LPC_Sound_filter (LPC me, Sound thee, bool useGain) {
 		autoSound source;
 		if (my samplingPeriod != thy dx) {
 			source = Sound_resample (thee, 1.0 / my samplingPeriod, 50);
-			thee = source.get();   // Reference copy; remove at end
+			thee = source.get();   // reference copy; remove at end
 		}
 
 		autoSound him = Data_copy (thee);
@@ -751,7 +768,7 @@ void LPC_Sound_filterInverseWithFilterAtTime_inplace (LPC me, Sound thee, intege
 		if (channel > thy ny)
 			channel = 1;
 		LPC_Frame lpc = & my d_frames [frameIndex];
-		autoVEC work = newVECraw (lpc -> nCoefficients);
+		autoVEC work = raw_VEC (lpc -> nCoefficients);
 		if (channel > 0)
 			VECfilterInverse_inplace (thy z.row (channel), lpc -> a.get(), work);
 		else
