@@ -134,8 +134,8 @@ autoLPC VocalTractTier_to_LPC (VocalTractTier me, double timeStep) {
 		integer numberOfSections = vtp -> d_vocalTract -> nx;
 		const double samplingPeriod = 1.0 / (1000.0 * numberOfSections);
 		
-		autoMAT area = newMATzero (numberOfFrames, numberOfSections);
-		autoVEC areavec = newVECraw (numberOfSections);
+		autoMAT area = zero_MAT (numberOfFrames, numberOfSections);
+		autoVEC areavec = raw_VEC (numberOfSections);
 		autoLPC thee = LPC_create (my xmin, my xmax, numberOfFrames, timeStep, timeStep / 2.0, numberOfSections, samplingPeriod);
 		// interpolate each section
 		for (integer isection = 1; isection <= numberOfSections; isection ++) {
