@@ -1,6 +1,6 @@
 /* FileInMemoryManager.cpp
  *
- * Copyright (C) 2017-2019 David Weenink
+ * Copyright (C) 2017-2020 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,23 +101,6 @@ integer SortedSetOfLong_Lookup (SortedSetOfLong me, integer number) {
 }
 */
 
-autoTable FileInMemoryManager_downto_Table (FileInMemoryManager me, bool openFilesOnly) {
-	try {
-		const integer numberOfRows = openFilesOnly ? my openFiles -> size : my files -> size;
-		autoTable thee = Table_createWithColumnNames (numberOfRows, U"path id size position");
-		for (integer irow = 1; irow <= numberOfRows; irow ++) {
-			const FileInMemory fim = static_cast <FileInMemory> (openFilesOnly ? my openFiles -> at [irow] : my files -> at [irow]);
-			Table_setStringValue (thee.get(), irow, 1, fim -> d_path.get());
-			Table_setStringValue (thee.get(), irow, 2, fim -> d_id.get());
-			Table_setNumericValue (thee.get(), irow, 3, fim -> d_numberOfBytes);
-			Table_setNumericValue (thee.get(), irow, 4, fim -> d_position);
-		}
-		return thee;
-	} catch (MelderError) {
-		Melder_throw (me, U": no Table created.");
-	}
-}
-
 autoFileInMemory FileInMemoryManager_createFile (FileInMemoryManager me, MelderFile file) {
 	try {
 		autoFileInMemory thee = FileInMemory_create (file);
@@ -443,7 +426,7 @@ char *FileInMemoryManager_fgets (FileInMemoryManager me, char *str, int num, FIL
 	if (startPos < fim -> d_numberOfBytes) {
 		integer i = 0, endPos = startPos + num;
 		endPos = endPos < fim -> d_numberOfBytes ? endPos : fim -> d_numberOfBytes;
-		const unsigned char * p = fim -> d_data + startPos;
+		const unsigned char * p = fim -> d_data.asArgumentToFunctionThatExpectsZeroBasedArray () + startPos;
 		char *p_str = str;
 		if (fim -> ungetChar > 0) {
 			/*
@@ -543,7 +526,7 @@ size_t FileInMemoryManager_fread (FileInMemoryManager me, void *ptr, size_t size
 			fim -> d_errno = EOF;
 		}
 		const integer numberOfBytes = count * size;
-		const unsigned char * p = fim -> d_data + fim -> d_position;
+		const unsigned char * p = fim -> d_data.asArgumentToFunctionThatExpectsZeroBasedArray () + fim -> d_position;
 		char * str = static_cast<char *> (ptr);
 		while (i < numberOfBytes)
 			str [i ++] = *p ++;
@@ -696,27 +679,14 @@ int FileInMemoryManager_ungetc (FileInMemoryManager me, int character, FILE * st
 int FileInMemoryManager_fprintf (FileInMemoryManager me, FILE * stream, const char *format, ... ) {
 	(void) me;
 	va_list args;
-	size_t bufferSize = -1;
 	if (stream == stderr) {
 		va_start (args, format);
-		bufferSize = 3;
-		autoNUMvector<char> buf (0_integer, bufferSize);
-		const int sizeNeeded = vsnprintf (buf.peek(), bufferSize, format, args); // find the size of the needed buffer
+		int sizeNeeded = vsnprintf (nullptr, 0, format, args); // find size of needed buffer (without final null byte)
+		const size_t bufferSize = sizeNeeded + 1;
 		va_end (args);
-		if (sizeNeeded > bufferSize) {
-			buf.reset (0_integer, sizeNeeded);
-			va_start (args, format);
-			(void) vsnprintf (buf.peek(), sizeNeeded, format, args);
-			va_end (args);
-		}
-		bufferSize = sizeNeeded;
-		// append the buffer 
-		//MelderInfo_writeLine (Melder_peek8to32 (buf.peek()));
-
-	} else {
-		//integer openFilesIndex = _FileInMemoryManager_getIndexInOpenFiles (me, stream); // 
+		return bufferSize;
 	}
-	return bufferSize;
+	return -1;
 }
 
 void test_FileInMemoryManager_io (void) {
