@@ -19,13 +19,13 @@
 #define ooSTRUCT FileInMemoryManager
 oo_DEFINE_CLASS (FileInMemoryManager, Daata)
 
-	oo_AUTO_OBJECT (FileInMemorySet, 0, files)
-	oo_AUTO_OBJECT (FileInMemorySet, 0, openFiles)
+	oo_OBJECT (FileInMemorySet, 0, files)
+	oo_OBJECT (FileInMemorySet, 0, openFiles)
 	oo_INTEGER (errorNumber)
+
 	#if oo_DECLARING
-
-		void v_info () override;
-
+		void v_info ()
+			override;
 	#endif
 	
 oo_END_CLASS (FileInMemoryManager)
