@@ -23,9 +23,7 @@
 #include "NUMmachar.h"
 #include "melder.h"
 
-#ifndef _NUMcblas_h_
-#include "NUMcblas.h"
-#endif
+#include "NUMlapack.h"
 
 static struct structmachar_Table machar_table;
 machar_Table NUMfpp = NULL;
@@ -50,22 +48,24 @@ ngrd
 		sfmin	'S'		safe minimum, such that 1/sfmin does not overflow
 */
 
+double dlamch_(const char *cmach); // blas
+
 void NUMmachar () {
 	if (NUMfpp)
 		return;
 
 	NUMfpp = & machar_table;
 
-	NUMfpp -> base  = (int) NUMblas_dlamch ("Base");
-	NUMfpp -> t     = (int) NUMblas_dlamch ("Number of digits in mantissa");
-	NUMfpp -> emin  = (int) NUMblas_dlamch ("Minimum exponent");
-	NUMfpp -> emax  = (int) NUMblas_dlamch ("Largest exponent");
-	NUMfpp -> rnd   = (int) NUMblas_dlamch ("Rounding mode");
-	NUMfpp -> prec  = NUMblas_dlamch ("Precision");
-	NUMfpp -> eps   = NUMblas_dlamch ("Epsilon");
-	NUMfpp -> rmin  = NUMblas_dlamch ("Underflow threshold");
-	NUMfpp -> sfmin = NUMblas_dlamch ("Safe minimum");
-	NUMfpp -> rmax  = NUMblas_dlamch ("Overflow threshold");
+	NUMfpp -> base  = (int) NUMlapack_dlamch_ ("Base");
+	NUMfpp -> t     = (int) NUMlapack_dlamch_ ("Number of digits in mantissa");
+	NUMfpp -> emin  = (int) NUMlapack_dlamch_ ("Minimum exponent");
+	NUMfpp -> emax  = (int) NUMlapack_dlamch_ ("Largest exponent");
+	NUMfpp -> rnd   = (int) NUMlapack_dlamch_ ("Rounding mode");
+	NUMfpp -> prec  = NUMlapack_dlamch_ ("Precision");
+	NUMfpp -> eps   = NUMlapack_dlamch_ ("Epsilon");
+	NUMfpp -> rmin  = NUMlapack_dlamch_ ("Underflow threshold");
+	NUMfpp -> sfmin = NUMlapack_dlamch_ ("Safe minimum");
+	NUMfpp -> rmax  = NUMlapack_dlamch_ ("Overflow threshold");
 }
 
 /* End of file NUMmachar.c */
