@@ -39,8 +39,8 @@ void MATrankColumns (MAT m, integer cb, integer ce) {
 	Melder_assert (cb > 0 && cb <= m.ncol);
 	Melder_assert (ce > 0 && ce <= m.ncol);
 	Melder_assert (cb <= ce);
-	autoVEC v = newVECraw (m.nrow);
-	autoINTVEC index = newINTVECraw (m.nrow);
+	autoVEC v = raw_VEC (m.nrow);
+	autoINTVEC index = raw_INTVEC (m.nrow);
 
 	for (integer j = cb; j <= ce; j ++) {
 		v.all() <<= m.column (j);
@@ -129,80 +129,74 @@ void NUMindexx (const T a[], integer n, integer index[], int (*compare) (void *,
 
 
 #define MACRO_NUMindex(TYPE) \
-{\
+{ \
 	Melder_assert (v.size == index.size); \
 	integer l, r, i, j, ii, k, imin; \
 	TYPE min; \
-	INTVEClinear (index, 1, 1); \
-	if (v.size < 2) return;   /* Already sorted. */ \
-	if (v.size == 2) \
-	{ \
-		if (COMPARELT (v [2], v [1])) \
-		{\
-			index [1] = 2; index [2] = 1; \
+	to_INTVEC_out (index); \
+	if (v.size < 2) \
+		return;   /* Already sorted. */ \
+	if (v.size == 2) { \
+		if (COMPARELT (v [2], v [1])) { \
+			index [1] = 2; \
+			index [2] = 1; \
 		} \
 		return; \
 	} \
-	if (v.size <= 12) \
-	{ \
-		for (i = 1; i < v.size; i ++) \
-		{ \
+	if (v.size <= 12) { \
+		for (i = 1; i < v.size; i ++) { \
 			imin = i; \
 			min = v [index [imin]]; \
-			for (j = i + 1; j <= v.size; j ++) \
-			{\
-				if (COMPARELT (v [index [j]], min))\
-				{ \
+			for (j = i + 1; j <= v.size; j ++) { \
+				if (COMPARELT (v [index [j]], min)) { \
 					imin = j; \
 					min = v [index [j]]; \
 				} \
 			} \
-			ii = index [imin]; index [imin] = index [i]; index [i] = ii; \
+			ii = index [imin]; \
+			index [imin] = index [i]; \
+			index [i] = ii; \
 		} \
 		return; \
 	} \
-	/* H1 */\
+	/* H1 */ \
 	l = v.size / 2 + 1; \
 	r = v.size; \
-	for (;;) /* H2 */\
-	{ \
-		if (l > 1) \
-		{ \
+	for (;;) { /* H2 */ \
+		if (l > 1) { \
 			l --; \
-			k = index[l]; \
-		} \
-		else /* l == 1 */ \
-		{ \
+			k = index [l]; \
+		} else { /* l == 1 */ \
 			k = index [r]; \
 			index [r] = index [1]; \
 			r --; \
-			if (r == 1) \
-			{ \
-				index [1] = k; break; \
+			if (r == 1) { \
+				index [1] = k; \
+				break; \
 			} \
 		} \
 		/* H3 */ \
 		j = l; \
-		for (;;) \
-		{ \
+		for (;;) { \
 			/* H4 */ \
 			i = j; \
 			j *= 2; \
-			if (j > r) break; \
-			if (j < r && COMPARELT (v [index [j]], v [index [j + 1]])) j ++; /* H5 */\
-			index [i] = index [j]; /* H7 */\
+			if (j > r) \
+				break; \
+			if (j < r && COMPARELT (v [index [j]], v [index [j + 1]])) \
+				j ++; /* H5 */ \
+			index [i] = index [j]; /* H7 */ \
 		} \
-		for (;;)  /*H8' */\
-		{\
+		for (;;) {  /*H8' */ \
 			j = i; \
 			i = j >> 1; \
 			/* H9' */ \
-			if (j == l || COMPARELT (v[k], v[index[i]])) \
-			{ \
-				index [j] = k; break; \
+			if (j == l || COMPARELT (v [k], v[index [i]])) { \
+				index [j] = k; \
+				break; \
 			} \
 			index [j] = index [i]; \
-		}\
+		} \
 	} \
 }
 
@@ -229,7 +223,7 @@ void VECsort3_inplace (VEC const& a, INTVEC const& iv1, INTVEC const& iv2, bool
 	Melder_assert (a.size == iv1.size && a.size == iv2.size);
 	if (a.size == 1)
 		return;
-	autoVEC atmp = newVECcopy (a);
+	autoVEC atmp = copy_VEC (a);
 	autoINTVEC index = newINTVECindex (atmp.get());
 	if (descending)
 		for (integer j = 1; j <= a.size / 2; j ++)
@@ -237,7 +231,7 @@ void VECsort3_inplace (VEC const& a, INTVEC const& iv1, INTVEC const& iv2, bool
 
 	for (integer j = 1; j <= a.size; j ++)
 		a [j] = atmp [index [j]];
-	autoINTVEC itmp = newINTVECraw (a.size);
+	autoINTVEC itmp = raw_INTVEC (a.size);
 	itmp.all() <<= iv1;
 	for (integer j = 1; j <= a.size; j ++)
 		iv1 [j] = itmp [index [j]];
