@@ -47,7 +47,7 @@ autoComplexSpectrogram ComplexSpectrogram_create (double tmin, double tmax, inte
 	try {
 		autoComplexSpectrogram me = Thing_new (ComplexSpectrogram);
 		Matrix_init (me.get(), tmin, tmax, nt, dt, t1, fmin, fmax, nf, df, f1);
-		my phase = newMATzero (my ny, my nx);
+		my phase = zero_MAT (my ny, my nx);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"ComplexSpectrogram not created.");
@@ -55,7 +55,7 @@ autoComplexSpectrogram ComplexSpectrogram_create (double tmin, double tmax, inte
 }
 
 autoVEC newVEChanning (integer size) {
-	autoVEC window = newVECraw (size);
+	autoVEC window = raw_VEC (size);
 	for (integer i = 1; i <= size; i ++)
 		window [i] = 0.5 * (1.0 - cos (NUM2pi * i / size));
 	return window;
@@ -146,7 +146,7 @@ autoSound ComplexSpectrogram_to_Sound (ComplexSpectrogram me, double stretchFact
 		autoSound synthesisWindow = Sound_createSimple (1, synthesisWindowDuration, samplingFrequency);
 		const double newDuration = (my xmax - my xmin) * stretchFactor;
 		autoSound thee = Sound_createSimple (1, newDuration, samplingFrequency); //TODO
-		double thyStartTime;
+		//double thyStartTime;
 		for (integer iframe = 1; iframe <= my nx; iframe ++) {
 			// "original" sound :
 			const double tmid = Sampled_indexToX (me, iframe);
@@ -155,23 +155,21 @@ autoSound ComplexSpectrogram_to_Sound (ComplexSpectrogram me, double stretchFact
 			const integer startSample = rightSample - halfnsamp_window;
 			const integer endSample = std::min (startSample + nsamp_window - 1, thy nx);
 			
-			const double startTime = Sampled_indexToX (thee.get(), startSample);
-			if (iframe == 1)
-				thyStartTime = Sampled_indexToX (thee.get(), startSample);
+			//const double startTime = Sampled_indexToX (thee.get(), startSample);
+			//if (iframe == 1)
+			//	thyStartTime = Sampled_indexToX (thee.get(), startSample);
 			//integer endSample = leftSample + halfnsamp_window;
 			// New Sound with stretch
-			const integer thyStartSample = Sampled_xToLowIndex (thee.get(), thyStartTime);
-			const double thyEndTime = thyStartTime + my dx * stretchFactor;
-			const integer thyEndSample = Sampled_xToLowIndex (thee.get(), thyEndTime);
-			const integer stretchedStepSizeSamples = thyEndSample - thyStartSample + 1;
+			//const integer thyStartSample = Sampled_xToLowIndex (thee.get(), thyStartTime);
+			//const double thyEndTime = thyStartTime + my dx * stretchFactor;
+			//const integer thyEndSample = Sampled_xToLowIndex (thee.get(), thyEndTime);
 			//double extraTime = (thyStartSample - startSample + 1) * thy dx;
-			const double extraTime = thyStartTime - startTime;
+			//const double extraTime = thyStartTime - startTime;
 			spectrum -> z [1] [1] = sqrt (my z [1] [iframe]);
 			for (integer ifreq = 2; ifreq <= my ny; ifreq ++) {
-				const double f = my y1 + (ifreq - 1) * my dy;
+				//const double f = my y1 + (ifreq - 1) * my dy;
 				const double a = sqrt (my z [ifreq] [iframe]);
-				double dummy;
-				const double extraPhase = 2.0 * NUMpi * modf (extraTime * f, & dummy); // fractional part
+				//double dummy;
 				const double phi = my phase [ifreq] [iframe]; // + extraPhase;
 				spectrum -> z [1] [ifreq] = a * cos (phi);
 				spectrum -> z [2] [ifreq] = a * sin (phi);
