@@ -366,7 +366,7 @@ double DataModeler_getDegreesOfFreedom (DataModeler me) {
 	If equal weighing than get the sigma form the residual sum of squares between model and data.
 */
 autoVEC DataModeler_getDataPointsWeights (DataModeler me, kDataModelerWeights weighData) {
-	autoVEC weights = newVECzero (my numberOfDataPoints);
+	autoVEC weights = zero_VEC (my numberOfDataPoints);
 	if (weighData == kDataModelerWeights::EQUAL_WEIGHTS) {
 			/*
 				We weigh with the inverse of the standard deviation of the data to give
@@ -375,7 +375,7 @@ autoVEC DataModeler_getDataPointsWeights (DataModeler me, kDataModelerWeights we
 			const double stdev = DataModeler_getDataStandardDeviation (me);
 			Melder_require (isdefined (stdev),
 				U"Not enough data points to calculate standard deviation.");
-			weights.get() <<= 1.0 / stdev;
+			weights.all()  <<=  1.0 / stdev;
 	} else {	
 		for (integer ipoint = 1; ipoint <= my numberOfDataPoints; ipoint ++) {
 			if (my data [ipoint] .status == kDataModelerData::INVALID)
@@ -399,7 +399,7 @@ autoVEC DataModeler_getDataPointsWeights (DataModeler me, kDataModelerWeights we
 
 autoVEC DataModeler_getZScores (DataModeler me) {
 	try {
-		autoVEC zscores = newVECraw (my numberOfDataPoints);
+		autoVEC zscores = raw_VEC (my numberOfDataPoints);
 		autoVEC weights = DataModeler_getDataPointsWeights (me, my weighData);
 		for (integer ipoint = 1; ipoint <= my numberOfDataPoints; ipoint ++) {
 			double z = undefined;
@@ -417,7 +417,7 @@ autoVEC DataModeler_getZScores (DataModeler me) {
 
 autoVEC DataModeler_getChisqScoresFromZScores (DataModeler me, constVEC zscores, bool substituteAverage) {
 	Melder_assert (zscores.size == my numberOfDataPoints);
-	autoVEC chisq = newVECraw (zscores.size);
+	autoVEC chisq = raw_VEC (zscores.size);
 	integer numberOfDefined = 0;
 	double sumchisq = 0.0;
 	for (integer ipoint = 1; ipoint <= my numberOfDataPoints; ipoint ++) {
@@ -496,9 +496,9 @@ void DataModeler_drawBasisFunction_inside (DataModeler me, Graphics g, double xm
 	integer iterm, bool scale, integer numberOfPoints)
 {
 	Function_unidirectionalAutowindow (me, & xmin, & xmax);
-	autoVEC x = newVECraw (numberOfPoints);
-	autoVEC y = newVECraw (numberOfPoints);
-	autoVEC term = newVECraw (my numberOfParameters);
+	autoVEC x = raw_VEC (numberOfPoints);
+	autoVEC y = raw_VEC (numberOfPoints);
+	autoVEC term = raw_VEC (my numberOfParameters);
 	for (integer i = 1; i <= numberOfPoints; i ++) {
 		x [i] = xmin + (i - 0.5) * (xmax - xmin) / numberOfPoints;
 		my f_evaluateBasisFunctions (me, x [i], term.get());
@@ -534,7 +534,7 @@ integer DataModeler_drawingSpecifiers_x (DataModeler me, double *xmin, double *x
 	return *ixmax - *ixmin + 1;
 }
 
-void DataModeler_drawOutliersMarked_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, double numberOfSigmas, conststring32 mark, double marksFontSize, double horizontalOffset_wc)
+void DataModeler_drawOutliersMarked_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, double numberOfSigmas, conststring32 mark, double marksFontSize)
 {
 	integer ixmin, ixmax;
 	if (DataModeler_drawingSpecifiers_x (me, & xmin, & xmax, & ixmin, & ixmax) < 1)
@@ -550,24 +550,23 @@ void DataModeler_drawOutliersMarked_inside (DataModeler me, Graphics g, double x
 			const double x = my data [ipoint] .x, y = my data [ipoint] .y;
 			if (x >= xmin && x <= xmax && y >= ymin && y <= ymax)
 				if (fabs (zscores [ipoint]) > numberOfSigmas)
-					Graphics_text (g, x + horizontalOffset_wc, y, mark);
+					Graphics_text (g, x, y, mark);
 		}
 	}
 	Graphics_setFontSize (g, currentFontSize);
 }
 
-void DataModeler_draw_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, bool estimated, integer numberOfParameters, bool errorbars, bool connectPoints, double barWidth_wc, double horizontalOffset_wc, bool drawDots)
+void DataModeler_draw_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, bool estimated, integer numberOfParameters, bool errorbars, bool connectPoints, double barWidth_wc, bool drawDots)
 {
 	Function_unidirectionalAutowindow (me, & xmin, & xmax);
-	integer ixmin = 2;
-	while (my data [ixmin] .x < xmin && ixmin < my numberOfDataPoints)
+
+	integer ixmin = 1;
+	while (ixmin <= my numberOfDataPoints && my data [ixmin] .x < xmin)
 		ixmin ++;
-	ixmin --;
-	integer ixmax = my numberOfDataPoints - 1;
-	while (my  data [ixmax] .x > xmax && ixmax > 1)
+	integer ixmax = my numberOfDataPoints;
+	while (ixmax > 0 && my data [ixmax] .x > xmax)
 		ixmax --;
-	ixmax ++;
-	if (ixmin >= ixmax)
+	if (ixmin > ixmax)
 		return; // nothing to draw
 	getAutoNaturalNumberWithinRange (& numberOfParameters, my numberOfParameters);	
 	
@@ -588,12 +587,12 @@ void DataModeler_draw_inside (DataModeler me, Graphics g, double xmin, double xm
 			}
 			if (x1defined && drawDots) {
 				if (y >= ymin && y <= ymax)
-					Graphics_speckle (g, x + horizontalOffset_wc, y);
+					Graphics_speckle (g, x, y);
 			}
 			if (x2defined) { // if (x1defined && x2defined)
 				if (connectPoints) {
 					double xo1, yo1, xo2, yo2;
-					if (NUMclipLineWithinRectangle (x1 + horizontalOffset_wc, y1, x2 + horizontalOffset_wc, y2,
+					if (NUMclipLineWithinRectangle (x1, y1, x2, y2,
 						xmin, ymin, xmax, ymax, & xo1, & yo1, & xo2, & yo2)) {
 						Graphics_line (g, xo1, yo1, xo2, yo2);
 					}
@@ -612,9 +611,9 @@ void DataModeler_draw_inside (DataModeler me, Graphics g, double xmin, double xm
 				bool topOutside = yt > ymax, bottomOutside = yb < ymin;
 				yt = ( topOutside ? ymax : yt );
 				yb = ( bottomOutside ? ymin : yb );
-				Graphics_line (g, x1 + horizontalOffset_wc, yb, x1 + horizontalOffset_wc, yt);
+				Graphics_line (g, x1, yb, x1, yt);
 				if (barWidth_wc > 0.0 && ! estimated) {
-					double xl = x1 - 0.5 * barWidth_wc + horizontalOffset_wc;
+					double xl = x1 - 0.5 * barWidth_wc;
 					double xr = xl + barWidth_wc;
 					if (! topOutside)
 						Graphics_line (g, xl, yt, xr, yt);
@@ -626,19 +625,40 @@ void DataModeler_draw_inside (DataModeler me, Graphics g, double xmin, double xm
 	}
 }
 
-void DataModeler_drawTrack_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, bool estimated, integer numberOfParameters, double horizontalOffset_wc)
+void DataModeler_drawModel_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, integer numberOfPoints) {
+	Function_bidirectionalAutowindow (me, & xmin, & xmax);
+	autoVEC x = raw_VEC (numberOfPoints), y = raw_VEC (numberOfPoints);
+	const double dx = (xmax - xmin) / numberOfPoints;
+	for (integer ipoint = 1; ipoint <= numberOfPoints; ipoint ++) {
+		x [ipoint] = xmin + (ipoint - 1) * dx;
+		y [ipoint] = my f_evaluate (me, x [ipoint], my parameters.get());
+	}
+	if (ymin == 0.0 && ymax == 0.0) {
+		ymin = NUMmin (y.get());
+		ymax = NUMmax (y.get());
+	}
+	Graphics_setWindow (g, xmin, xmax, ymin, ymax);
+	for (integer ipoint = 2; ipoint <= numberOfPoints; ipoint ++) {
+		double segment_x1, segment_y1, segment_x2, segment_y2;
+		if (NUMclipLineWithinRectangle (x [ipoint - 1], y [ipoint - 1], x [ipoint], y [ipoint],
+			xmin, ymin, xmax, ymax, & segment_x1, & segment_y1, & segment_x2, & segment_y2))
+				Graphics_line (g, segment_x1, segment_y1, segment_x2, segment_y2);
+	}
+}
+
+void DataModeler_drawTrack_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, bool estimated, integer numberOfParameters)
 {
 	const bool errorbars = false, connectPoints = true;
 	const double barWidth_mm = 0;
-	DataModeler_draw_inside (me, g, xmin, xmax, ymin, ymax, estimated, numberOfParameters, errorbars, connectPoints, barWidth_mm, horizontalOffset_wc, 0);
+	DataModeler_draw_inside (me, g, xmin, xmax, ymin, ymax, estimated, numberOfParameters, errorbars, connectPoints, barWidth_mm, 0);
 }
 
 void DataModeler_drawTrack (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax,
-	bool estimated, integer numberOfParameters, double horizontalOffset_wc, bool garnish) {
+	bool estimated, integer numberOfParameters, bool garnish) {
 	if (ymax <= ymin)
 		DataModeler_getExtremaY (me, & ymin, & ymax);
 	Graphics_setInner (g);
-	DataModeler_drawTrack_inside (me, g, xmin, xmax, ymin, ymax, estimated, numberOfParameters, horizontalOffset_wc);
+	DataModeler_drawTrack_inside (me, g, xmin, xmax, ymin, ymax, estimated, numberOfParameters);
 	Graphics_unsetInner (g);
 	if (garnish) {
 		Graphics_drawInnerBox (g);
@@ -647,19 +667,19 @@ void DataModeler_drawTrack (DataModeler me, Graphics g, double xmin, double xmax
 	}
 }
 
-void DataModeler_speckle_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, bool estimated, integer numberOfParameters, bool errorbars, double barWidth_wc, double horizontalOffset_wc) {
+void DataModeler_speckle_inside (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax, bool estimated, integer numberOfParameters, bool errorbars, double barWidth_wc) {
 	bool connectPoints = false;
-	DataModeler_draw_inside (me, g, xmin, xmax, ymin, ymax, estimated, numberOfParameters, errorbars, connectPoints, barWidth_wc, horizontalOffset_wc, 1);
+	DataModeler_draw_inside (me, g, xmin, xmax, ymin, ymax, estimated, numberOfParameters, errorbars, connectPoints, barWidth_wc, 1);
 }
 
 void DataModeler_speckle (DataModeler me, Graphics g, double xmin, double xmax, double ymin, double ymax,
-	bool estimated, integer numberOfParameters, bool errorbars, double barWidth_mm, double horizontalOffset_wc, bool garnish)
+	bool estimated, integer numberOfParameters, bool errorbars, double barWidth_mm, bool garnish)
 {
 	if (ymax <= ymin)
 		DataModeler_getExtremaY (me, & ymin, & ymax);
 	Graphics_setInner (g);
 	DataModeler_speckle_inside (me, g, xmin, xmax, ymin, ymax,
-		estimated, numberOfParameters, errorbars, barWidth_mm, horizontalOffset_wc);
+		estimated, numberOfParameters, errorbars, barWidth_mm);
 	Graphics_unsetInner (g);
 	if (garnish) {
 		Graphics_drawInnerBox (g);
@@ -712,8 +732,6 @@ void DataModeler_init (DataModeler me, double xmin, double xmax, integer numberO
 	
 	Melder_require (numberOfParameters > 0,
 		U"The number of parameters should be greater than zero.");
-	Melder_require (numberOfParameters <= numberOfDataPoints,
-		U"The number of parameters should not exceed the number of data points");
 	
 	my parameters = newvectorzero<structDataModelerParameter> (numberOfParameters);
 	for (integer ipar = 1; ipar <= numberOfParameters; ipar ++)
@@ -768,10 +786,12 @@ void DataModeler_fit (DataModeler me) {
 		if (numberOfFreeParameters == 0)
 			return;
 		const integer numberOfValidDataPoints = DataModeler_getNumberOfValidDataPoints (me);
-		autoVEC yEstimation = newVECzero (numberOfValidDataPoints);
-		autoVEC term = newVECzero (my numberOfParameters);
+		if (numberOfValidDataPoints - numberOfFreeParameters < 0)
+			return;
+		autoVEC yEstimation = zero_VEC (numberOfValidDataPoints);
+		autoVEC term = zero_VEC (my numberOfParameters);
 		autovector<structDataModelerParameter> fixedParameters = newvectorcopy (my parameters.all());
-		autoMAT designMatrix = newMATzero (numberOfValidDataPoints, numberOfFreeParameters);
+		autoMAT designMatrix = zero_MAT (numberOfValidDataPoints, numberOfFreeParameters);
 		autoVEC weights = DataModeler_getDataPointsWeights (me, my weighData);
 		/*
 			For function evaluation with only the FIXED parameters
@@ -872,9 +892,9 @@ autoDataModeler Table_to_DataModeler (Table me, double xmin, double xmax, intege
 			Table_checkSpecifiedColumnNumberWithinRange (me, sigmacolumn);
 		const integer numberOfRows = my rows.size;
 		integer numberOfData = 0;
-		autoVEC x = newVECraw (numberOfRows);
-		autoVEC y = newVECraw (numberOfRows);
-		autoVEC sy = newVECraw (numberOfRows);
+		autoVEC x = raw_VEC (numberOfRows);
+		autoVEC y = raw_VEC (numberOfRows);
+		autoVEC sy = raw_VEC (numberOfRows);
 		for (integer i = 1; i <= numberOfRows; i ++) {
 			const double val = Table_getNumericValue_Assert (me, i, xcolumn);
 			if (isdefined (val)) {
@@ -958,7 +978,7 @@ void DataModeler_reportChiSquared (DataModeler me) {
 double DataModeler_getDataStandardDeviation (DataModeler me) {
 	try {
 		integer numberOfDataPoints = 0;
-		autoVEC y = newVECraw (my numberOfDataPoints);
+		autoVEC y = raw_VEC (my numberOfDataPoints);
 		for (integer i = 1; i <= my numberOfDataPoints; i ++) {
 			if (my data [i] .status != kDataModelerData::INVALID)
 				y [++ numberOfDataPoints] = my data [i]. y;
