@@ -9,20 +9,21 @@
  *
  * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 enums_begin (kContextCombination, 1)
-	enums_add (kContextCombination, 1, LEFT, U"Left")
-	enums_add (kContextCombination, 2, RIGHT, U"Right")
-	enums_add (kContextCombination, 3, LEFT_AND_RIGHT, U"Left and right")
-	enums_add (kContextCombination, 4, LEFT_OR_RIGHT_NOT_BOTH, U"Left or right, not both")
-	enums_add (kContextCombination, 5, LEFT_OR_RIGHT_OR_BOTH, U"Left or right or both")
-	enums_add (kContextCombination, 6, NO_LEFT_AND_NO_RIGHT, U"No left and no right")
-enums_end (kContextCombination, 6, LEFT)
+	enums_add (kContextCombination, 1, LEFT, U"left")
+	enums_add (kContextCombination, 2, RIGHT, U"right")
+	enums_add (kContextCombination, 3, LEFT_AND_RIGHT, U"left and right")
+	enums_add (kContextCombination, 4, LEFT_OR_RIGHT_NOT_BOTH, U"left or right, not both")
+	enums_add (kContextCombination, 5, LEFT_OR_RIGHT_OR_BOTH, U"left or right or both")
+	enums_add (kContextCombination, 6, NO_LEFT_AND_NO_RIGHT, U"no left and no right")
+enums_end (kContextCombination, 6, NO_LEFT_AND_NO_RIGHT)
+
 
 /* End of file IntervalTierNavigator_enums.h */
