@@ -1,4 +1,4 @@
-/* KlattGridEditors.c
+/* KlattGridEditors.cpp
  *
  * Copyright (C) 2009-2019 david Weenink
  *
@@ -36,6 +36,8 @@ static void KlattGrid_Editor_defaultPlay (KlattGrid me, double tmin, double tmax
 
 /************************** KlattGrid_RealTierEditor *********************************/
 
+Thing_implement (KlattGrid_RealTierArea, RealTierArea, 0);
+
 Thing_implement (KlattGrid_RealTierEditor, RealTierEditor, 0);
 
 static void menu_cb_KlattGridHelp (KlattGrid_RealTierEditor, EDITOR_ARGS_DIRECT) {
@@ -47,17 +49,19 @@ void structKlattGrid_RealTierEditor :: v_createHelpMenuItems (EditorMenu menu) {
 	EditorMenu_addCommand (menu, U"KlattGrid help", 0, menu_cb_KlattGridHelp);
 }
 
-void structKlattGrid_RealTierEditor :: v_play (double ltmin, double ltmax) {
-	KlattGrid_Editor_defaultPlay (klattgrid, ltmin, ltmax);
+void structKlattGrid_RealTierEditor :: v_play (double startTime, double endTime) {
+	KlattGrid_Editor_defaultPlay (klattgrid, startTime, endTime);
 }
 
-void KlattGrid_RealTierEditor_init (KlattGrid_RealTierEditor me, conststring32 title, KlattGrid klattgrid, RealTier data) {
+void KlattGrid_RealTierEditor_init (KlattGrid_RealTierEditor me, ClassInfo viewClass, conststring32 title, KlattGrid klattgrid, RealTier data) {
 	my klattgrid = klattgrid;
-	RealTierEditor_init (me, title, data, nullptr, false);
+	RealTierEditor_init (me, viewClass, title, data, nullptr, false);
 }
 
 /************************** KlattGrid_PitchTierEditor *********************************/
 
+Thing_implement (KlattGrid_PitchTierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_PitchTierEditor, KlattGrid_RealTierEditor, 0);
 
 static void menu_cb_KlattGrid_PitchTierEditorHelp (KlattGrid_PitchTierEditor, EDITOR_ARGS_DIRECT) {
@@ -77,7 +81,7 @@ autoKlattGrid_PitchTierEditor KlattGrid_PitchTierEditor_create (conststring32 ti
 	try {
 		autoKlattGrid_PitchTierEditor me = Thing_new (KlattGrid_PitchTierEditor);
 		const RealTier tier = klattgrid -> phonation -> pitch.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_PitchTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid pitch window not created.");
@@ -86,6 +90,8 @@ autoKlattGrid_PitchTierEditor KlattGrid_PitchTierEditor_create (conststring32 ti
 
 /************************** KlattGrid_IntensityTierEditor *********************************/
 
+Thing_implement (KlattGrid_IntensityTierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_IntensityTierEditor, KlattGrid_RealTierEditor, 0);
 
 static void menu_cb_IntensityTierHelp (KlattGrid_IntensityTierEditor, EDITOR_ARGS_DIRECT) {
@@ -97,19 +103,21 @@ void structKlattGrid_IntensityTierEditor :: v_createHelpMenuItems (EditorMenu me
 	EditorMenu_addCommand (menu, U"IntensityTier help", 0, menu_cb_IntensityTierHelp);
 }
 
-void KlattGrid_IntensityTierEditor_init (KlattGrid_IntensityTierEditor me, conststring32 title, KlattGrid klattgrid, RealTier tier) {
-	KlattGrid_RealTierEditor_init (me, title, klattgrid, tier);
+void KlattGrid_IntensityTierEditor_init (KlattGrid_IntensityTierEditor me, ClassInfo viewClass, conststring32 title, KlattGrid klattgrid, RealTier tier) {
+	KlattGrid_RealTierEditor_init (me, viewClass, title, klattgrid, tier);
 }
 
 
 /************************** KlattGrid_DecibelTierEditor *********************************/
 
+Thing_implement (KlattGrid_DecibelTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_DecibelTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_DecibelTierEditor KlattGrid_DecibelTierEditor_create (conststring32 title, KlattGrid klattgrid, RealTier tier) {
 	try {
 		autoKlattGrid_DecibelTierEditor me = Thing_new (KlattGrid_DecibelTierEditor);
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_DecibelTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid decibel window not created.");
@@ -118,13 +126,15 @@ autoKlattGrid_DecibelTierEditor KlattGrid_DecibelTierEditor_create (conststring3
 
 /************************** KlattGrid_VoicingAmplitudeTierEditor *********************************/
 
+Thing_implement (KlattGrid_VoicingAmplitudeTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_VoicingAmplitudeTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_VoicingAmplitudeTierEditor KlattGrid_VoicingAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_VoicingAmplitudeTierEditor me = Thing_new (KlattGrid_VoicingAmplitudeTierEditor);
 		const RealTier tier = klattgrid -> phonation -> voicingAmplitude.get();
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_VoicingAmplitudeTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid voicing amplitude window not created.");
@@ -133,13 +143,15 @@ autoKlattGrid_VoicingAmplitudeTierEditor KlattGrid_VoicingAmplitudeTierEditor_cr
 
 /************************** KlattGrid_AspirationAmplitudeTierEditor *********************************/
 
+Thing_implement (KlattGrid_AspirationAmplitudeTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_AspirationAmplitudeTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_AspirationAmplitudeTierEditor KlattGrid_AspirationAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_AspirationAmplitudeTierEditor me = Thing_new (KlattGrid_AspirationAmplitudeTierEditor);
 		const RealTier tier = klattgrid -> phonation -> aspirationAmplitude.get();
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_AspirationAmplitudeTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid aspiration amplitude window not created.");
@@ -148,13 +160,15 @@ autoKlattGrid_AspirationAmplitudeTierEditor KlattGrid_AspirationAmplitudeTierEdi
 
 /************************** KlattGrid_BreathinessAmplitudeTierEditor *********************************/
 
+Thing_implement (KlattGrid_BreathinessAmplitudeTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_BreathinessAmplitudeTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_BreathinessAmplitudeTierEditor KlattGrid_BreathinessAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_BreathinessAmplitudeTierEditor me = Thing_new (KlattGrid_BreathinessAmplitudeTierEditor);
 		const RealTier tier = klattgrid -> phonation -> breathinessAmplitude.get();
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_BreathinessAmplitudeTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid breathiness amplitude window not created.");
@@ -163,13 +177,15 @@ autoKlattGrid_BreathinessAmplitudeTierEditor KlattGrid_BreathinessAmplitudeTierE
 
 /************************** KlattGrid_SpectralTiltTierEditor *********************************/
 
+Thing_implement (KlattGrid_SpectralTiltTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_SpectralTiltTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_SpectralTiltTierEditor KlattGrid_SpectralTiltTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_SpectralTiltTierEditor me = Thing_new (KlattGrid_SpectralTiltTierEditor);
 		const RealTier tier = klattgrid -> phonation -> spectralTilt.get();
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_SpectralTiltTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid spectral tilt window not created.");
@@ -178,13 +194,15 @@ autoKlattGrid_SpectralTiltTierEditor KlattGrid_SpectralTiltTierEditor_create (co
 
 /************************** KlattGrid_FricationBypassTierEditor *********************************/
 
+Thing_implement (KlattGrid_FricationBypassTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_FricationBypassTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_FricationBypassTierEditor KlattGrid_FricationBypassTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_FricationBypassTierEditor me = Thing_new (KlattGrid_FricationBypassTierEditor);
 		const RealTier tier = klattgrid -> frication -> bypass.get();
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_FricationBypassTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid frication bypass window not created.");
@@ -193,13 +211,15 @@ autoKlattGrid_FricationBypassTierEditor KlattGrid_FricationBypassTierEditor_crea
 
 /************************** KlattGrid_FricationAmplitudeTierEditor *********************************/
 
+Thing_implement (KlattGrid_FricationAmplitudeTierArea, KlattGrid_IntensityTierArea, 0);
+
 Thing_implement (KlattGrid_FricationAmplitudeTierEditor, KlattGrid_IntensityTierEditor, 0);
 
 autoKlattGrid_FricationAmplitudeTierEditor KlattGrid_FricationAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_FricationAmplitudeTierEditor me = Thing_new (KlattGrid_FricationAmplitudeTierEditor);
 		const RealTier tier = klattgrid -> frication -> fricationAmplitude.get();
-		KlattGrid_IntensityTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_IntensityTierEditor_init (me.get(), classKlattGrid_FricationAmplitudeTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid frication amplitude window not created.");
@@ -208,13 +228,15 @@ autoKlattGrid_FricationAmplitudeTierEditor KlattGrid_FricationAmplitudeTierEdito
 
 /************************** KlattGrid_OpenPhaseTierEditor *********************************/
 
+Thing_implement (KlattGrid_OpenPhaseTierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_OpenPhaseTierEditor, KlattGrid_RealTierEditor, 0);
 
 autoKlattGrid_OpenPhaseTierEditor KlattGrid_OpenPhaseTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_OpenPhaseTierEditor me = Thing_new (KlattGrid_OpenPhaseTierEditor);
 		const RealTier tier = klattgrid -> phonation -> openPhase.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_OpenPhaseTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid open phase window not created.");
@@ -223,13 +245,15 @@ autoKlattGrid_OpenPhaseTierEditor KlattGrid_OpenPhaseTierEditor_create (conststr
 
 /************************** KlattGrid_CollisionPhaseTierEditor *********************************/
 
+Thing_implement (KlattGrid_CollisionPhaseTierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_CollisionPhaseTierEditor, KlattGrid_RealTierEditor, 0);
 
 autoKlattGrid_CollisionPhaseTierEditor KlattGrid_CollisionPhaseTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_CollisionPhaseTierEditor me = Thing_new (KlattGrid_CollisionPhaseTierEditor);
 		const RealTier tier = klattgrid -> phonation -> collisionPhase.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_CollisionPhaseTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid collision phase window not created.");
@@ -238,13 +262,15 @@ autoKlattGrid_CollisionPhaseTierEditor KlattGrid_CollisionPhaseTierEditor_create
 
 /************************** KlattGrid_Power1TierEditor *********************************/
 
+Thing_implement (KlattGrid_Power1TierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_Power1TierEditor, KlattGrid_RealTierEditor, 0);
 
 autoKlattGrid_Power1TierEditor KlattGrid_Power1TierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_Power1TierEditor me = Thing_new (KlattGrid_Power1TierEditor);
 		const RealTier tier = klattgrid -> phonation -> power1.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_Power1TierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid power1 window not created.");
@@ -253,13 +279,15 @@ autoKlattGrid_Power1TierEditor KlattGrid_Power1TierEditor_create (conststring32
 
 /************************** KlattGrid_Power2TierEditor *********************************/
 
+Thing_implement (KlattGrid_Power2TierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_Power2TierEditor, KlattGrid_RealTierEditor, 0);
 
 autoKlattGrid_Power2TierEditor KlattGrid_Power2TierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_Power2TierEditor me = Thing_new (KlattGrid_Power2TierEditor);
 		const RealTier tier = klattgrid -> phonation -> power2.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_Power2TierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid power2 window not created.");
@@ -268,13 +296,15 @@ autoKlattGrid_Power2TierEditor KlattGrid_Power2TierEditor_create (conststring32
 
 /************************** KlattGrid_FlutterTierEditor *********************************/
 
+Thing_implement (KlattGrid_FlutterTierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_FlutterTierEditor, KlattGrid_RealTierEditor, 0);
 
 autoKlattGrid_FlutterTierEditor KlattGrid_FlutterTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_FlutterTierEditor me = Thing_new (KlattGrid_FlutterTierEditor);
 		const RealTier tier = klattgrid -> phonation -> flutter.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_FlutterTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid flutter window not created.");
@@ -283,13 +313,15 @@ autoKlattGrid_FlutterTierEditor KlattGrid_FlutterTierEditor_create (conststring3
 
 /************************** KlattGrid_DoublePulsingTierEditor *********************************/
 
+Thing_implement (KlattGrid_DoublePulsingTierArea, KlattGrid_RealTierArea, 0);
+
 Thing_implement (KlattGrid_DoublePulsingTierEditor, KlattGrid_RealTierEditor, 0);
 
 autoKlattGrid_DoublePulsingTierEditor KlattGrid_DoublePulsingTierEditor_create (conststring32 title, KlattGrid klattgrid) {
 	try {
 		autoKlattGrid_DoublePulsingTierEditor me = Thing_new (KlattGrid_DoublePulsingTierEditor);
 		const RealTier tier = klattgrid -> phonation -> doublePulsing.get();
-		KlattGrid_RealTierEditor_init (me.get(), title, klattgrid, tier);
+		KlattGrid_RealTierEditor_init (me.get(), classKlattGrid_DoublePulsingTierArea, title, klattgrid, tier);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"KlattGrid double pulsing window not created.");
@@ -304,8 +336,8 @@ static bool FormantGrid_isEmpty (FormantGrid me) {
 	return my formants.size == 0 || my bandwidths.size == 0;
 }
 
-void structKlattGrid_FormantGridEditor :: v_play (double ltmin, double ltmax) {
-	KlattGrid_Editor_defaultPlay (klattgrid, ltmin, ltmax);
+void structKlattGrid_FormantGridEditor :: v_play (double startTime, double endTime) {
+	KlattGrid_Editor_defaultPlay (klattgrid, startTime, endTime);
 }
 
 autoKlattGrid_FormantGridEditor KlattGrid_FormantGridEditor_create (conststring32 title, KlattGrid data, kKlattGridFormantType formantType) {
