@@ -24,32 +24,37 @@
 #include "RealTierEditor.h"
 #include "FormantGridEditor.h"
 
+Thing_define (KlattGrid_RealTierArea, RealTierArea) {
+};
 
 Thing_define (KlattGrid_RealTierEditor, RealTierEditor) {
 	KlattGrid klattgrid;
 
 	void v_createHelpMenuItems (EditorMenu menu)
 		override;
-	void v_play (double tmin, double tmax)
+	void v_play (double startTime, double endTime)
 		override;
 };
 
-void KlattGrid_RealTierEditor_init (KlattGrid_RealTierEditor me, conststring32 title, KlattGrid klattgrid, RealTier data);
+void KlattGrid_RealTierEditor_init (KlattGrid_RealTierEditor me, ClassInfo areaClass, conststring32 title, KlattGrid klattgrid, RealTier data);
 
 
-Thing_define (KlattGrid_OpenPhaseTierEditor, KlattGrid_RealTierEditor) {
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_OpenPhaseTierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	double v_maximumLegalValue ()
+	double v_maximumLegalY ()
 		override { return 1.0; }
-	conststring32 v_quantityText ()
-		override { return U"Open phase (0..1)"; }
 	conststring32 v_rightTickUnits ()
 		override { return U""; }
 	double v_defaultYmin ()
 		override { return 0.0; }
 	double v_defaultYmax ()
 		override { return 1.0; }
+};
+
+Thing_define (KlattGrid_OpenPhaseTierEditor, KlattGrid_RealTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Open phase (0..1)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set open phase range..."; }
 	conststring32 v_defaultYminText ()
@@ -65,19 +70,22 @@ Thing_define (KlattGrid_OpenPhaseTierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_OpenPhaseTierEditor KlattGrid_OpenPhaseTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_CollisionPhaseTierEditor, KlattGrid_RealTierEditor) {
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_CollisionPhaseTierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	double v_maximumLegalValue ()
+	double v_maximumLegalY ()
 		override { return 1.0; }
-	conststring32 v_quantityText ()
-		override { return U"Collision phase (0..1)"; }
 	conststring32 v_rightTickUnits ()
 		override { return U""; }
 	double v_defaultYmin ()
 		override { return 0.0; }
 	double v_defaultYmax ()
 		override { return 0.1; }
+};
+
+Thing_define (KlattGrid_CollisionPhaseTierEditor, KlattGrid_RealTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Collision phase (0..1)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set collision phase range..."; }
 	conststring32 v_defaultYminText ()
@@ -93,17 +101,20 @@ Thing_define (KlattGrid_CollisionPhaseTierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_CollisionPhaseTierEditor KlattGrid_CollisionPhaseTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_Power1TierEditor, KlattGrid_RealTierEditor) {
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_Power1TierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	conststring32 v_quantityText ()
-		override { return U"Power1"; }
 	conststring32 v_rightTickUnits ()
 		override { return U""; }
 	double v_defaultYmin ()
 		override { return 0.0; }
 	double v_defaultYmax ()
 		override { return 4.0; }
+};
+
+Thing_define (KlattGrid_Power1TierEditor, KlattGrid_RealTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Power1"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set power1 range..."; }
 	conststring32 v_defaultYminText ()
@@ -119,17 +130,20 @@ Thing_define (KlattGrid_Power1TierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_Power1TierEditor KlattGrid_Power1TierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_Power2TierEditor, KlattGrid_RealTierEditor) {
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_Power2TierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	conststring32 v_quantityText ()
-		override { return U"Power2"; }
 	conststring32 v_rightTickUnits ()
 		override { return U""; }
 	double v_defaultYmin ()
 		override { return 0.0; }
 	double v_defaultYmax ()
 		override { return 5.0; }
+};
+
+Thing_define (KlattGrid_Power2TierEditor, KlattGrid_RealTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Power2"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set power2 range..."; }
 	conststring32 v_defaultYminText ()
@@ -145,19 +159,22 @@ Thing_define (KlattGrid_Power2TierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_Power2TierEditor KlattGrid_Power2TierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_DoublePulsingTierEditor, KlattGrid_RealTierEditor) {
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_DoublePulsingTierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	double v_maximumLegalValue ()
+	double v_maximumLegalY ()
 		override { return 1.0; }
-	conststring32 v_quantityText ()
-		override { return U"Double pulsing (0..1)"; }
 	conststring32 v_rightTickUnits ()
 		override { return U""; }
 	double v_defaultYmin ()
 		override { return 0.0; }
 	double v_defaultYmax ()
 		override { return 1.0; }
+};
+
+Thing_define (KlattGrid_DoublePulsingTierEditor, KlattGrid_RealTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Double pulsing (0..1)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set double pulsing range..."; }
 	conststring32 v_defaultYminText ()
@@ -173,19 +190,22 @@ Thing_define (KlattGrid_DoublePulsingTierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_DoublePulsingTierEditor KlattGrid_DoublePulsingTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_PitchTierEditor, KlattGrid_RealTierEditor) {
-	void v_createHelpMenuItems (EditorMenu menu)
-		override;
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_PitchTierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	conststring32 v_quantityText ()
-		override { return U"Frequency (Hz)"; }
 	conststring32 v_rightTickUnits ()
 		override { return U" Hz"; }
 	double v_defaultYmin ()
 		override { return 50.0; }
 	double v_defaultYmax ()
 		override { return 600.0; }
+};
+
+Thing_define (KlattGrid_PitchTierEditor, KlattGrid_RealTierEditor) {
+	void v_createHelpMenuItems (EditorMenu menu)
+		override;
+	conststring32 v_quantityText ()
+		override { return U"Frequency (Hz)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set frequency range..."; }
 	conststring32 v_defaultYminText ()
@@ -201,19 +221,22 @@ Thing_define (KlattGrid_PitchTierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_PitchTierEditor KlattGrid_PitchTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_FlutterTierEditor, KlattGrid_RealTierEditor) {
-	double v_minimumLegalValue ()
+Thing_define (KlattGrid_FlutterTierArea, KlattGrid_RealTierArea) {
+	double v_minimumLegalY ()
 		override { return 0.0; }
-	double v_maximumLegalValue ()
+	double v_maximumLegalY ()
 		override { return 1.0; }
-	conststring32 v_quantityText ()
-		override { return U"Flutter (0..1)"; }
 	conststring32 v_rightTickUnits ()
 		override { return U""; }
 	double v_defaultYmin ()
 		override { return 0.0; }
 	double v_defaultYmax ()
 		override { return 1.0; }
+};
+
+Thing_define (KlattGrid_FlutterTierEditor, KlattGrid_RealTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Flutter (0..1)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set flutter range..."; }
 	conststring32 v_defaultYminText ()
@@ -229,17 +252,20 @@ Thing_define (KlattGrid_FlutterTierEditor, KlattGrid_RealTierEditor) {
 autoKlattGrid_FlutterTierEditor KlattGrid_FlutterTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_IntensityTierEditor, KlattGrid_RealTierEditor) {
-	void v_createHelpMenuItems (EditorMenu menu)
-		override;
-	conststring32 v_quantityText ()
-		override { return U"Intensity (dB)"; }
+Thing_define (KlattGrid_IntensityTierArea, KlattGrid_RealTierArea) {
 	conststring32 v_rightTickUnits ()
 		override { return U" dB"; }
 	double v_defaultYmin ()
 		override { return 50.0; }
 	double v_defaultYmax ()
 		override { return 100.0; }
+};
+
+Thing_define (KlattGrid_IntensityTierEditor, KlattGrid_RealTierEditor) {
+	void v_createHelpMenuItems (EditorMenu menu)
+		override;
+	conststring32 v_quantityText ()
+		override { return U"Intensity (dB)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set intensity range..."; }
 	conststring32 v_defaultYminText ()
@@ -252,18 +278,21 @@ Thing_define (KlattGrid_IntensityTierEditor, KlattGrid_RealTierEditor) {
 		override { return U"Maximum intensity (dB)"; }
 };
 
-void KlattGrid_IntensityTierEditor_init (KlattGrid_IntensityTierEditor me, conststring32 title, KlattGrid klattgrid, RealTier tier);
+void KlattGrid_IntensityTierEditor_init (KlattGrid_IntensityTierEditor me, ClassInfo viewClass, conststring32 title, KlattGrid klattgrid, RealTier tier);
 
 
-Thing_define (KlattGrid_DecibelTierEditor, KlattGrid_IntensityTierEditor) {
-	conststring32 v_quantityText ()
-		override { return U"Amplitude (dB)"; }
+Thing_define (KlattGrid_DecibelTierArea, KlattGrid_IntensityTierArea) {
 	conststring32 v_rightTickUnits ()
 		override { return U" dB"; }
 	double v_defaultYmin ()
 		override { return -30.0; }
 	double v_defaultYmax ()
 		override { return 30.0; }
+};
+
+Thing_define (KlattGrid_DecibelTierEditor, KlattGrid_IntensityTierEditor) {
+	conststring32 v_quantityText ()
+		override { return U"Amplitude (dB)"; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set amplitude range..."; }
 	conststring32 v_defaultYminText ()
@@ -279,29 +308,41 @@ Thing_define (KlattGrid_DecibelTierEditor, KlattGrid_IntensityTierEditor) {
 autoKlattGrid_DecibelTierEditor KlattGrid_DecibelTierEditor_create (conststring32 title, KlattGrid klattgrid, RealTier data);
 
 
+Thing_define (KlattGrid_VoicingAmplitudeTierArea, KlattGrid_IntensityTierArea) {
+};
+
 Thing_define (KlattGrid_VoicingAmplitudeTierEditor, KlattGrid_IntensityTierEditor) {
 };
 
 autoKlattGrid_VoicingAmplitudeTierEditor KlattGrid_VoicingAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
+Thing_define (KlattGrid_AspirationAmplitudeTierArea, KlattGrid_IntensityTierArea) {
+};
+
 Thing_define (KlattGrid_AspirationAmplitudeTierEditor, KlattGrid_IntensityTierEditor) {
 };
 
 autoKlattGrid_AspirationAmplitudeTierEditor KlattGrid_AspirationAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
+Thing_define (KlattGrid_BreathinessAmplitudeTierArea, KlattGrid_IntensityTierArea) {
+};
+
 Thing_define (KlattGrid_BreathinessAmplitudeTierEditor, KlattGrid_IntensityTierEditor) {
 };
 
 autoKlattGrid_BreathinessAmplitudeTierEditor KlattGrid_BreathinessAmplitudeTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_SpectralTiltTierEditor, KlattGrid_IntensityTierEditor) {
+Thing_define (KlattGrid_SpectralTiltTierArea, KlattGrid_IntensityTierArea) {
 	double v_defaultYmin ()
 		override { return -50.0; }
 	double v_defaultYmax ()
 		override { return 10.0; }
+};
+
+Thing_define (KlattGrid_SpectralTiltTierEditor, KlattGrid_IntensityTierEditor) {
 	conststring32 v_defaultYminText ()
 		override { return U"-50.0"; }
 	conststring32 v_defaultYmaxText ()
@@ -311,11 +352,14 @@ Thing_define (KlattGrid_SpectralTiltTierEditor, KlattGrid_IntensityTierEditor) {
 autoKlattGrid_SpectralTiltTierEditor KlattGrid_SpectralTiltTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
-Thing_define (KlattGrid_FricationBypassTierEditor, KlattGrid_IntensityTierEditor) {
+Thing_define (KlattGrid_FricationBypassTierArea, KlattGrid_IntensityTierArea) {
 	double v_defaultYmin ()
 		override { return -50.0; }
 	double v_defaultYmax ()
 		override { return 10.0; }
+};
+
+Thing_define (KlattGrid_FricationBypassTierEditor, KlattGrid_IntensityTierEditor) {
 	conststring32 v_defaultYminText ()
 		override { return U"-50.0"; }
 	conststring32 v_defaultYmaxText ()
@@ -325,6 +369,9 @@ Thing_define (KlattGrid_FricationBypassTierEditor, KlattGrid_IntensityTierEditor
 autoKlattGrid_FricationBypassTierEditor KlattGrid_FricationBypassTierEditor_create (conststring32 title, KlattGrid klattgrid);
 
 
+Thing_define (KlattGrid_FricationAmplitudeTierArea, KlattGrid_IntensityTierArea) {
+};
+
 Thing_define (KlattGrid_FricationAmplitudeTierEditor, KlattGrid_IntensityTierEditor) {
 };
 
@@ -334,7 +381,7 @@ autoKlattGrid_FricationAmplitudeTierEditor KlattGrid_FricationAmplitudeTierEdito
 Thing_define (KlattGrid_FormantGridEditor, FormantGridEditor) {
 	KlattGrid klattgrid;
 
-	void v_play (double tmin, double tmax)
+	void v_play (double startTime, double endTime)
 		override;
 	bool v_hasSourceMenu ()
 		override { return false; }
