@@ -2,7 +2,7 @@
 #define _Ltas_extensions_h_
 /* Ltas_extensions.h
  *
- * Copyright (C) 2012-2013 David Weenink
+ * Copyright (C) 2012-2019 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,6 @@
 
 #include "Ltas.h"
 
-void Ltas_fitTiltLine (Ltas me, double fmin, double fmax, bool lnf, int method, double *a, double *b);
+void Ltas_fitTrendLine (Ltas me, double fmin, double fmax, bool lnf, int method, double *a, double *b);
 
 #endif /* _Ltas_extensions_h_ */
