@@ -19,6 +19,8 @@
 #include "OptimalCeilingTierEditor.h"
 #include "EditorM.h"
 
+Thing_implement (OptimalCeilingTierArea, RealTierArea, 0);
+
 Thing_implement (OptimalCeilingTierEditor, RealTierEditor, 0);
 
 static void menu_cb_OptimalCeilingTierHelp (OptimalCeilingTierEditor, EDITOR_ARGS_DIRECT) { Melder_help (U"OptimalCeilingTier"); }
@@ -28,17 +30,17 @@ void structOptimalCeilingTierEditor :: v_createHelpMenuItems (EditorMenu menu) {
 	EditorMenu_addCommand (menu, U"OptimalCeilingTier help", 0, menu_cb_OptimalCeilingTierHelp);
 }
 
-void structOptimalCeilingTierEditor :: v_play (double fromTime, double toTime) {
+void structOptimalCeilingTierEditor :: v_play (double startTime, double endTime) {
 	if (our d_sound.data)
-		Sound_playPart (our d_sound.data, fromTime, toTime, theFunctionEditor_playCallback, this);
+		Sound_playPart (our d_sound.data, startTime, endTime, theFunctionEditor_playCallback, this);
 	//else
-	//	OptimalCeilingTier_playPart (data, fromTime, toTime, false);
+	//	OptimalCeilingTier_playPart (data, startTime, endTime, false);
 }
 
 autoOptimalCeilingTierEditor OptimalCeilingTierEditor_create (conststring32 title, OptimalCeilingTier octier, Sound sound, bool ownSound) {
 	try {
 		autoOptimalCeilingTierEditor me = Thing_new (OptimalCeilingTierEditor);
-		RealTierEditor_init (me.get(), title, (RealTier) octier, sound, ownSound);
+		RealTierEditor_init (me.get(), classOptimalCeilingTierArea, title, octier, sound, ownSound);
 		return me;
 	} catch (MelderError) {
 		Melder_throw (U"OptimalCeilingTier window not created.");
