@@ -45,7 +45,7 @@ void PatternList_normalize (PatternList me, int choice, double pmin, double pmax
  */
 
 void PatternList_draw (PatternList me, Graphics g, integer pattern, double xmin, double xmax,
-	double ymin, double ymax, int garnish);
+	double ymin, double ymax, bool garnish);
 
 autoPatternList Matrix_to_PatternList (Matrix me, integer join);
 
