@@ -100,8 +100,8 @@ double Dissimilarity_getAdditiveConstant (Dissimilarity me) {
 		Melder_require (isdefined (additiveConstant),
 			U"There are no positive dissimilarities.");
 		
-		autoMAT wd = newMATzero (nPoints, nPoints);
-		autoMAT wdsqrt = newMATzero (nPoints, nPoints);
+		autoMAT wd = zero_MAT (nPoints, nPoints);
+		autoMAT wdsqrt = zero_MAT (nPoints, nPoints);
 		/*
 			The matrices D & D1/2 with distances (squared and linear)
 		*/
@@ -113,12 +113,12 @@ double Dissimilarity_getAdditiveConstant (Dissimilarity me) {
 			}
 		}
 
-		MATdoubleCentre_inplace (wdsqrt.get());
-		MATdoubleCentre_inplace (wd.get());
+		doubleCentre_MAT_inout (wdsqrt.get());
+		doubleCentre_MAT_inout (wd.get());
 		/*
 			Calculate the B matrix according to eq. 6
 		*/
-		autoMAT b = newMATzero (nPoints2, nPoints2);
+		autoMAT b = zero_MAT (nPoints2, nPoints2);
 		b.part (1, nPoints, nPoints + 1, nPoints2) <<= 2.0  *  wd.get();
 		b.part (nPoints + 1, nPoints2, 1, nPoints).diagonal() <<= - 1.0;
 		b.part (nPoints + 1, nPoints2, nPoints + 1, nPoints2) <<= -4.0  *  wdsqrt.get();
@@ -136,7 +136,7 @@ double Dissimilarity_getAdditiveConstant (Dissimilarity me) {
 			if (eigenvalues [i] .imag() == 0.0) {
 				++ numberOfRealEigenvalues;
 				if (eigenvalues [i] .real() > largestRealEigenvalue)
-					largestRealEigenvalue = eigenvalues [i] .real();
+					largestRealEigenvalue = eigenvalues [i].real();
 			}
 		}
 		
