@@ -207,32 +207,45 @@ autoSSCPList SSCPList_extractTwoDimensions (SSCPList me, integer d1, integer d2)
 void SSCP_drawTwoDimensionalEllipse_inside (SSCP me, Graphics g, double scale, conststring32 label, double fontSize) {
 	try {
 		constexpr integer nsteps = 100;
-		autoVEC x = newVECraw (nsteps + 1);
-		autoVEC y = newVECraw (nsteps + 1);
+		autoVEC x = raw_VEC (nsteps + 1);
+		autoVEC y = raw_VEC (nsteps + 1);
 		/*
-			Get principal axes and orientation for the ellipse by performing the
-			eigen decomposition of a symmetric 2-by-2 matrix.
-			Principal axes are a and b with eigenvector/orientation (cs, sn).
+			From the eigenvalues and eigenvectors of the symmetrical sscp matrix we
+			can calculate the length and directions of the principal axes of the ellipse.
 		*/
-		double a, b, cs, sn;
-		NUMeigencmp22 (my data [1] [1], my data [1] [2], my data [2] [2], & a, & b, & cs, & sn);
+		double eval1, eval2, cosine, sine;
+		NUMeigencmp22 (my data [1] [1], my data [1] [2], my data [2] [2], & eval1, & eval2, & cosine, & sine);
 		/*
-			1. Take sqrt to get units of 'std_dev'
+			1. Parametrize as standard ellipse with horizontal radius a and vertical radius b and origin at (0,0) as
+				x = a cos(phi)
+				y = b sin(phi)
 		*/
-		const double axisLength_a = scale * sqrt (a) / 2.0;
-		const double axisLength_b = scale * sqrt (b) / 2.0;
-		x [nsteps + 1] = x [1] = my centroid [1] + cs * axisLength_a;
-		y [nsteps + 1] = y [1] = my centroid [2] + sn * axisLength_a; // axisLength_a is no mistake!
+		const double a = scale * sqrt (eval1) / 2.0;
+		const double b = scale * sqrt (eval2) / 2.0;
 		const double angle_inc = NUM2pi / nsteps;
-		double angle = 0.0;
-		for (integer i = 2; i <= nsteps; i ++, angle += angle_inc) {
-			const double xc = axisLength_a * cos (angle);
-			const double yc = axisLength_b * sin (angle);
-			const double xt = xc * cs - yc * sn;
-			y [i] = my centroid [2] + xc * sn + yc * cs;
-			x [i] = my centroid [1] + xt;
+		for (integer i = 1; i <= nsteps + 1; i ++) {
+			const double phi = (i - 1) * angle_inc;
+			x [i] = a * cos (phi);
+			y [i] = b * sin (phi);
 		}
+		/*
+			2. Rotate x axis to the eigenvector 1 (cosine, sine)
+			|x'|   | cosine -sine |   |x|
+			|  | = |              | * | |
+			|y'|   | sine  cosine |   |y|
+		*/
+		for (integer i = 1; i <= nsteps + 1; i ++) {
+			double xp =  cosine * x [i] -   sine * y [i];			
+			y [i]     =    sine * x [i] + cosine * y[i];
+			x [i] = xp;
+		}
+		/*
+			3. Translate to the centroid
+		*/
+		x.get()  +=  my centroid [1];
+		y.get()  +=  my centroid [2];
 		Graphics_polyline (g, nsteps + 1, & x [1], & y [1]);
+		
 		if (label && fontSize > 0.0) {
 			const double oldFontSize = Graphics_inqFontSize (g);
 			Graphics_setFontSize (g, fontSize);
@@ -282,7 +295,7 @@ autoSSCP SSCP_toTwoDimensions (SSCP me, constVECVU const& v1, constVECVU const&
 void SSCP_init (SSCP me, integer dimension, kSSCPstorage storage) {
 	const integer numberOfRows = storage == kSSCPstorage::DIAGONAL ? 1 : dimension;
 	TableOfReal_init (me, numberOfRows, dimension);
-	my centroid = newVECzero (dimension);
+	my centroid = zero_VEC (dimension);
 }
 
 autoSSCP SSCP_create (integer dimension) {
@@ -407,17 +420,17 @@ autoSSCP TableOfReal_to_SSCP (TableOfReal me, integer rowb, integer rowe, intege
 			U"All the table's elements should be defined.");
 		fixAndCheckRowRange (& rowb, & rowe, my data.get(), 1);
 		fixAndCheckColumnRange (& colb, & cole, my data.get(), 1);
-		autoMAT part = newMATpart (my data.get(), rowb, rowe, colb, cole);
+		autoMAT part = part_MAT (my data.get(), rowb, rowe, colb, cole);
 		if (part.nrow < part.ncol)
 			Melder_warning (U"The selected number of rows (", part.nrow,
 				U") is less than the selected number of columns (", part.ncol,
 				U").\nThe SSCP will not have full dimensionality. This may be a problem in later analysis steps."
 			);
 		autoSSCP thee = SSCP_create (part.ncol);
-		VECcolumnMeans (thy centroid.get(), part.get());
+		columnMeans_VEC_out (thy centroid.get(), part.get());
 		part.all()  -=  thy centroid.all();
 		SSCP_setNumberOfObservations (thee.get(), part.nrow);
-		MATmtm (thy data.get(), part.get());   // sum of squares and cross products = T'T
+		mtm_MAT_out (thy data.get(), part.get());   // sum of squares and cross products = T'T
 		for (integer j = 1; j <= part.ncol; j ++) {
 			const conststring32 label = my columnLabels [colb - 1 + j].get();
 			TableOfReal_setColumnLabel (thee.get(), j, label);
@@ -438,21 +451,21 @@ autoSSCP TableOfReal_to_SSCP_rowWeights (TableOfReal me, integer rowb, integer r
 		if (weightColumnNumber != 0)
 			Melder_require (weightColumnNumber < colb || weightColumnNumber > cole,
 				U"The weight columns must be outside the selected block.");
-		autoMAT part = newMATpart (my data.get(), rowb, rowe, colb, cole);
+		autoMAT part = part_MAT (my data.get(), rowb, rowe, colb, cole);
 		if (part.nrow < part.ncol)
 			Melder_warning (U"The selected number of data points (", part.nrow,
 				U") is less than the selected number of variables (", part.ncol,
 				U").\nThe SSCP will not have full dimensionality. This may be a problem in later analysis steps."
 			);
 		autoSSCP thee = SSCP_create (part.ncol);
-		VECcolumnMeans (thy centroid.get(), part.get());
+		columnMeans_VEC_out (thy centroid.get(), part.get());
 		part.all()  -=  thy centroid.all();
 		SSCP_setNumberOfObservations (thee.get(), part.nrow);
 		if (weightColumnNumber != 0) {
-			autoVEC rowWeights = newVECcolumn (my data.horizontalBand (rowb, rowe), weightColumnNumber);
+			autoVEC rowWeights = column_VEC (my data.horizontalBand (rowb, rowe), weightColumnNumber);
 			MATmtm_weighRows (thy data.get(), part.get(), rowWeights.get());
 		} else
-			MATmtm (thy data.get(), part.get());   // sum of squares and cross products = T'T
+			mtm_MAT_out (thy data.get(), part.get());   // sum of squares and cross products = T'T
 		for (integer j = 1; j <= part.ncol; j ++) {
 			const conststring32 label = my columnLabels [colb - 1 + j].get();
 			TableOfReal_setColumnLabel (thee.get(), j, label);
@@ -538,10 +551,10 @@ autoPCA SSCP_to_PCA (SSCP me) {
 		Melder_assert (my data.ncol == my numberOfColumns);
 		autoMAT mat;
 		if (my numberOfRows == 1) {
-			mat = newMATzero (my numberOfColumns, my numberOfColumns);
+			mat = zero_MAT (my numberOfColumns, my numberOfColumns);
 			mat.diagonal() <<= my data.row (1); // 1xn matrix -> nxn
 		} else if (my data.nrow == my numberOfColumns && my data.ncol == my numberOfColumns)
-			mat = newMATcopy (my data.get());
+			mat = copy_MAT (my data.get());
 		else
 			Melder_throw (me, U": the SSCP has the wrong dimensions.");
 		autoPCA thee = PCA_create (my numberOfColumns, my numberOfColumns);
@@ -756,7 +769,7 @@ void SSCP_expand (SSCP me) {
 		return;
 
 	if (NUMisEmpty (my expansion.get()))
-		my expansion = newMATzero (my numberOfColumns, my numberOfColumns);
+		my expansion = zero_MAT (my numberOfColumns, my numberOfColumns);
 	for (integer ir = 1; ir <= my numberOfColumns; ir ++)
 		for (integer ic = ir; ic <= my numberOfColumns; ic ++) {
 			const integer dij = integer_abs (ir - ic);
@@ -781,7 +794,7 @@ void SSCP_unExpand (SSCP me) {
 
 void SSCP_expandLowerCholeskyInverse (SSCP me) {
 	if (NUMisEmpty (my lowerCholeskyInverse.get()))
-		my lowerCholeskyInverse = newMATraw (my numberOfColumns, my numberOfColumns);
+		my lowerCholeskyInverse = raw_MAT (my numberOfColumns, my numberOfColumns);
 	if (my numberOfRows == 1) {   // diagonal
 		my lnd = 0.0;
 		for (integer j = 1; j <= my numberOfColumns; j ++) {
