@@ -49,6 +49,9 @@ autoSound Sound_readFromDialogicADPCMFile (MelderFile file, double sampleRate);
 /*
 */
 
+autoSound Sound_readFromOggVorbisFile (MelderFile file);
+autoSound Sound_readFromOggOpusFile (MelderFile file);
+
 void Sound_writeToRawFile (Sound me, MelderFile file, const char *format, bool littleEndian, int nBitsCoding, bool unSigned);
 
 void Sound_into_Sound (Sound me, Sound to, double startTime);
@@ -127,7 +130,7 @@ void Sound_scale_dB (Sound me, double level_dB);
 	where extremum is the maximum of the absolute values the signal values.
 */
 
-void Sound_fade (Sound me, int channel, double t, double fadeTime, int inout, bool fadeGlobal);
+void Sound_fade (Sound me, int channel, double t, double fadeTime, bool fadeOut, bool fadeGlobal);
 /* if inout <= 0 fade in with (1-cos)/2  else fade out with (1+cos)/2
 	channel = 0 (all), 1 (left), 2 (right).
 */
