@@ -33,7 +33,7 @@
 static void spec_enhance_SHS (VEC const & a) {
 	Melder_assert (a.size >= 2);
 
-	autoINTVEC posmax = newINTVECraw ((a.size + 1) / 2);
+	autoINTVEC posmax = raw_INTVEC ((a.size + 1) / 2);
 	integer nmax = 0;
 	if (a [1] > a [2])
 		posmax [++ nmax] = 1;
@@ -114,12 +114,12 @@ autoPitch Sound_to_Pitch_shs (Sound me, double timeStep, double minimumPitch, do
 		autoSound analysisframe = Sound_createSimple (1, frameDuration, newSamplingFrequency);
 		autoSound hamming = Sound_createHamming (frameDuration, newSamplingFrequency);
 		autoPitch thee = Pitch_create (my xmin, my xmax, numberOfFrames, timeStep, firstTime, ceiling, maxnCandidates);
-		autoVEC cc = newVECzero (numberOfFrames);
-		autoVEC specAmp = newVECraw (nfft2);
-		autoVEC fl2 = newVECraw (nfft2);
-		autoVEC yv2 = newVECraw (nfft2);
-		autoVEC arctg = newVECraw (numberOfFrequencyPoints);
-		autoVEC al2 = newVECraw (numberOfFrequencyPoints);
+		autoVEC cc = zero_VEC (numberOfFrames);
+		autoVEC specAmp = raw_VEC (nfft2);
+		autoVEC fl2 = raw_VEC (nfft2);
+		autoVEC yv2 = raw_VEC (nfft2);
+		autoVEC arctg = raw_VEC (numberOfFrequencyPoints);
+		autoVEC al2 = raw_VEC (numberOfFrequencyPoints);
 
 		Melder_assert (fftframe -> nx >= numberOfSamples);
 		Melder_assert (hamming -> nx == numberOfSamples);
@@ -196,7 +196,7 @@ autoPitch Sound_to_Pitch_shs (Sound me, double timeStep, double minimumPitch, do
 				The subharmonic summation. Shift spectra in octaves and sum.
 			*/
 			Pitch_Frame_init (pitchFrame, maxnCandidates);
-			autoVEC sumspec = newVECzero (numberOfFrequencyPoints);
+			autoVEC sumspec = zero_VEC (numberOfFrequencyPoints);
 			pitchFrame -> candidates. resize (pitchFrame -> nCandidates = 0);   // !!!!!
 
 			double hm = 1.0;
