@@ -64,19 +64,19 @@ autoEspeakVoice EspeakVoice_create () {
 		autoEspeakVoice me = Thing_new (EspeakVoice);
 		my numberOfFormants = 9; // equals N_PEAKS 
 		my numberOfKlattParameters = 8;
-		my klattv = newINTVECzero (my numberOfKlattParameters);
-		my freq = newINTVECzero (my numberOfFormants);
-		my height = newINTVECzero (my numberOfFormants);	// 100% = 256
-		my width = newINTVECzero (my numberOfFormants);		// 100% = 256
-		my freqadd = newINTVECzero (my numberOfFormants);	// Hz
+		my klattv = zero_INTVEC (my numberOfKlattParameters);
+		my freq = zero_INTVEC (my numberOfFormants);
+		my height = zero_INTVEC (my numberOfFormants);	// 100% = 256
+		my width = zero_INTVEC (my numberOfFormants);		// 100% = 256
+		my freqadd = zero_INTVEC (my numberOfFormants);	// Hz
 
 		// copies without temporary adjustments from embedded commands
-		my freq2 = newINTVECzero (my numberOfFormants);		// 100% = 256
-		my height2 = newINTVECzero (my numberOfFormants);	// 100% = 256
-		my width2 = newINTVECzero (my numberOfFormants);	// 100% = 256
+		my freq2 = zero_INTVEC (my numberOfFormants);		// 100% = 256
+		my height2 = zero_INTVEC (my numberOfFormants);	// 100% = 256
+		my width2 = zero_INTVEC (my numberOfFormants);	// 100% = 256
 
-		my breath = newINTVECzero (my numberOfFormants);	// amount of breath for each formant. breath[0] indicates whether any are set.
-		my breathw = newINTVECzero (my numberOfFormants);	// width of each breath formant
+		my breath = zero_INTVEC (my numberOfFormants);	// amount of breath for each formant. breath[0] indicates whether any are set.
+		my breathw = zero_INTVEC (my numberOfFormants);	// width of each breath formant
 		my numberOfToneAdjusts = 1000; // equals N_TONE_ADJUST in voice.h
 		my tone_adjust = newvectorzero<unsigned char> (my numberOfToneAdjusts);
 		EspeakVoice_setDefaults (me.get());
@@ -601,8 +601,8 @@ static autoTextGrid Table_to_TextGrid (Table me, conststring32 text, double xmin
 	}
 }
 
-static void espeakdata_SetVoiceByName (conststring32 languageName, conststring32 voiceName)
-{
+#if 0
+static void espeakdata_SetVoiceByName (conststring32 languageName, conststring32 voiceName) {
 	espeak_VOICE voice_selector;
 
 	memset (& voice_selector, 0, sizeof voice_selector);
@@ -614,6 +614,7 @@ static void espeakdata_SetVoiceByName (conststring32 languageName, conststring32
 		SetVoiceStack (& voice_selector, Melder_peek32to8 (voiceName));
 	}
 }
+#endif
 
 autoSound SpeechSynthesizer_to_Sound (SpeechSynthesizer me, conststring32 text, autoTextGrid *tg, autoTable *events) {
 	try {
