@@ -44,19 +44,19 @@ static void IntervalTier_checkRange (IntervalTier me, integer startInterval, int
 		U"The specified interval range end number (", endinterval, U") exceeds the number of intervals (", my intervals.size, U") in this tier.");
 }
 
-autoSound SpeechSynthesizer_TextInterval_to_Sound (SpeechSynthesizer me, TextInterval thee, autoTextGrid *p_tg)
+autoSound SpeechSynthesizer_TextInterval_to_Sound (SpeechSynthesizer me, TextInterval thee, autoTextGrid *out_textgrid)
 {
 	try {
-		Melder_require (thy text && thy text[0] != U'\0',
+		Melder_require (thy text && thy text [0] != U'\0',
 			U"TextInterval should not be empty.");
-		autoSound him = SpeechSynthesizer_to_Sound (me, thy text.get(), p_tg, nullptr);
+		autoSound him = SpeechSynthesizer_to_Sound (me, thy text.get(), out_textgrid, nullptr);
 		return him;
 	} catch (MelderError) {
 		Melder_throw (U"Sound not created from TextInterval.");
 	}
 }
 
-autoSound SpeechSynthesizer_TextGrid_to_Sound (SpeechSynthesizer me, TextGrid thee, integer tierNumber, integer iinterval, autoTextGrid *p_tg) {
+autoSound SpeechSynthesizer_TextGrid_to_Sound (SpeechSynthesizer me, TextGrid thee, integer tierNumber, integer iinterval, autoTextGrid *out_textgrid) {
 	try {
 		TextGrid_checkSpecifiedTierNumberWithinRange (thee, tierNumber);
 		const IntervalTier intervalTier = (IntervalTier) thy tiers->at [tierNumber];
@@ -64,7 +64,7 @@ autoSound SpeechSynthesizer_TextGrid_to_Sound (SpeechSynthesizer me, TextGrid th
 			U"Tier ", tierNumber, U" is not an interval tier.");
 		Melder_require (iinterval > 0 && iinterval <= intervalTier -> intervals.size, 
 			U"Interval ", iinterval, U" does not exist on tier ", tierNumber, U".");
-		return SpeechSynthesizer_TextInterval_to_Sound (me, intervalTier -> intervals.at [iinterval], p_tg);
+		return SpeechSynthesizer_TextInterval_to_Sound (me, intervalTier -> intervals.at [iinterval], out_textgrid);
 	} catch (MelderError) {
 		Melder_throw (U"Sound not created from textGrid.");
 	}
@@ -184,7 +184,7 @@ autoIntervalTier IntervalTier_IntervalTier_cutPartsMatchingLabel (IntervalTier m
     try {
         Melder_require (my xmin == thy xmin && my xmax != thy xmax,
             U"Domains should be identical.");
-        autoVEC durations = newVECraw (my intervals.size);
+        autoVEC durations = raw_VEC (my intervals.size);
         for (integer i = 1; i <= my intervals.size; i ++) {
             const TextInterval ti = my intervals.at [i];
             durations [i] = ti -> xmax - ti -> xmin;
@@ -291,7 +291,7 @@ autoTextGrid TextGrid_IntervalTier_cutPartsMatchingLabel (TextGrid me, IntervalT
 // The resulting IntervalTier has thy xmin as starting time and thy xmax as end time
 autoIntervalTier IntervalTiers_patch_noBoundaries (IntervalTier me, IntervalTier thee, conststring32 patchLabel, double precision) {
     try {
-		autoVEC durations = newVECzero (my intervals.size + 1);
+		autoVEC durations = zero_VEC (my intervals.size + 1);
 		for (integer i = 1; i <= my intervals.size; i ++) {
 			const TextInterval myti = my intervals.at [i];
 			durations [i] = myti -> xmax - myti -> xmin;
@@ -481,7 +481,7 @@ autoTextGrid SpeechSynthesizer_Sound_TextInterval_align (SpeechSynthesizer me, S
 		Melder_require (fabs (1.0 / thy dx - my d_samplingFrequency) < 1e-9, 
 			U"The sampling frequencies of the SpeechSynthesizer and the Sound should be equal.");
 
-		autoSTRVEC tokens = newSTRVECtokenize (his text.get());
+		autoSTRVEC tokens = splitByWhitespace_STRVEC (his text.get());
 		const integer numberOfTokens = tokens.size;
 		Melder_require (numberOfTokens > 0,
 			U"The interval should contain text.");
@@ -708,8 +708,8 @@ autoTable IntervalTiers_to_Table_textAlignmentment (IntervalTier target, Interva
 	try {
 		const integer numberOfTargetIntervals = target -> intervals.size;
 		const integer numberOfSourceIntervals = source -> intervals.size;
-		autoINTVEC targetOrigin = newINTVECzero (numberOfTargetIntervals);
-		autoINTVEC sourceOrigin = newINTVECzero (numberOfSourceIntervals);
+		autoINTVEC targetOrigin = zero_INTVEC (numberOfTargetIntervals);
+		autoINTVEC sourceOrigin = zero_INTVEC (numberOfSourceIntervals);
 		autoStrings targets = IntervalTier_to_Strings_withOriginData (target, targetOrigin.get());
 		autoStrings sources = IntervalTier_to_Strings_withOriginData (source, sourceOrigin.get());
 		autoEditDistanceTable edit = EditDistanceTable_create (targets.get(), sources.get());
