@@ -158,7 +158,7 @@ static autoPitchTier PitchTier_createAsModifiedPart (PitchTier me, double tmin,
 		const integer numberOfPitches = items -> numberOfStrings;
 		Melder_require (times.size == numberOfPitches,
 			U"The number of items in the times and the pitches string have to be equal.");
-		autoVEC pitchesraw = newVECraw (numberOfPitches);
+		autoVEC pitchesraw = raw_VEC (numberOfPitches);
 		for (integer i = 1; i <= numberOfPitches; i ++) {
 			const conststring32 token = items -> strings [i].get();
 			if (pitch_as == PITCH_VALUE_AS_MUSIC_NOTE)
@@ -169,7 +169,7 @@ static autoPitchTier PitchTier_createAsModifiedPart (PitchTier me, double tmin,
 		/*
 			Now we have the real times and we can sort them tohether with the pitches
 		*/
-		autoVEC pitches = newVECcopy (pitchesraw.get());
+		autoVEC pitches = copy_VEC (pitchesraw.get());
 		NUMsortTogether (times.get(), pitches.get());
 		double pitchAnchor, pitch;
 		for (integer i = 1; i <= times.size; i ++) {
@@ -271,6 +271,7 @@ autoPitchTier IntervalTier_PitchTier_to_PitchTier (IntervalTier me, PitchTier th
 	}
 }
 
+#if 0
 static autoPitchTier TextGrid_PitchTier_to_PitchTier (TextGrid me, PitchTier thee, integer tierNumber,
 	conststring32 times_string, int time_offset, conststring32 pitches_string, int pitch_unit, int pitch_as, int pitchAnchor_status, kMelder_string which, conststring32 criterion) {
 	try {
@@ -280,6 +281,7 @@ static autoPitchTier TextGrid_PitchTier_to_PitchTier (TextGrid me, PitchTier the
 		Melder_throw (me, U": cannot create PitchTier.");
 	}
 }
+#endif
 
 /* 
 	We specify pitches as tone levels (1 - numberOfToneLevels). These levels are relative to the pitch range of a speaker.
