@@ -30,7 +30,6 @@
  djmw 20071202 Melder_warning<n>
 */
 
-#include <ctype.h>
 #include "TextGrid_extensions.h"
 #include "NUM2.h"
 
@@ -158,12 +157,12 @@ autoDaata TextGrid_TIMITLabelFileRecognizer (integer nread, const char *header,
 	char hkruis[3] = "h#", label1[512], label2[512];
 	int length;
 	bool phnFile = false;
-	integer it[5];
-	if (nread < 12 || sscanf (header, "%ld%ld%511s%n\n", &it[1], &it[2], label1, & length) != 3 ||
-		it[1] < 0 || it[2] <= it[1] || sscanf (& header[length], "%ld%ld%511s\n", &it[3], &it[4], label2) != 3 ||
-		it[4] <= it[3]) {
+	long_not_integer it [5]; // because of %ld in sscanf we need an explicit long
+	if (nread < 12 || sscanf (header, "%ld%ld%511s%n\n", & it [1], & it [2], label1, & length) != 3 ||
+		it [1] < 0 || it [2] <= it [1] || sscanf (& header[length], "%ld%ld%511s\n", & it [3], & it [4], label2) != 3 ||
+		it [4] <= it [3]) {
 		/*
-			20120512 djmw removed the extra "it[3] < it[2]" check, because otherwise train/dr7/mdlm0/si1864.wrd cannot be read
+			20120512 djmw removed the extra "it [3] < it [2]" check, because otherwise train/dr7/mdlm0/si1864.wrd cannot be read
 		*/
 		return autoDaata ();
 	}
@@ -225,9 +224,9 @@ autoTextGrid TextGrid_readFromTIMITLabelFile (MelderFile file, bool phnFile) {
 		integer linesRead = 0;
 		char line[200], label[200];
 		while (fgets (line, 199, f)) {
-			integer it1, it2;
+			long_not_integer it1, it2; // because of %ld in sscanf we need an explicit long
 			linesRead++;
-			Melder_require (sscanf (line, "%ld%ld%199s", &it1, &it2, label) == 3,
+			Melder_require (sscanf (line, "%ld%ld%199s", & it1, & it2, label) == 3,
 				U"Incorrect number of items.");
 			Melder_require (it1 >= 0 && it1 < it2,
 				U"Incorrect time at line ", linesRead);
@@ -606,7 +605,8 @@ void IntervalTier_changeLabels (IntervalTier me, integer from, integer to,
 			labels [i - offset] = interval -> text.get();   // shallow copy
 		}
 		autoSTRVEC newLabels = string32vector_searchAndReplace (
-			constSTRVEC (labels.asArgumentToFunctionThatExpectsOneBasedArray(), nlabels),
+			constSTRVEC (& labels [1], nlabels),
+			//labels.get(),
 			search, replace, 0, nmatches, nstringmatches, use_regexp
 		);
 		for (integer i = from; i <= to; i ++) {
@@ -636,8 +636,9 @@ void TextTier_changeLabels (TextTier me, integer from, integer to,
 			TextPoint point = my points.at [i];
 			marks [i - offset] = point -> mark.get();   // reference copy
 		}
-		autoSTRVEC newMarks = string32vector_searchAndReplace (constSTRVEC (marks.asArgumentToFunctionThatExpectsOneBasedArray(), nmarks),
-			search, replace, 0, nmatches, nstringmatches, use_regexp);
+		autoSTRVEC newMarks = string32vector_searchAndReplace (
+				constSTRVEC (& marks [1], nmarks),
+				search, replace, 0, nmatches, nstringmatches, use_regexp);
 		for (integer i = from; i <= to; i ++) {
 			TextPoint point = my points.at [i];
 			point -> mark = newMarks [i - offset].move();
