@@ -41,9 +41,8 @@ Thing_define (Trajectory, Function) {
 #include "VowelEditor_enums.h"
 
 Thing_define (VowelEditor, Editor) {
-	int shiftKeyPressed;
 	autoGraphics graphics;   // the drawing
-	short width, height;  // size of drawing area in pixels
+	int width, height;  // size of drawing area in pixels
 	autoTable marks;   // Vowel, F1, F2, Colour
 	autoTrajectory trajectory;
 	autoVEC extraFrequencyBandwidthPairs;
