@@ -76,9 +76,9 @@ FORM (NEW_EEG_to_EEG_bss, U"EEG: To EEG (bss)", U"EEG: To EEG (bss)...") {
 	LABEL (U"To supply rising or falling ranges, use e.g. 2:6 or 5:3.")
 	LABEL (U"Pre-whitening parameters")
 	OPTIONMENUx (whiteningMethod, U"Whitening method", 1, 0)
-		OPTION (U"No whitening")
-		OPTION (U"Covariance")
-		OPTION (U"Correlation")
+		OPTION (U"no whitening")
+		OPTION (U"covariance")
+		OPTION (U"correlation")
 	LABEL (U"Iteration parameters")
 	NATURAL (maximumNumberOfIterations, U"Maximum number of iterations", U"100")
 	POSITIVE (tolerance, U"Tolerance", U"0.001")
