@@ -20,7 +20,7 @@
 #include "config.h"
 
 #include <ctype.h>
-#include <stdbool.h>
+//#include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
