@@ -2,7 +2,7 @@
 #define _DurationTier_h_
 /* DurationTier.h
  *
- * Copyright (C) 1992-2011,2015 Paul Boersma
+ * Copyright (C) 1992-2005,2007,2010-2012,2015,2016,2018,2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ Thing_define (DurationTier, RealTier) {
 autoDurationTier DurationTier_create (double tmin, double tmax);
 
 void DurationTier_draw (DurationTier me, Graphics g, double tmin, double tmax,
-	double ymin, double ymax, conststring32 method, int garnish);
+	double ymin, double ymax, conststring32 method, bool garnish);
 
 autoDurationTier PointProcess_upto_DurationTier (PointProcess me);
 
