@@ -2,7 +2,7 @@
 #define _FormantGridEditor_h_
 /* FormantGridEditor.h
  *
- * Copyright (C) 2008-2011,2012,2013,2015,2017 Paul Boersma & David Weenink
+ * Copyright (C) 2008-2018,2020 Paul Boersma & David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,20 +20,25 @@
 
 #include "FunctionEditor.h"
 #include "FormantGrid.h"
+#include "RealTierArea.h"
+
+Thing_define (FormantGridArea, RealTierArea) {
+};
 
 Thing_define (FormantGridEditor, FunctionEditor) {
+	autoFormantGridArea formantGridArea;
+
 	bool editingBandwidths;
 	GuiMenuItem d_bandwidthsToggle;
 	integer selectedFormant;
-	double ycursor;
 
 	void v_createMenus ()
 		override;
 	void v_draw ()
 		override;
-	bool v_click (double xWC, double yWC, bool shiftKeyPressed)
+	bool v_mouseInWideDataView (GuiDrawingArea_MouseEvent event, double x_world, double globalY_fraction)
 		override;
-	void v_play (double tmin, double tmax)
+	void v_play (double startTime, double endTime)
 		override;
 
 	virtual bool v_hasSourceMenu () { return true; }
