@@ -2,7 +2,7 @@
 #define _FunctionEditor_h_
 /* FunctionEditor.h
  *
- * Copyright (C) 1992-2019 Paul Boersma
+ * Copyright (C) 1992-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,23 +28,97 @@ struct FunctionEditor_picture {
 };
 
 Thing_define (FunctionEditor, Editor) {
-	/* Subclass may change the following attributes, */
-	/* but has to respect the invariants, */
-	/* and has to call FunctionEditor_marksChanged () */
-	/* immediately after making the changes. */
+	/*
+		Inherited attributes:
+			data: must be a Function.
+	*/
+	Function & function() { return * reinterpret_cast <Function *> (& our data); }
+
+	/*
+		Subclasses may change the following attributes,
+		but have to respect the invariants,
+		and have to call FunctionEditor_marksChanged ()
+		immediately after making those changes.
+		Invariants:
+			tmin <= startWindow < endWindow <= tmax;
+			tmin <= startSelection <= endSelection <= tmax;
+	*/
 	double tmin, tmax, startWindow, endWindow;
 	double startSelection, endSelection;   // markers
-		/* These attributes are all expressed in seconds. Invariants: */
-		/*    tmin <= startWindow < endWindow <= tmax; */
-		/*    tmin <= (startSelection, endSelection) <= tmax; */
 
 	autoGraphics graphics;   // used in the 'draw' method
-	int functionViewerLeft, functionViewerRight;   // size of drawing areas in pixels
-	int selectionViewerLeft, selectionViewerRight;   // size of drawing areas in pixels
-	int height;   // size of drawing areas in pixels
+	void draw ();
+	/*
+		The Normalized Device cordinates are in "pixelettes", which are a bit smaller than pixels.
+		The purpose of this is optimal look and feel.
+		The extent to which a pixelette is smaller than a pixel depends on the size of the drawing area:
+		for smaller drawing areas, texts are a bit more cramped in their rectangles
+		than for larger drawing areas.
+	*/
+	double width_pxlt, height_pxlt;   // size of drawing area in pixelettes
+private:
+	double functionViewerLeft, functionViewerRight;   // location of function viewer in pixelettes
+	double selectionViewerLeft, selectionViewerRight;   // location of selection viewer in pixelettes
+public:
+	void updateGeometry (int width_pixels, int height_pixels) {
+		Graphics_setWsViewport (our graphics.get(), 0.0, width_pixels, 0.0, height_pixels);
+		our width_pxlt = width_pixels + 21;   // the +21 means that the horizontal margin becomes a tiny bit larger when the window grows
+		our height_pxlt = height_pixels + 111;   // the +111 means that the vertical margins become a bit larger when the window grows
+		Graphics_setWsWindow (our graphics.get(), 0.0, our width_pxlt, 0.0, our height_pxlt);
+		//my viewAllAsPixelettes ();
+		/*
+			Put the function viewer at the left and the selection viewer at the right.
+		*/
+		our functionViewerLeft = 0;
+		our functionViewerRight = ( our p_showSelectionViewer ? our width_pxlt * (2.0/3.0) : our width_pxlt );
+		our selectionViewerLeft = our functionViewerRight;
+		our selectionViewerRight = our width_pxlt;
+	}
+	bool isInSelectionViewer (double x_pxlt) const {
+		return x_pxlt > our selectionViewerLeft;
+	}
+	void viewAllAsPixelettes () const {
+		Graphics_setViewport (our graphics.get(), 0.0, our width_pxlt, 0.0, our height_pxlt);
+		Graphics_setWindow (our graphics.get(), 0.0, our width_pxlt, 0.0, our height_pxlt);
+	}
+	void viewFunctionViewerAsPixelettes () const {
+		Graphics_setViewport (our graphics.get(), our functionViewerLeft, our functionViewerRight, 0.0, our height_pxlt);
+		Graphics_setWindow (our graphics.get(), our functionViewerLeft, our functionViewerRight, 0.0, our height_pxlt);
+	}
+	void viewSelectionViewerAsPixelettes () const {
+		Graphics_setViewport (our graphics.get(), our selectionViewerLeft, our selectionViewerRight, 0.0, our height_pxlt);
+		Graphics_setWindow (our graphics.get(), our selectionViewerLeft, our selectionViewerRight, 0.0, our height_pxlt);
+	}
+	constexpr static double space = 30.0;
+	constexpr static double MARGIN = 107.0;
+	constexpr static double BOTTOM_MARGIN = 2.0;
+	constexpr static double TOP_MARGIN = 3.0;
+	double dataLeft_pxlt () const { return our functionViewerLeft + our MARGIN; }
+	double dataRight_pxlt () const { return our functionViewerRight - our MARGIN; }
+	double dataBottom_pxlt () const { return our BOTTOM_MARGIN + our space * 3; }
+	double dataTop_pxlt () const { return our height_pxlt - (TOP_MARGIN + space); }
+	void viewDataAsWorldByFraction () const {
+		Graphics_setViewport (our graphics.get(), dataLeft_pxlt(), dataRight_pxlt(), dataBottom_pxlt(), dataTop_pxlt());
+		Graphics_setWindow (our graphics.get(), our startWindow, our endWindow, 0.0, 1.0);
+	}
+	void viewTallDataAsWorldByFraction () const {
+		Graphics_setViewport (our graphics.get(), our dataLeft_pxlt(), our dataRight_pxlt(), 0.0, our height_pxlt);
+		Graphics_setWindow (our graphics.get(), our startWindow, our endWindow, 0.0, our height_pxlt);
+	}
+	constexpr static double SELECTION_VIEWER_MARGIN = 0.0;
+	void viewInnerSelectionViewerAsFractionByFraction () const {
+		Graphics_setViewport (our graphics.get(), our selectionViewerLeft + our MARGIN, our selectionViewerRight - our MARGIN,
+				our BOTTOM_MARGIN + our space * 3, our height_pxlt - (our TOP_MARGIN + our space));
+		Graphics_setViewport (our graphics.get(),
+			our selectionViewerLeft + our SELECTION_VIEWER_MARGIN, our selectionViewerRight - our SELECTION_VIEWER_MARGIN,
+			our SELECTION_VIEWER_MARGIN, our height_pxlt - SELECTION_VIEWER_MARGIN
+		);
+		Graphics_setWindow (our graphics.get(), 0.0, 1.0, 0.0, 1.0);
+	}
+
 	GuiText text;   // optional text at top
-	int shiftKeyPressed;   // information for the 'play' method
-	bool playingCursor, playingSelection;   // information for end of play
+	bool clickWasModifiedByShiftKey;   // information for drag-and-drop and for start of play
+	bool duringPlay;
 	struct FunctionEditor_picture picture;
 
 	/* Private: */
@@ -76,11 +150,8 @@ Thing_define (FunctionEditor, Editor) {
 		override;
 
 	virtual void v_draw () { }
-		/*
-		 * Message: "draw your part of the data between startWindow and endWindow."
-		 */
 	virtual void v_drawSelectionViewer () { }
-	virtual void v_drawRealTimeSelectionViewer (int /* phase */, double /* time */) { }
+	virtual void v_drawRealTimeSelectionViewer (double /* time */) { }
 	virtual void v_prepareDraw () { }   // for less flashing
 	virtual conststring32 v_domainName () { return U"time"; }
 	virtual conststring32 v_selectionViewerName () { return U"selection viewer"; }
@@ -94,30 +165,18 @@ Thing_define (FunctionEditor, Editor) {
 	virtual const char *v_format_selection () { return u8"%f (%.3f / s)"; }
 	virtual int v_fixedPrecision_long () { return 6; }
 	virtual bool v_hasText () { return false; }
-	virtual void v_play (double /* timeFrom */, double /* timeTo */) { }
+	virtual void v_play (double /* startTime */, double /* endTime */) { }
+	virtual bool v_mouseInWideDataView (GuiDrawingArea_MouseEvent event, double x_world, double y_fraction);
 		/*
-		 * Message: "the user clicked in one of the rectangles above or below the data window."
-		 */
-	virtual bool v_click (double xWC, double yWC, bool shiftKeyPressed);
-		/*
-		 * Message: "the user clicked in data window with the left mouse button."
-		 * 'xWC' is the time;
-		 * 'yWC' is a value between 0.0 (bottom) and 1.0 (top);
-		 * 'shiftKeyPressed' flags if the Shift key was held down during the click.
-		 * Constraints:
-		 *    Return FunctionEditor_UPDATE_NEEDED if you want a window update, i.e.,
-		 *    if your 'click' moves the cursor or otherwise changes the appearance of the data.
-		 *    Return FunctionEditor_NO_UPDATE_NEEDED if you do not want a window update, e.g.,
-		 *    if your 'click' method just 'plays' something or puts a dialog on the screen.
-		 *    In the latter case, the 'ok' callback of the dialog should
-		 *    call FunctionEditor_marksChanged if necessary.
-		 * Behaviour of FunctionEditor::click ():
-		 *    moves the cursor to 'xWC', drags to create a selection, or extends the selection.
-		 */
-	virtual void v_clickSelectionViewer (double xWC, double yWC);
-	virtual bool v_clickB (double xWC, double yWC);
-	virtual bool v_clickE (double xWC, double yWC);
-	virtual int v_playCallback (int phase, double tmin, double tmax, double t);
+			Message: "they clicked in the data part of the window, or in the left or right margin."
+			'event' is the mouse event, with still relevant info on phase and modifier keys;
+			'x_world' is the time (or another world unit);
+			'y_fraction' is a value between 0.0 (bottom) and 1.0 (top);
+			Behaviour of structFunctionEditor::v_mouseInWideDataView ():
+				moves the cursor to 'x_world', drags to create a selection, or extends the selection.
+		*/
+	virtual void v_clickSelectionViewer (double x_fraction, double y_fraction);
+	virtual int v_playCallback (int phase, double startTime, double endTime, double currentTime);
 	virtual void v_updateText () { }
 	virtual void v_prefs_addFields (EditorCommand) { }
 	virtual void v_prefs_setValues (EditorCommand) { }
@@ -129,7 +188,6 @@ Thing_define (FunctionEditor, Editor) {
 	virtual void v_createMenuItems_view_timeDomain (EditorMenu);
 	virtual void v_createMenuItems_view_audio (EditorMenu);
 	virtual void v_highlightSelection (double left, double right, double bottom, double top);
-	virtual void v_unhighlightSelection (double left, double right, double bottom, double top);
 	virtual double v_getBottomOfSoundArea () { return 0.0; }
 	virtual double v_getBottomOfSoundAndAnalysisArea () { return 0.0; }
 	virtual void v_form_pictureSelection (EditorCommand);
@@ -139,31 +197,7 @@ Thing_define (FunctionEditor, Editor) {
     #include "FunctionEditor_prefs.h"
 };
 
-int theFunctionEditor_playCallback (FunctionEditor me, int phase, double tmin, double tmax, double t);
-
-/*
-	Attributes:
-		data: must be a Function.
-
-	int clickB (double xWC, double yWC);
-		"user clicked in data window with the middle mouse button (Mac: control- or option-click)."
-		'xWC' is the time; 'yWC' is a value between 0.0 (bottom) and 1.0 (top).
-		For the return value, see the 'click' method.
-		FunctionEditor::clickB simply moves the start of the selection (B) to 'xWC',
-			with the sole statement 'my startSelection = xWC'.
-
-	int clickE (double xWC, double yWC);
-		"user clicked in data window with the right mouse button (Mac: command-click)."
-		'xWC' is the time; 'yWC' is a value between 0.0 (bottom) and 1.0 (top).
-		For the return value, see the 'click' method.
-		FunctionEditor::clickB simply moves the end of the selection (E) to 'xWC',
-			with the sole statement 'my endSelection = xWC'.
-
-	void key (unsigned char key);
-		"user typed a key to the data window."
-		FunctionEditor::key ignores this message.
-*/
-
+int theFunctionEditor_playCallback (FunctionEditor me, int phase, double startTime, double endTime, double currentTime);
 
 #define FunctionEditor_UPDATE_NEEDED  true
 #define FunctionEditor_NO_UPDATE_NEEDED  false
@@ -213,7 +247,7 @@ void FunctionEditor_redraw (FunctionEditor me);
 	Function:
 		update the drawing area of a single editor.
 	Usage:
-		calls this after she changes a view option (font, scaling, hide/show xx)
+		call this after she changes a view option (font, scaling, hide/show xx)
 		or after any of the data have changed. In the latter case, also call Editor_broadcastChange.
 	Behaviour:
 		we just call Graphics_updateWs (my graphics).
@@ -224,7 +258,7 @@ void FunctionEditor_enableUpdates (FunctionEditor me, bool enable);
 	Function:
 		temporarily disable update event to cause 'draw' messages.
 	Usage:
-		If you call from your 'draw' method routines that may trigger expose events,
+		If you call from your 'draw' method functions that may trigger expose events,
 		you should bracket those routines between
 			FunctionEditor_enableUpdates (me, false);
 		and
@@ -237,23 +271,27 @@ void FunctionEditor_ungroup (FunctionEditor me);
 	Function:
 		force me out of the group.
 	Usage:
-		Start cut or paste methods by calling this routine,
+		Start cut or paste methods by calling this function,
 		as the grouped editors will not be synchronized
 		after either of those actions. Worse, the selection
 		may get outside the common interval of the editors.
 */
 
-/* Some routines to enforce common look to all function editors. */
-/* The x axis of the window is supposed to have been set to [my startWindow, my endWindow]. */
-/* Preconditions: default line type, default line width. */
-/* Postconditions: default line type, default line width, undefined colour, undefined text alignment. */
+/*
+	Some functions to enforce a common look to all function editors.
+	The x axis of the window is supposed to have been set to [my startWindow, my endWindow].
+	Preconditions:
+		default line type, default line width.
+	Postconditions:
+		default line type, default line width, undefined colour, undefined text alignment.
+*/
 void FunctionEditor_drawRangeMark (FunctionEditor me, double yWC, conststring32 yWC_string, conststring32 units, int verticalAlignment);
 void FunctionEditor_drawCursorFunctionValue (FunctionEditor me, double yWC, conststring32 yWC_string, conststring32 units);
 void FunctionEditor_insertCursorFunctionValue (FunctionEditor me, double yWC, conststring32 yWC_string, conststring32 units, double minimum, double maximum);
 void FunctionEditor_drawHorizontalHair (FunctionEditor me, double yWC, conststring32 yWC_string, conststring32 units);
 void FunctionEditor_drawGridLine (FunctionEditor me, double yWC);
 
-void FunctionEditor_garnish (FunctionEditor me);   // Optionally selection times and selection hairs.
+void FunctionEditor_garnish (FunctionEditor me);   // optionally selection times and selection hairs
 
 /* End of file FunctionEditor.h */
 #endif
