@@ -2,7 +2,7 @@
 #define _IntensityTierEditor_h_
 /* IntensityTierEditor.h
  *
- * Copyright (C) 1992-2011,2012,2015,2017 Paul Boersma
+ * Copyright (C) 1992-2005,2007,2009-2012,2015-2018,2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,21 @@
 #include "IntensityTier.h"
 #include "Sound.h"
 
+Thing_define (IntensityTierArea, RealTierArea) {
+	conststring32 v_rightTickUnits ()
+		override { return U" dB"; }
+	double v_defaultYmin ()
+		override { return 50.0; }
+	double v_defaultYmax ()
+		override { return 100.0; }
+};
+
+inline autoIntensityTierArea IntensityTierArea_create (FunctionEditor editor, double ymin_fraction, double ymax_fraction) {
+	autoIntensityTierArea me = Thing_new (IntensityTierArea);
+	FunctionArea_init (me.get(), editor, ymin_fraction, ymax_fraction);
+	return me;
+}
+
 Thing_define (IntensityTierEditor, RealTierEditor) {
 	void v_createHelpMenuItems (EditorMenu menu)
 		override;
@@ -29,12 +44,6 @@ Thing_define (IntensityTierEditor, RealTierEditor) {
 		override;
 	conststring32 v_quantityText ()
 		override { return U"Intensity (dB)"; }
-	conststring32 v_rightTickUnits ()
-		override { return U" dB"; }
-	double v_defaultYmin ()
-		override { return 50.0; }
-	double v_defaultYmax ()
-		override { return 100.0; }
 	conststring32 v_setRangeTitle ()
 		override { return U"Set intensity range..."; }
 	conststring32 v_defaultYminText ()
