@@ -1,6 +1,6 @@
 /* PitchTier_to_PointProcess.cpp
  *
- * Copyright (C) 1992-2011,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2005,2011,2012,2015-2017,2019 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,8 @@ autoPointProcess PitchTier_to_PointProcess (PitchTier me) {
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 1000);
 		double area = 0.5;   // imagine an event half a period before the beginning
 		integer size = my points.size;
-		if (size == 0) return thee;
+		if (size == 0)
+			return thee;
 		for (integer interval = 0; interval <= size; interval ++) {
 			double t1 = ( interval == 0 ? my xmin : my points.at [interval] -> number );
 			Melder_assert (isdefined (t1));
@@ -36,10 +37,11 @@ autoPointProcess PitchTier_to_PointProcess (PitchTier me) {
 			Melder_assert (isdefined (f2));
 			area += (t2 - t1) * 0.5 * (f1 + f2);
 			while (area >= 1.0) {
-				double slope = (f2 - f1) / (t2 - t1), discriminant;
+				const double slope = (f2 - f1) / (t2 - t1);
 				area -= 1.0;
-				discriminant = f2 * f2 - 2.0 * area * slope;
-				if (discriminant < 0.0) discriminant = 0.0;   // catch rounding errors
+				double discriminant = f2 * f2 - 2.0 * area * slope;
+				if (discriminant < 0.0)
+					discriminant = 0.0;   // catch rounding errors
 				PointProcess_addPoint (thee.get(), t2 - 2.0 * area / (f2 + sqrt (discriminant)));
 			}
 		}
@@ -52,15 +54,14 @@ autoPointProcess PitchTier_to_PointProcess (PitchTier me) {
 autoPointProcess PitchTier_Pitch_to_PointProcess (PitchTier me, Pitch vuv) {
 	try {
 		autoPointProcess fullPoint = PitchTier_to_PointProcess (me);
-		autoPointProcess thee = PointProcess_create (my xmin, my xmax, fullPoint -> maxnt);
+		autoPointProcess thee = PointProcess_create (my xmin, my xmax, fullPoint -> nt);
 		/*
 		 * Copy only voiced parts to result.
 		 */
 		for (integer i = 1; i <= fullPoint -> nt; i ++) {
 			double t = fullPoint -> t [i];
-			if (Pitch_isVoiced_t (vuv, t)) {
+			if (Pitch_isVoiced_t (vuv, t))
 				PointProcess_addPoint (thee.get(), t);
-			}
 		}
 		return thee;
 	} catch (MelderError) {
@@ -68,30 +69,33 @@ autoPointProcess PitchTier_Pitch_to_PointProcess (PitchTier me, Pitch vuv) {
 	}
 }
 
-static int PointProcess_isVoiced_t (PointProcess me, double t, double maxT) {
+static bool PointProcess_isVoiced_t (PointProcess me, double t, double maxT) {
 	integer imid = PointProcess_getNearestIndex (me, t);
-	if (imid == 0) return 0;
+	if (imid == 0)
+		return false;
 	double tmid = my t [imid];
-	int leftVoiced = imid > 1 && tmid - my t [imid - 1] <= maxT;
-	int rightVoiced = imid < my nt && my t [imid + 1] - tmid <= maxT;
-	if ((leftVoiced && t <= tmid) || (rightVoiced && t >= tmid)) return 1;
-	if (leftVoiced && t < 1.5 * tmid - 0.5 * my t [imid - 1]) return 1;
-	if (rightVoiced && t > 1.5 * tmid - 0.5 * my t [imid + 1]) return 1;
-	return 0;
+	bool leftVoiced = ( imid > 1 && tmid - my t [imid - 1] <= maxT );
+	bool rightVoiced = ( imid < my nt && my t [imid + 1] - tmid <= maxT );
+	if (leftVoiced && t <= tmid || rightVoiced && t >= tmid)
+		return true;
+	if (leftVoiced && t < 1.5 * tmid - 0.5 * my t [imid - 1])
+		return true;
+	if (rightVoiced && t > 1.5 * tmid - 0.5 * my t [imid + 1])
+		return true;
+	return false;
 }
 
 autoPointProcess PitchTier_Point_to_PointProcess (PitchTier me, PointProcess vuv, double maxT) {
 	try {
 		autoPointProcess fullPoint = PitchTier_to_PointProcess (me);
-		autoPointProcess thee = PointProcess_create (my xmin, my xmax, fullPoint -> maxnt);
+		autoPointProcess thee = PointProcess_create (my xmin, my xmax, fullPoint -> nt);
 		/*
 		 * Copy only voiced parts to result.
 		 */
 		for (integer i = 1; i <= fullPoint -> nt; i ++) {
 			double t = fullPoint -> t [i];
-			if (PointProcess_isVoiced_t (vuv, t, maxT)) {
+			if (PointProcess_isVoiced_t (vuv, t, maxT))
 				PointProcess_addPoint (thee.get(), t);
-			}
 		}
 		return thee;
 	} catch (MelderError) {
@@ -104,9 +108,8 @@ autoPitchTier PointProcess_to_PitchTier (PointProcess me, double maximumInterval
 		autoPitchTier thee = PitchTier_create (my xmin, my xmax);
 		for (integer i = 1; i < my nt; i ++) {
 			double interval = my t [i + 1] - my t [i];
-			if (interval <= maximumInterval) {
+			if (interval <= maximumInterval)
 				RealTier_addPoint (thee.get(), my t [i] + 0.5 * interval, 1.0 / interval);
-			}
 		}
 		return thee;
 	} catch (MelderError) {
