@@ -1,6 +1,6 @@
 /* Polygon_def.h
  *
- * Copyright (C) 1992-2011,2015,2017 Paul Boersma
+ * Copyright (C) 1992-2005,2008,2011,2015-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,16 +23,16 @@ oo_DEFINE_CLASS (Polygon, Daata)
 	oo_INTEGER (numberOfPoints)
 
 	#if oo_READING
-		if (formatVersion >= 1) {
-			oo_DOUBLE_VECTOR (x, numberOfPoints)
-			oo_DOUBLE_VECTOR (y, numberOfPoints)
-		} else {
-			oo_FLOAT_VECTOR (x, numberOfPoints)
-			oo_FLOAT_VECTOR (y, numberOfPoints)
-		}
+		oo_VERSION_UNTIL (1)
+			oo_obsoleteVEC32 (x, numberOfPoints)
+			oo_obsoleteVEC32 (y, numberOfPoints)
+		oo_VERSION_ELSE
+			oo_VEC (x, numberOfPoints)
+			oo_VEC (y, numberOfPoints)
+		oo_VERSION_END
 	#else
-		oo_DOUBLE_VECTOR (x, numberOfPoints)
-		oo_DOUBLE_VECTOR (y, numberOfPoints)
+		oo_VEC (x, numberOfPoints)
+		oo_VEC (y, numberOfPoints)
 	#endif
 
 	#if oo_DECLARING
