@@ -88,14 +88,14 @@ double Sampled_getValueAtSample (Sampled me, integer sampleNumber, integer level
 }
 
 autoVEC Sampled_listValuesOfAllSamples (Sampled me, integer levelNumber, int unit) {
-	autoVEC result = newVECraw (my nx);
+	autoVEC result = raw_VEC (my nx);
 	for (integer isamp = 1; isamp <= my nx; isamp ++)
 		result [isamp] = my v_getValueAtSample (isamp, levelNumber, unit);
 	return result;
 }
 
 autoVEC Sampled_listValuesAtXes (Sampled me, constVECVU const& xes, integer levelNumber, int unit, bool interpolate) {
-	autoVEC result = newVECraw (xes.size);
+	autoVEC result = raw_VEC (xes.size);
 	for (integer ix = 1; ix <= xes.size; ix ++)
 		result [ix] = Sampled_getValueAtX (me, xes [ix], levelNumber, unit, interpolate);
 	return result;
@@ -157,7 +157,7 @@ autoVEC Sampled_getSortedValues (Sampled me, double xmin, double xmax, integer l
 	integer numberOfDefinedSamples = Sampled_countDefinedSamples (me, xmin, xmax, levelNumber, unit);
 	if (numberOfDefinedSamples == 0)
 		return autoVEC();
-	autoVEC definedValues = newVECraw (numberOfDefinedSamples);
+	autoVEC definedValues = raw_VEC (numberOfDefinedSamples);
 	integer imin, imax;
 	autoWindowDomainSamples (me, & xmin, & xmax, & imin, & imax);
 	integer definedSampleNumber = 0;
@@ -167,7 +167,7 @@ autoVEC Sampled_getSortedValues (Sampled me, double xmin, double xmax, integer l
 			definedValues [++ definedSampleNumber] = value;
 	}
 	Melder_assert (definedSampleNumber == numberOfDefinedSamples);
-	VECsort_inplace (definedValues.get());
+	sort_VEC_inout (definedValues.get());
 	return definedValues;
 }
 
@@ -195,7 +195,7 @@ static void Sampled_getSumAndDefinitionRange
 	if (Function_intersectRangeWithDomain (me, & xmin, & xmax)) {
 		if (interpolate) {
 			integer imin, imax;
-			if (Sampled_getWindowSamples (me, xmin, xmax, & imin, & imax)) {
+			if (Sampled_getWindowSamples (me, xmin, xmax, & imin, & imax) > 0) {
 				double leftEdge = my x1 - 0.5 * my dx, rightEdge = leftEdge + my nx * my dx;
 				for (integer isamp = imin; isamp <= imax; isamp ++) {
 					const double value = my v_getValueAtSample (isamp, levelNumber, unit);   // a fast way to integrate a linearly interpolated curve; works everywhere except at the edges
@@ -356,7 +356,7 @@ static void Sampled_getSum2AndDefinitionRange
 	if (Function_intersectRangeWithDomain (me, & xmin, & xmax)) {
 		if (interpolate) {
 			integer imin, imax;
-			if (Sampled_getWindowSamples (me, xmin, xmax, & imin, & imax)) {
+			if (Sampled_getWindowSamples (me, xmin, xmax, & imin, & imax) > 0) {
 				const double leftEdge = my x1 - 0.5 * my dx, rightEdge = leftEdge + my nx * my dx;
 				for (integer isamp = imin; isamp <= imax; isamp ++) {
 					double value = my v_getValueAtSample (isamp, levelNumber, unit);   // a fast way to integrate a linearly interpolated curve; works everywhere except at the edges
@@ -729,7 +729,9 @@ static void Sampled_speckleInside (Sampled me, Graphics g, double xmin, double x
 {
 	Function_unidirectionalAutowindow (me, & xmin, & xmax);
 	integer ixmin, ixmax;
-	Sampled_getWindowSamples (me, xmin, xmax, & ixmin, & ixmax);
+	integer numberOfSamples = Sampled_getWindowSamples (me, xmin, xmax, & ixmin, & ixmax);
+	if (numberOfSamples <= 0)
+		return;
 	if (Function_isUnitLogarithmic (me, levelNumber, unit)) {
 		ymin = Function_convertStandardToSpecialUnit (me, ymin, levelNumber, unit);
 		ymax = Function_convertStandardToSpecialUnit (me, ymax, levelNumber, unit);
@@ -757,7 +759,9 @@ void Sampled_drawInside (Sampled me, Graphics g, double xmin, double xmax, doubl
 		}
 		Function_unidirectionalAutowindow (me, & xmin, & xmax);
 		integer ixmin, ixmax, startOfDefinedStretch = -1;
-		Sampled_getWindowSamples (me, xmin, xmax, & ixmin, & ixmax);
+		integer numberOfSamples = Sampled_getWindowSamples (me, xmin, xmax, & ixmin, & ixmax);
+		if (numberOfSamples <= 0)
+			return;
 		if (Function_isUnitLogarithmic (me, levelNumber, unit)) {
 			ymin = Function_convertStandardToSpecialUnit (me, ymin, levelNumber, unit);
 			ymax = Function_convertStandardToSpecialUnit (me, ymax, levelNumber, unit);
@@ -767,7 +771,7 @@ void Sampled_drawInside (Sampled me, Graphics g, double xmin, double xmax, doubl
 		Graphics_setWindow (g, xmin, xmax, ymin, ymax);
 		auto const lowIndex = ixmin - 1, highIndex = ixmax + 1;
 		auto const nbuffer = highIndex - lowIndex + 1;
-		auto xbuffer = newVECzero (nbuffer), ybuffer = newVECzero (nbuffer);
+		auto xbuffer = zero_VEC (nbuffer), ybuffer = zero_VEC (nbuffer);
 		auto const bufferShift = 1 - lowIndex;
 		double *xarray = & xbuffer [bufferShift];
 		double *yarray = & ybuffer [bufferShift];
