@@ -68,9 +68,10 @@ void SampledXY_init (SampledXY me,
 integer SampledXY_getWindowSamplesY (SampledXY me, double fromY, double toY, integer *iymin, integer *iymax) {
 	double riymin = 1.0 + Melder_roundUp   ((fromY - my y1) / my dy);
 	double riymax = 1.0 + Melder_roundDown ((toY - my y1) / my dy);   // could be above 32-bit LONG_MAX
-	*iymin = riymin < 1.0 ? 1 : (integer) riymin;
-	*iymax = riymax > (double) my ny ? my ny : (integer) riymax;
-	if (*iymin > *iymax) return 0;
+	*iymin = ( riymin < 1.0 ? 1 : (integer) riymin );
+	*iymax = ( riymax > double (my ny) ? my ny : (integer) riymax );
+	if (*iymin > *iymax)
+		return 0;
 	return *iymax - *iymin + 1;
 }
 
