@@ -1,6 +1,6 @@
 /* Sampled_def.h
  *
- * Copyright (C) 1992-2005,2011,2014-2018 Paul Boersma
+ * Copyright (C) 1992-2005,2011,2014-2018,2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,6 +53,19 @@ oo_DEFINE_CLASS (Sampled, Function)
 
 		virtual double v_getValueAtSample (integer /* isamp */, integer /* ilevel */, int /* unit */)
 			{ return undefined; }
+		virtual conststring32 v_getIndexText () const
+			{ return U"index"; }
+		virtual conststring32 v_getNxText () const
+			{ return U"nx"; }
+		virtual void checkIndex (integer index) {
+			Melder_require (index >= 1,
+				U"The ", our v_getIndexText (), U" should be at least 1, but is ", index, U" instead.");
+			Melder_require (index <= our nx,
+				U"The ", our v_getIndexText (), U" should be at most ", our v_getNxText (),
+				U" (", our nx, U"), but is ", index, U" instead."
+			);
+		}
+
 	#endif
 
 oo_END_CLASS (Sampled)
