@@ -1,6 +1,6 @@
 /* SoundEditor.cpp
  *
- * Copyright (C) 1992-2018 Paul Boersma, 2007 Erez Volk (FLAC support)
+ * Copyright (C) 1992-2020 Paul Boersma, 2007 Erez Volk (FLAC support)
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,11 +16,10 @@
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "Sound_and_MixingMatrix.h"
 #include "SoundEditor.h"
 #include "Sound_and_Spectrogram.h"
 #include "Pitch.h"
-#include "Preferences.h"
+#include "Sound_and_MixingMatrix.h"
 #include "EditorM.h"
 
 Thing_implement (SoundEditor, TimeSoundAnalysisEditor, 0);
@@ -40,8 +39,9 @@ void structSoundEditor :: v_dataChanged () {
 
 static void menu_cb_Copy (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	try {
-		Sound_clipboard = my d_longSound.data ? LongSound_extractPart ((LongSound) my data, my startSelection, my endSelection, false) :
-			Sound_extractPart ((Sound) my data, my startSelection, my endSelection, kSound_windowShape::RECTANGULAR, 1.0, false);
+		Sound_clipboard = my d_longSound.data ?
+				LongSound_extractPart ((LongSound) my data, my startSelection, my endSelection, false) :
+				Sound_extractPart ((Sound) my data, my startSelection, my endSelection, kSound_windowShape::RECTANGULAR, 1.0, false);
 	} catch (MelderError) {
 		Melder_throw (U"Sound selection not copied to clipboard.");
 	}
@@ -51,7 +51,7 @@ static void menu_cb_Cut (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	try {
 		Sound sound = (Sound) my data;
 		integer first, last, selectionNumberOfSamples = Sampled_getWindowSamples (sound,
-			my startSelection, my endSelection, & first, & last);
+				my startSelection, my endSelection, & first, & last);
 		integer oldNumberOfSamples = sound -> nx;
 		integer newNumberOfSamples = oldNumberOfSamples - selectionNumberOfSamples;
 		if (newNumberOfSamples < 1)
@@ -69,7 +69,7 @@ static void menu_cb_Cut (SoundEditor me, EDITOR_ARGS_DIRECT) {
 				for (integer i = first; i <= last; i ++)
 					publish -> z [channel] [++ j] = sound -> z [channel] [i];
 			}
-			autoMAT newData = newMATraw (sound -> ny, newNumberOfSamples);
+			autoMAT newData = raw_MAT (sound -> ny, newNumberOfSamples);
 			for (integer channel = 1; channel <= sound -> ny; channel ++) {
 				integer j = 0;
 				for (integer i = 1; i < first; i ++)
@@ -89,18 +89,22 @@ static void menu_cb_Cut (SoundEditor me, EDITOR_ARGS_DIRECT) {
 			sound -> z = newData.move();
 			Sound_clipboard = publish.move();
 
-			/* Start updating the markers of the FunctionEditor, respecting the invariants. */
-
+			/*
+				Start updating the markers of the FunctionEditor, respecting the invariants.
+			*/
 			my tmin = sound -> xmin;
 			my tmax = sound -> xmax;
 
-			/* Collapse the selection, */
-			/* so that the Cut operation can immediately be undone by a Paste. */
-			/* The exact position will be half-way in between two samples. */
-
+			/*
+				Collapse the selection,
+				so that the Cut operation can immediately be undone by a Paste.
+				The exact position will be half-way in between two samples.
+			*/
 			my startSelection = my endSelection = sound -> xmin + (first - 1) * sound -> dx;
 
-			/* Update the window. */
+			/*
+				Update the window.
+			*/
 			{
 				double t1 = (first - 1) * sound -> dx;
 				double t2 = last * sound -> dx;
@@ -128,8 +132,9 @@ static void menu_cb_Cut (SoundEditor me, EDITOR_ARGS_DIRECT) {
 				}
 			}
 
-			/* Force FunctionEditor to show changes. */
-
+			/*
+				Force FunctionEditor to show changes.
+			*/
 			Matrix_getWindowExtrema (sound, 1, sound -> nx, 1, sound -> ny, & my d_sound.minimum, & my d_sound.maximum);
 			my v_reset_analysis ();
 			FunctionEditor_ungroup (me);
@@ -151,21 +156,22 @@ static void menu_cb_Paste (SoundEditor me, EDITOR_ARGS_DIRECT) {
 		Melder_warning (U"Clipboard is empty; nothing pasted.");
 		return;
 	}
-	if (Sound_clipboard -> ny != sound -> ny)
-		Melder_throw (U"Cannot paste, because\n"
-			U"the number of channels of the clipboard is not equal to\n"
-			U"the number of channels of the edited sound.");
-	if (Sound_clipboard -> dx != sound -> dx)
-		Melder_throw (U"Cannot paste, because\n"
-			U"the sampling frequency of the clipboard is not equal to\n"
-			U"the sampling frequency of the edited sound.");
-	if (leftSample < 0) leftSample = 0;
-	if (leftSample > oldNumberOfSamples) leftSample = oldNumberOfSamples;
+	Melder_require (Sound_clipboard -> ny == sound -> ny,
+		U"Cannot paste, because\n"
+		U"the number of channels of the clipboard is not equal to\n"
+		U"the number of channels of the edited sound."
+	);
+	Melder_require (Sound_clipboard -> dx == sound -> dx,
+		U"Cannot paste, because\n"
+		U"the sampling frequency of the clipboard is not equal to\n"
+		U"the sampling frequency of the edited sound."
+	);
+	Melder_clip (0_integer, & leftSample, oldNumberOfSamples);
 	newNumberOfSamples = oldNumberOfSamples + Sound_clipboard -> nx;
 	/*
 		Check without change.
 	*/
-	autoMAT newData = newMATraw (sound -> ny, newNumberOfSamples);
+	autoMAT newData = raw_MAT (sound -> ny, newNumberOfSamples);
 	for (integer channel = 1; channel <= sound -> ny; channel ++) {
 		integer j = 0;
 		for (integer i = 1; i <= leftSample; i ++)
@@ -186,15 +192,19 @@ static void menu_cb_Paste (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	sound -> x1 = 0.5 * sound -> dx;
 	sound -> z = newData.move();
 
-	/* Start updating the markers of the FunctionEditor, respecting the invariants. */
-
+	/*
+		Start updating the markers of the FunctionEditor, respecting the invariants.
+	*/
 	my tmin = sound -> xmin;
 	my tmax = sound -> xmax;
+	Melder_clipLeft (my tmin, & my startWindow);
+	Melder_clipRight (& my endWindow, my tmax);
 	my startSelection = leftSample * sound -> dx;
 	my endSelection = (leftSample + Sound_clipboard -> nx) * sound -> dx;
 
-	/* Force FunctionEditor to show changes. */
-
+	/*
+		Force FunctionEditor to show changes.
+	*/
 	Matrix_getWindowExtrema (sound, 1, sound -> nx, 1, sound -> ny, & my d_sound.minimum, & my d_sound.maximum);
 	my v_reset_analysis ();
 	FunctionEditor_ungroup (me);
@@ -207,11 +217,7 @@ static void menu_cb_SetSelectionToZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	integer first, last;
 	Sampled_getWindowSamples (sound, my startSelection, my endSelection, & first, & last);
 	Editor_save (me, U"Set to zero");
-	for (integer channel = 1; channel <= sound -> ny; channel ++) {
-		for (integer i = first; i <= last; i ++) {
-			sound -> z [channel] [i] = 0.0;
-		}
-	}
+	sound -> z.verticalBand	(first, last)  <<=  0.0;
 	my v_reset_analysis ();
 	FunctionEditor_redraw (me);
 	Editor_broadcastDataChanged (me);
@@ -228,7 +234,7 @@ static void menu_cb_ReverseSelection (SoundEditor me, EDITOR_ARGS_DIRECT) {
 /***** SELECT MENU *****/
 
 static void menu_cb_MoveCursorToZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
-	double zero = Sound_getNearestZeroCrossing ((Sound) my data, 0.5 * (my startSelection + my endSelection), 1);   // STEREO BUG
+	const double zero = Sound_getNearestZeroCrossing ((Sound) my data, 0.5 * (my startSelection + my endSelection), 1);   // STEREO BUG
 	if (isdefined (zero)) {
 		my startSelection = my endSelection = zero;
 		FunctionEditor_marksChanged (me, true);
@@ -236,14 +242,10 @@ static void menu_cb_MoveCursorToZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 }
 
 static void menu_cb_MoveBtoZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
-	double zero = Sound_getNearestZeroCrossing ((Sound) my data, my startSelection, 1);   // STEREO BUG
+	const double zero = Sound_getNearestZeroCrossing ((Sound) my data, my startSelection, 1);   // STEREO BUG
 	if (isdefined (zero)) {
 		my startSelection = zero;
-		if (my startSelection > my endSelection) {
-			double dummy = my startSelection;
-			my startSelection = my endSelection;
-			my endSelection = dummy;
-		}
+		Melder_sort (& my startSelection, & my endSelection);
 		FunctionEditor_marksChanged (me, true);
 	}
 }
@@ -252,11 +254,7 @@ static void menu_cb_MoveEtoZero (SoundEditor me, EDITOR_ARGS_DIRECT) {
 	double zero = Sound_getNearestZeroCrossing ((Sound) my data, my endSelection, 1);   // STEREO BUG
 	if (isdefined (zero)) {
 		my endSelection = zero;
-		if (my startSelection > my endSelection) {
-			double dummy = my startSelection;
-			my startSelection = my endSelection;
-			my endSelection = dummy;
-		}
+		Melder_sort (& my startSelection, & my endSelection);
 		FunctionEditor_marksChanged (me, true);
 	}
 }
@@ -272,15 +270,16 @@ void structSoundEditor :: v_createMenus () {
 	Melder_assert (d_sound.data || d_longSound.data);
 
 	Editor_addCommand (this, U"Edit", U"-- cut copy paste --", 0, nullptr);
-	if (d_sound.data) cutButton = Editor_addCommand (this, U"Edit", U"Cut", 'X', menu_cb_Cut);
+	if (d_sound.data)
+		cutButton = Editor_addCommand (this, U"Edit", U"Cut", 'X', menu_cb_Cut);
 	copyButton = Editor_addCommand (this, U"Edit", U"Copy selection to Sound clipboard", 'C', menu_cb_Copy);
-	if (d_sound.data) pasteButton = Editor_addCommand (this, U"Edit", U"Paste after selection", 'V', menu_cb_Paste);
+	if (d_sound.data)
+		pasteButton = Editor_addCommand (this, U"Edit", U"Paste after selection", 'V', menu_cb_Paste);
 	if (d_sound.data) {
 		Editor_addCommand (this, U"Edit", U"-- zero --", 0, nullptr);
 		zeroButton = Editor_addCommand (this, U"Edit", U"Set selection to zero", 0, menu_cb_SetSelectionToZero);
 		reverseButton = Editor_addCommand (this, U"Edit", U"Reverse selection", 'R', menu_cb_ReverseSelection);
 	}
-
 	if (d_sound.data) {
 		Editor_addCommand (this, U"Select", U"-- move to zero --", 0, 0);
 		Editor_addCommand (this, U"Select", U"Move start of selection to nearest zero crossing", ',', menu_cb_MoveBtoZero);
@@ -288,7 +287,6 @@ void structSoundEditor :: v_createMenus () {
 		Editor_addCommand (this, U"Select", U"Move cursor to nearest zero crossing", '0', menu_cb_MoveCursorToZero);
 		Editor_addCommand (this, U"Select", U"Move end of selection to nearest zero crossing", '.', menu_cb_MoveEtoZero);
 	}
-
 	v_createMenus_analysis ();
 }
 
@@ -318,8 +316,8 @@ void structSoundEditor :: v_draw () {
 	Melder_assert (our d_sound.data || our d_longSound.data);
 
 	/*
-	 * We check beforehand whether the window fits the LongSound buffer.
-	 */
+		We check beforehand whether the window fits the LongSound buffer.
+	*/
 	if (our d_longSound.data && our endWindow - our startWindow > our d_longSound.data -> bufferLength) {
 		Graphics_setColour (our graphics.get(), Melder_WHITE);
 		Graphics_setWindow (our graphics.get(), 0.0, 1.0, 0.0, 1.0);
@@ -332,42 +330,27 @@ void structSoundEditor :: v_draw () {
 		return;
 	}
 
-	/* Draw sound. */
-
+	/*
+		Draw data.
+	*/
 	if (showAnalysis)
 		viewport = Graphics_insetViewport (our graphics.get(), 0.0, 1.0, 0.5, 1.0);
 	Graphics_setColour (our graphics.get(), Melder_WHITE);
 	Graphics_setWindow (our graphics.get(), 0.0, 1.0, 0.0, 1.0);
 	Graphics_fillRectangle (our graphics.get(), 0.0, 1.0, 0.0, 1.0);
+	if (p_pulses_show)
+		v_draw_analysis_pulses ();
 	TimeSoundEditor_drawSound (this, our d_sound.minimum, our d_sound.maximum);
-	//Graphics_flushWs (our graphics.get());
-	if (showAnalysis)
-		Graphics_resetViewport (our graphics.get(), viewport);
-
-	/* Draw analyses. */
-
 	if (showAnalysis) {
-		/* Draw spectrogram, pitch, formants. */
+		Graphics_resetViewport (our graphics.get(), viewport);
 		viewport = Graphics_insetViewport (our graphics.get(), 0.0, 1.0, 0.0, 0.5);
 		v_draw_analysis ();
-		//Graphics_flushWs (our graphics.get());
 		Graphics_resetViewport (our graphics.get(), viewport);
 	}
 
-	/* Draw pulses. */
-
-	if (p_pulses_show) {
-		if (showAnalysis)
-			viewport = Graphics_insetViewport (our graphics.get(), 0.0, 1.0, 0.5, 1.0);
-		v_draw_analysis_pulses ();
-		TimeSoundEditor_drawSound (this, our d_sound.minimum, our d_sound.maximum);   // second time, partially across the pulses
-		//Graphics_flushWs (our graphics.get());
-		if (showAnalysis)
-			Graphics_resetViewport (our graphics.get(), viewport);
-	}
-
-	/* Update buttons. */
-
+	/*
+		Update buttons.
+	*/
 	integer first, last;
 	integer selectedSamples = Sampled_getWindowSamples (data, our startSelection, our endSelection, & first, & last);
 	v_updateMenuItems_file ();
@@ -379,7 +362,7 @@ void structSoundEditor :: v_draw () {
 	}
 }
 
-void structSoundEditor :: v_play (double a_tmin, double a_tmax) {
+void structSoundEditor :: v_play (double startTime, double endTime) {
 	integer numberOfChannels = ( our d_longSound.data ? our d_longSound.data -> numberOfChannels : our d_sound.data -> ny );
 	integer numberOfMuteChannels = 0;
 	Melder_assert (our d_sound.muteChannels.size == numberOfChannels);
@@ -391,29 +374,29 @@ void structSoundEditor :: v_play (double a_tmin, double a_tmax) {
 		U"Please select at least one channel to play.");
 	if (our d_longSound.data) {
 		if (numberOfMuteChannels > 0) {
-			autoSound part = LongSound_extractPart (our d_longSound.data, a_tmin, a_tmax, 1);
+			autoSound part = LongSound_extractPart (our d_longSound.data, startTime, endTime, 1);
 			autoMixingMatrix thee = MixingMatrix_create (numberOfChannelsToPlay, numberOfChannels);
 			MixingMatrix_muteAndActivateChannels (thee.get(), our d_sound.muteChannels.get());
-			Sound_MixingMatrix_playPart (part.get(), thee.get(), a_tmin, a_tmax, theFunctionEditor_playCallback, this);
+			Sound_MixingMatrix_playPart (part.get(), thee.get(), startTime, endTime, theFunctionEditor_playCallback, this);
 		} else {
-			LongSound_playPart (our d_longSound.data, a_tmin, a_tmax, theFunctionEditor_playCallback, this);
+			LongSound_playPart (our d_longSound.data, startTime, endTime, theFunctionEditor_playCallback, this);
 		}
 	} else {
 		if (numberOfMuteChannels > 0) {
 			autoMixingMatrix thee = MixingMatrix_create (numberOfChannelsToPlay, numberOfChannels);
 			MixingMatrix_muteAndActivateChannels (thee.get(), our d_sound.muteChannels.get());
-			Sound_MixingMatrix_playPart (our d_sound.data, thee.get(), a_tmin, a_tmax, theFunctionEditor_playCallback, this);
+			Sound_MixingMatrix_playPart (our d_sound.data, thee.get(), startTime, endTime, theFunctionEditor_playCallback, this);
 		} else {
-			Sound_playPart (our d_sound.data, a_tmin, a_tmax, theFunctionEditor_playCallback, this);
+			Sound_playPart (our d_sound.data, startTime, endTime, theFunctionEditor_playCallback, this);
 		}
 	}
 }
 
-bool structSoundEditor :: v_click (double xWC, double yWC, bool shiftKeyPressed) {
+bool structSoundEditor :: v_mouseInWideDataView (GuiDrawingArea_MouseEvent event, double xWC, double yWC) {
 	if ((our p_spectrogram_show || our p_formant_show) && yWC < 0.5 && xWC > our startWindow && xWC < our endWindow)
 		our d_spectrogram_cursor = our p_spectrogram_viewFrom +
 				2.0 * yWC * (our p_spectrogram_viewTo - our p_spectrogram_viewFrom);
-	return SoundEditor_Parent :: v_click (xWC, yWC, shiftKeyPressed);   // drag & update
+	return SoundEditor_Parent :: v_mouseInWideDataView (event, xWC, yWC);
 }
 
 void structSoundEditor :: v_highlightSelection (double left, double right, double bottom, double top) {
@@ -423,13 +406,6 @@ void structSoundEditor :: v_highlightSelection (double left, double right, doubl
 		Graphics_highlight (our graphics.get(), left, right, bottom, top);
 }
 
-void structSoundEditor :: v_unhighlightSelection (double left, double right, double bottom, double top) {
-	if (our p_spectrogram_show)
-		Graphics_unhighlight (our graphics.get(), left, right, 0.5 * (bottom + top), top);
-	else
-		Graphics_unhighlight (our graphics.get(), left, right, bottom, top);
-}
-
 void SoundEditor_init (SoundEditor me, conststring32 title, Sampled data) {
 	/*
 	 * my longSound.data or my sound.data have to be set before we call FunctionEditor_init,
