@@ -1,6 +1,6 @@
 /* Sound_and_Spectrogram.cpp
  *
- * Copyright (C) 1992-2011,2014-2019 Paul Boersma
+ * Copyright (C) 1992-2011,2014-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ autoSpectrogram Sound_to_Spectrogram (Sound me, double effectiveAnalysisWidth, d
 		autoSpectrogram thee = Spectrogram_create (my xmin, my xmax, numberOfTimes, timeStep, t1,
 				0.0, fmax, numberOfFreqs, freqStep, 0.5 * (freqStep - binWidth_hertz));
 
-		autoVEC window = newVECzero (nsamp_window);
+		autoVEC window = zero_VEC (nsamp_window);
 		longdouble windowssq = 0.0;
 		for (integer i = 1; i <= nsamp_window; i ++) {
 			const double nSamplesPerWindow_f = physicalAnalysisWidth / my dx;
@@ -118,8 +118,8 @@ autoSpectrogram Sound_to_Spectrogram (Sound me, double effectiveAnalysisWidth, d
 		}
 		const double oneByBinWidth = 1.0 / double (windowssq) / binWidth_samples;
 
-		autoVEC data = newVECzero (nsampFFT);
-		autoVEC spectrum = newVECzero (half_nsampFFT + 1);
+		autoVEC data = zero_VEC (nsampFFT);
+		autoVEC spectrum = zero_VEC (half_nsampFFT + 1);
 		autoNUMfft_Table fftTable;
 		NUMfft_Table_init (& fftTable, nsampFFT);
 
@@ -133,7 +133,7 @@ autoSpectrogram Sound_to_Spectrogram (Sound me, double effectiveAnalysisWidth, d
 			Melder_assert (startSample >= 1);
 			Melder_assert (endSample <= my nx);
 
-			spectrum.all() <<= 0.0;
+			spectrum.all()  <<=  0.0;
 			/*
 				For multichannel sounds, the power spectrogram should represent the
 				average power in the channels,
