@@ -123,7 +123,7 @@ void Spectrum_drawInside (Spectrum me, Graphics g, double fmin, double fmax, dou
 	const integer nf = Matrix_getWindowSamplesX (me, fmin, fmax, & ifmin, & ifmax);
 	if (nf == 0)
 		return;
-	auto ybuffer = newVECzero (nf);
+	autoVEC ybuffer = zero_VEC (nf);
 	double *yWC = & ybuffer [1 - ifmin];
 
 	/*
@@ -158,7 +158,7 @@ void Spectrum_drawInside (Spectrum me, Graphics g, double fmin, double fmax, dou
 	Graphics_function (g, yWC, ifmin, ifmax, Matrix_columnToX (me, ifmin), Matrix_columnToX (me, ifmax));
 }
 
-void Spectrum_draw (Spectrum me, Graphics g, double fmin, double fmax, double minimum, double maximum, int garnish) {
+void Spectrum_draw (Spectrum me, Graphics g, double fmin, double fmax, double minimum, double maximum, bool garnish) {
 	Graphics_setInner (g);
 	Spectrum_drawInside (me, g, fmin, fmax, minimum, maximum);
 	Graphics_unsetInner (g);
@@ -171,7 +171,7 @@ void Spectrum_draw (Spectrum me, Graphics g, double fmin, double fmax, double mi
 	}
 }
 
-void Spectrum_drawLogFreq (Spectrum me, Graphics g, double fmin, double fmax, double minimum, double maximum, int garnish) {
+void Spectrum_drawLogFreq (Spectrum me, Graphics g, double fmin, double fmax, double minimum, double maximum, bool garnish) {
 	bool autoscaling = ( minimum >= maximum );
 	if (fmax <= fmin) {
 		fmin = my xmin;
@@ -182,7 +182,7 @@ void Spectrum_drawLogFreq (Spectrum me, Graphics g, double fmin, double fmax, do
 	if (nf == 0)
 		return;
 if(ifmin==1)ifmin=2;  /* BUG */
-	auto xbuffer = newVECzero (nf), ybuffer = newVECzero (nf);
+	auto xbuffer = zero_VEC (nf), ybuffer = zero_VEC (nf);
 	double *xWC = & xbuffer [1 - ifmin], *yWC = & ybuffer [1 - ifmin];
 
 	/*
