@@ -1,6 +1,6 @@
 /* SpectrumEditor.cpp
  *
- * Copyright (C) 1992-2011,2012,2013,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,8 @@ static void updateRange (SpectrumEditor me) {
 	if (Spectrum_getPowerDensityRange ((Spectrum) my data, & my minimum, & my maximum)) {
 		my minimum = my maximum - my p_dynamicRange;
 	} else {
-		my minimum = -1000.0, my maximum = 1000.0;
+		my minimum = -1000.0;
+		my maximum = 1000.0;
 	}
 }
 
@@ -57,26 +58,30 @@ void structSpectrumEditor :: v_draw () {
 		FunctionEditor_drawHorizontalHair (this, our cursorHeight, Melder_fixed (our cursorHeight, 1), U" dB");
 	Graphics_setColour (our graphics.get(), Melder_BLACK);
 
-	/* Update buttons. */
-
+	/*
+		Update buttons.
+		TODO: this is not about drawing, so improve the logic.
+	*/
 	integer first, last;
-	integer selectedSamples = Sampled_getWindowSamples (spectrum, our startSelection, our endSelection, & first, & last);
+	const integer selectedSamples = Sampled_getWindowSamples (spectrum, our startSelection, our endSelection, & first, & last);
 	GuiThing_setSensitive (our publishBandButton,  selectedSamples != 0);
 	GuiThing_setSensitive (our publishSoundButton, selectedSamples != 0);
 }
 
-bool structSpectrumEditor :: v_click (double xWC, double yWC, bool shiftKeyPressed) {
-	our cursorHeight = our minimum + yWC * (our maximum - our minimum);
-	return our SpectrumEditor_Parent :: v_click (xWC, yWC, shiftKeyPressed);   // move cursor or drag selection
+bool structSpectrumEditor :: v_mouseInWideDataView (GuiDrawingArea_MouseEvent event, double x_world, double y_fraction) {
+	our cursorHeight = our minimum + y_fraction * (our maximum - our minimum);
+	return our SpectrumEditor_Parent :: v_mouseInWideDataView (event, x_world, y_fraction) || true;
 }
 
 static autoSpectrum Spectrum_band (Spectrum me, double fmin, double fmax) {
 	autoSpectrum band = Data_copy (me);
 	double *re = & band -> z [1] [0], *im = & band -> z [2] [0];
-	integer imin = Sampled_xToLowIndex (band.get(), fmin);
-	integer imax = Sampled_xToHighIndex (band.get(), fmax);
-	for (integer i = 1; i <= imin; i ++) re [i] = 0.0, im [i] = 0.0;
-	for (integer i = imax; i <= band -> nx; i ++) re [i] = 0.0, im [i] = 0.0;
+	const integer imin = Sampled_xToLowIndex (band.get(), fmin);
+	const integer imax = Sampled_xToHighIndex (band.get(), fmax);
+	for (integer i = 1; i <= imin; i ++)
+		re [i] = 0.0, im [i] = 0.0;
+	for (integer i = imax; i <= band -> nx; i ++)
+		re [i] = 0.0, im [i] = 0.0;
 	return band;
 }
 
@@ -108,7 +113,8 @@ static void menu_cb_passBand (SpectrumEditor me, EDITOR_ARGS_FORM) {
 		SET_REAL (bandSmoothing, my p_bandSmoothing)
 	EDITOR_DO
 		my pref_bandSmoothing() = my p_bandSmoothing = bandSmoothing;
-		if (my endSelection <= my startSelection) Melder_throw (U"To apply a band-pass filter, first make a selection.");
+		Melder_require (my endSelection > my startSelection,
+			U"To apply a band-pass filter, first make a selection.");
 		Editor_save (me, U"Pass band");
 		Spectrum_passHannBand ((Spectrum) my data, my startSelection, my endSelection, my p_bandSmoothing);
 		FunctionEditor_redraw (me);
@@ -123,7 +129,8 @@ static void menu_cb_stopBand (SpectrumEditor me, EDITOR_ARGS_FORM) {
 		SET_REAL (bandSmoothing, my p_bandSmoothing)
 	EDITOR_DO
 		my pref_bandSmoothing () = my p_bandSmoothing = bandSmoothing;
-		if (my endSelection <= my startSelection) Melder_throw (U"To apply a band-stop filter, first make a selection.");
+		Melder_require (my endSelection > my startSelection,
+			U"To apply a band-stop filter, first make a selection.");
 		Editor_save (me, U"Stop band");
 		Spectrum_stopHannBand ((Spectrum) my data, my startSelection, my endSelection, my p_bandSmoothing);
 		FunctionEditor_redraw (me);
