@@ -1,6 +1,6 @@
 /* manual_sound.cpp
  *
- * Copyright (C) 1992-2008,2010-2012,2014-2017 Paul Boersma
+ * Copyright (C) 1992-2008,2010-2012,2014-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -205,9 +205,8 @@ INTRO (U"A command in the @@Open menu@ of the #Objects window. "
 	"If the file name is hello.wav, Praat will name the channels hello_ch1, hello_ch2, and so on.")
 MAN_END
 
-MAN_BEGIN (U"Record mono Sound...", U"ppgb", 20021212)
-INTRO (U"A command in the @@New menu@ to record a @Sound. Creates a @SoundRecorder window, "
-	"except on very old Macintoshes with 8-bit audio, where it presents a native Macintosh sound-recorder window.")
+MAN_BEGIN (U"Record mono Sound...", U"ppgb", 20201120)
+INTRO (U"A command in the @@New menu@ to record a @Sound. Creates a @SoundRecorder window.")
 MAN_END
 
 MAN_BEGIN (U"Record stereo Sound...", U"ppgb", 20021212)
@@ -731,7 +730,7 @@ NORMAL (U"For the intensity in Watt/m^2, see @@Sound: Get power in air@. For an
 	"see @@Excitation: Get loudness@.")
 MAN_END
 
-MAN_BEGIN (U"Sound: Get maximum...", U"ppgb", 20041123)
+MAN_BEGIN (U"Sound: Get maximum...", U"ppgb", 20200912)
 INTRO (U"A command available in the #Query menu if you select a @Sound object. "
 	"The Info window will show the maximum amplitude (sound pressure in Pascal) within a specified time window.")
 ENTRY (U"Settings")
@@ -739,8 +738,8 @@ TAG (U"##Time range (s)")
 DEFINITION (U"the time range (%t__1_, %t__2_). Values outside this range are ignored, except for purposes of interpolation. "
 	"If %t__1_ is not less than %t__2_, the entire time domain of the sound is considered.")
 TAG (U"##Interpolation")
-DEFINITION (U"the interpolation method (#None, #Parabolic, #Cubic, #Sinc) of the @@vector peak interpolation@. "
-	"The standard is #Sinc70 because a Sound object is normally a sampled band-limited signal, "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is “sinc70” because a Sound object is normally a sampled band-limited signal, "
 	"which can be seen as a sum of sinc functions.")
 MAN_END
 
@@ -757,7 +756,7 @@ FORMULA (U"1/(%t__2_ - %t__1_)  \\in__%%t%1_^^%%t%2^ %x(%t) %dt")
 NORMAL (U"where %x(%t) is the amplitude of the sound in Pa.")
 MAN_END
 
-MAN_BEGIN (U"Sound: Get minimum...", U"ppgb", 20041123)
+MAN_BEGIN (U"Sound: Get minimum...", U"ppgb", 20200912)
 INTRO (U"A command available in the #Query menu if you select a @Sound object. "
 	"The Info window will show the minimum amplitude (sound pressure in Pascal) within a specified time window.")
 ENTRY (U"Settings")
@@ -765,8 +764,8 @@ TAG (U"##Time range (s)")
 DEFINITION (U"the time range (%t__1_, %t__2_). Values outside this range are ignored, except for purposes of interpolation. "
 	"If %t__1_ is not less than %t__2_, the entire time domain of the sound is considered.")
 TAG (U"%%Interpolation")
-DEFINITION (U"the interpolation method (None, Parabolic, Cubic, Sinc) of the @@vector peak interpolation@. "
-	"The standard is Sinc70 because a Sound object is normally a sampled band-limited signal, "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is “sinc70” because a Sound object is normally a sampled band-limited signal, "
 	"which can be seen as a sum of sinc functions.")
 MAN_END
 
@@ -843,7 +842,7 @@ FORMULA (U"1/(%n-1) \\su__%i=%m..%m+%n-1_ (%x__%i_ - %\\mu)^2")
 NORMAL (U"where %n is the number of sample centres between %t__1_ and %t__2_. Note the \"minus 1\".")
 MAN_END
 
-MAN_BEGIN (U"Sound: Get time of maximum...", U"ppgb", 20041123)
+MAN_BEGIN (U"Sound: Get time of maximum...", U"ppgb", 20200912)
 INTRO (U"A command available in the #Query menu if you select a @Sound object. "
 	"The Info window will show the time (in seconds) associated with the maximum pressure in a specified time range.")
 ENTRY (U"Settings")
@@ -851,12 +850,12 @@ TAG (U"##Time range (s)")
 DEFINITION (U"the time range (%t__1_, %t__2_). Values outside this range are ignored, except for purposes of interpolation. "
 	"If %t__1_ is not less than %t__2_, the entire time domain of the sound is considered.")
 TAG (U"##Interpolation")
-DEFINITION (U"the interpolation method (#None, #Parabolic, #Cubic, #Sinc) of the @@vector peak interpolation@. "
-	"The standard is #Sinc70 because a Sound object is normally a sampled band-limited signal, "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is “sinc70” because a Sound object is normally a sampled band-limited signal, "
 	"which can be seen as a sum of sinc functions.")
 MAN_END
 
-MAN_BEGIN (U"Sound: Get time of minimum...", U"ppgb", 20041107)
+MAN_BEGIN (U"Sound: Get time of minimum...", U"ppgb", 20200912)
 INTRO (U"A command available in the #Query menu if you select a @Sound object. "
 	"The Info window will show the time (in seconds) associated with the minimum pressure in a specified time range.")
 ENTRY (U"Settings")
@@ -864,8 +863,8 @@ TAG (U"##Time range (s)")
 DEFINITION (U"the time range (%t__1_, %t__2_). Values outside this range are ignored, except for purposes of interpolation. "
 	"If %t__1_ is not less than %t__2_, the entire time domain of the sound is considered.")
 TAG (U"##Interpolation")
-DEFINITION (U"the interpolation method (#None, #Parabolic, #Cubic, #Sinc) of the @@vector peak interpolation@. "
-	"The standard is #Sinc70 because a Sound object is normally a sampled band-limited signal, "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is “sinc70” because a Sound object is normally a sampled band-limited signal, "
 	"which can be seen as a sum of sinc functions.")
 MAN_END
 
@@ -878,7 +877,7 @@ TAG (U"##Sample number")
 DEFINITION (U"the sample number at which the value is to be evaluated.")
 MAN_END
 
-MAN_BEGIN (U"Sound: Get value at time...", U"ppgb", 20030916)
+MAN_BEGIN (U"Sound: Get value at time...", U"ppgb", 20200912)
 INTRO (U"A command available in the #Query menu if you select a @Sound object. "
 	"The Info window will show an estimate of the amplitude (sound pressure in Pascal) at a specified time. "
 	"If that time is outside the samples of the Sound, the result is equal to the value of the nearest sample; "
@@ -888,7 +887,7 @@ TAG (U"##Time (s)")
 DEFINITION (U"the time at which the value is to be evaluated.")
 TAG (U"##Interpolation")
 DEFINITION (U"the interpolation method, see @@vector value interpolation@. "
-	"The standard is #Sinc70 because a Sound object is normally a sampled band-limited signal, "
+	"The standard is “sinc70” because a Sound object is normally a sampled band-limited signal, "
 	"which can be seen as a sum of sinc functions.")
 MAN_END
 
@@ -907,12 +906,14 @@ ENTRY (U"Algorithm")
 NORMAL (U"@@overlap-add@.")
 MAN_END
 
-MAN_BEGIN (U"audio control panel", U"ppgb", 20050822)
-INTRO (U"Your system's way of controlling where sounds will be played, and how loud.")
-NORMAL (U"On Windows, double-click the loudspeaker icon in the Start bar. "
-	"On MacOS X, go to ##System Preferences#, then to #Sound, then to ##Output Volume# "
-	"(you can put a loudspeaker icon in OSX's menu bar here). "
-	"On HP-UX, try the ##Use internal loudspeaker...# preference in Praat's #Preferences menu.")
+MAN_BEGIN (U"audio control panel", U"ppgb", 20201230)
+INTRO (U"Your platform's way of controlling where sounds will be played, and how loud.")
+NORMAL (U"On macOS X or 11, go to the Apple menu, then to ##System Preferences#, then to #Sound, then to #Output "
+	"(you can put a loudspeaker icon in the menu bar here). "
+	"On Ubuntu Linux 18.04 or 20.04, go to the left side bar, then to #Settings, then to #Sound, then to #Output "
+	"(a loudspeaker icon can be in the menu bar). "
+	"On Windows 10, it lies somewhat deeper: "
+	"go to the Start icon, then to #Settings, then to #System, then to #Sound, then to #Output.")
 MAN_END
 
 MAN_BEGIN (U"Sound: Play", U"ppgb", 20050822)
@@ -1028,7 +1029,7 @@ NORMAL (U"To synchronize a SoundEditor window with other windows that show a tim
 	"You cannot Cut from or Paste into a synchronized SoundEditor window.")
 MAN_END
 
-MAN_BEGIN (U"SoundRecorder", U"ppgb", 20110129)
+MAN_BEGIN (U"SoundRecorder", U"ppgb", 20201120)
 INTRO (U"With the Praat SoundRecorder window you can record a mono or stereo sound "
 	"for subsequent viewing and analysis in Praat. "
 	"The SoundRecorder appears on your screen if you choose @@Record mono Sound...@ or @@Record stereo Sound...@ "
@@ -1050,29 +1051,24 @@ NORMAL (U"The size of the recording buffer determines how many seconds of sound
 	"or 110 seconds in stereo (220 seconds in mono) at a sampling frequency of 44100 Hz. "
 	"You can change the size of the recording buffer "
 	"with ##Sound input prefs...# from the Preferences menu.")
-NORMAL (U"If you recorded a very long sound, it is probable that you cannot copy it to the list of objects. "
-	"In such a case, you can still write the sound to disk with one of the #Save commands in the #File menu. "
-	"You can then open such a long sound file in Praat with @@Open long sound file...@ from the Open menu.")
-#ifdef macintosh
-ENTRY (U"Recording sounds on MacOS X")
-NORMAL (U"You can record from the combined microphone / line input. On some computers, these are separate.")
-NORMAL (U"Note that in MacOS X you cannot record from the internal CD. This is because the system provides you with something better. "
-	"If you open the CD in the Finder, you will see the audio tracks as AIFC files! "
-	"To open these audio tracks in Praat, use @@Read from file...@ or @@Open long sound file...@.")
-#endif
-#ifdef _WIN32
-ENTRY (U"Recording sounds in Windows")
-NORMAL (U"In Windows, you can choose your input device with the help of the recording mixer that is supplied by Windows or comes with "
-	"your sound card. There will usually be a loudspeaker icon in the Start bar; double-click it, and you will see the %playing mixer "
-	"(if there is no loudspeaker icon, go to ##Control Panels#, then ##Sounds and Audio Devices#, then #Volume, then #Advanced; "
-	"do not blame us for how Windows XP works). In the playing mixer, choose #Properties from the #Option menu, then click #Recording, "
-	"then #OK. You are now in the %recording mixer.")
-NORMAL (U"You can watch the input level only while recording.")
-#endif
+ENTRY (U"Recording sounds on the Mac or in Linux")
+NORMAL (U"On the Mac or in Linux, you can record from the list on the left in the SoundRecorder window. "
+	"The list can contain several devices, such as the internal microphone, a line input, or external USB devices. "
+	"Audio tracks on a CD can be opened directly with @@Read from file...@ or @@Open long sound file...@.")
+ENTRY (U"Recording sounds in Windows 10")
+NORMAL (U"In Windows 10, you can choose your input device by right-clicking on the loudspeaker icon in the Start bar; "
+	"then ##Open Sound settings#, then ##Choose your input device#. "
+	"To set some input #Properties, right-click the loudspeaker icon, then #Sounds, then #Recording.")
+ENTRY (U"Watching the input level")
+NORMAL (U"While recording, you can watch the input level as a green rectangle whose size changes. "
+	"Whenever the input is loud, the top of the rectangle becomes yellow; if it turns red, the sound may have been clipped. "
+	"In the Meter menu you cna choose other visualizations, "
+	"such as a moving ball that measures spectral centre of gravity (horizontally) versus intensity (vertically).")
 ENTRY (U"The File menu")
-NORMAL (U"If your computer has little memory, a very long recorded sound can be too big to be copied to the list of objects. "
+NORMAL (U"If your computer has little memory, a very long recorded sound might be too big to be copied to the list of objects. "
 	"Fortunately, the File menu contains commands to save the recording "
-	"to a sound file on disk, so that you will never have to lose your recording.")
+	"to a sound file on disk, so that you will never have to lose your recording. "
+	"You can later open such a long sound file in Praat with @@Open long sound file...@ from the Open menu.")
 ENTRY (U"Sound pressure calibration")
 NORMAL (U"Your computer's sound-recording software returns integer values between -32768 and 32767. "
 	"Praat divides them by 32768 before putting them into a Sound object, "
