@@ -1,6 +1,6 @@
 /* manual_spectrum.cpp
  *
- * Copyright (C) 1992-2008,2010,2012,2014-2017 Paul Boersma
+ * Copyright (C) 1992-2008,2010-2012,2014-2017,2019,2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,27 +20,55 @@
 
 #include "Sound.h"
 
-static void draw_SpectrumHann (Graphics g, double f1, double f2, bool stop, int garnish) {
+enum class Decoration {
+	None,
+	Minimal,
+	Fancy,
+};
+
+static void draw_SpectrumHann (Graphics g, double f1, double f2, bool stop, Decoration garnish) {
 	try {
-		double fmin = garnish == 1 ? 300 : 0, fmax = garnish == 1 ? 1300 : 4000, df = garnish == 1 ? 1 : 4;
+		const double fmin = ( garnish == Decoration::Fancy ? 300 : 0 );
+		const double fmax = ( garnish == Decoration::Fancy ? 1300 : 4000 );
+		const double df = ( garnish == Decoration::Fancy ? 1 : 4 );
 		autoSound me = Sound_create (1, fmin, fmax, (long) floor ((fmax - fmin) / df) + 1, df, fmin);
-		double w = 100, f1left = f1 - w, f1right = f1 + w, f2left = f2 - w, f2right = f2 + w, halfpibysmooth = NUMpi / (w + w);
+		constexpr double w = 100.0;
+		const double f1left = f1 - w, f1right = f1 + w, f2left = f2 - w, f2right = f2 + w;
+		constexpr double halfpibysmooth = NUMpi / (w + w);
 		Graphics_setWindow (g, fmin, fmax, -0.1, 1.1);
-		for (int i = 1; i <= my nx; i ++) {
-			double f = my x1 + (i - 1) * my dx;
-			my z [1] [i] = f < f1left ? 0.0 : f < f1right ? ( f1 > 0.0 ? 0.5 - 0.5 * cos (halfpibysmooth * (f - f1left)) : 1.0 ) :
-				f < f2left ? 1.0 : f < f2right ? ( f2 < fmax ? 0.5 + 0.5 * cos (halfpibysmooth * (f - f2left)) : 1.0 ) : 0.0;
+		for (integer i = 1; i <= my nx; i ++) {
+			const double f = my x1 + (i - 1) * my dx;
+			my z [1] [i] = (
+				f < f1left ?
+					0.0
+				: f < f1right ?
+					( f1 > 0.0 ? 0.5 - 0.5 * cos (halfpibysmooth * (f - f1left)) : 1.0 )
+				: f < f2left ?
+					1.0
+				: f < f2right ?
+					( f2 < fmax ? 0.5 + 0.5 * cos (halfpibysmooth * (f - f2left)) : 1.0 )
+				:
+					0.0
+			);
 		}
 		if (stop)
-			for (int i = 1; i <= my nx; i ++)
+			for (integer i = 1; i <= my nx; i ++)
 				my z [1] [i] = 1.0 - my z [1] [i];
-		if (garnish) {
+		if (garnish != Decoration::None) {
 			Graphics_drawInnerBox (g);
 			Graphics_textLeft (g, true, U"Amplitude filter %H (%f)");
 			Graphics_markLeft (g, 0.0, true, true, false, nullptr);
 			Graphics_markLeft (g, 1.0, true, true, false, nullptr);
 		}
-		if (garnish == 1) {
+		if (garnish == Decoration::Minimal) {
+			Graphics_textBottom (g, true, U"Frequency %f (Hz)");
+			Graphics_markBottom (g, 0.0, true, true, false, nullptr);
+			Graphics_markBottom (g, 500.0, true, true, false, nullptr);
+			Graphics_markBottom (g, 1000.0, true, true, false, nullptr);
+			Graphics_markBottom (g, 2000.0, true, true, false, nullptr);
+			Graphics_markBottom (g, 4000.0, true, true, false, nullptr);
+		}
+		if (garnish == Decoration::Fancy) {
 			Graphics_textBottom (g, true, U"Frequency %f");
 			Graphics_markBottom (g, f1left, false, true, true, U"%f__1_-%w");
 			Graphics_markBottom (g, f1, false, true, true, U"%f__1_");
@@ -52,14 +80,6 @@ static void draw_SpectrumHann (Graphics g, double f1, double f2, bool stop, int
 			Graphics_markLeft (g, 0.5, true, true, true, nullptr);
 			Graphics_markRight (g, 0.5, false, true, false, U"-6 dB");
 		}
-		if (garnish == 2) {
-			Graphics_textBottom (g, true, U"Frequency %f (Hz)");
-			Graphics_markBottom (g, 0.0, true, true, false, nullptr);
-			Graphics_markBottom (g, 500.0, true, true, false, nullptr);
-			Graphics_markBottom (g, 1000.0, true, true, false, nullptr);
-			Graphics_markBottom (g, 2000.0, true, true, false, nullptr);
-			Graphics_markBottom (g, 4000.0, true, true, false, nullptr);
-		}
 		Graphics_setColour (g, stop ? Melder_BLUE : Melder_RED);
 		Sound_draw (me.get(), g, 0.0, 0.0, -0.1, 1.1, false, U"curve");
 		Graphics_setColour (g, Melder_BLACK);
@@ -68,18 +88,20 @@ static void draw_SpectrumHann (Graphics g, double f1, double f2, bool stop, int
 	}
 }
 static void draw_SpectrumPassHann (Graphics g) {
-	draw_SpectrumHann (g, 500.0, 1000.0, false, 1);
+	draw_SpectrumHann (g, 500.0, 1000.0, false, Decoration::Fancy);
 }
 static void draw_SpectrumPassHann_decompose (Graphics g) {
-	draw_SpectrumHann (g, 0.0, 500.0, false, 2);
-	draw_SpectrumHann (g, 500, 1000, false, 0);
-	draw_SpectrumHann (g, 1000, 2000, false, 0);
-	draw_SpectrumHann (g, 2000, 4000, false, 0);
+	draw_SpectrumHann (g, 0.0, 500.0, false, Decoration::Minimal);
+	draw_SpectrumHann (g, 500, 1000, false, Decoration::None);
+	draw_SpectrumHann (g, 1000, 2000, false, Decoration::None);
+	draw_SpectrumHann (g, 2000, 4000, false, Decoration::None);
+}
+static void draw_SpectrumStopHann (Graphics g) {
+	draw_SpectrumHann (g, 500, 1000, true, Decoration::Fancy);
 }
-static void draw_SpectrumStopHann (Graphics g) { draw_SpectrumHann (g, 500, 1000, 1, 1); }
 static void draw_SpectrumStopHann_decompose (Graphics g) {
-	draw_SpectrumHann (g, 500.0, 1000.0, false, 2);
-	draw_SpectrumHann (g, 500.0, 1000.0, true, 0);
+	draw_SpectrumHann (g, 500.0, 1000.0, false, Decoration::Minimal);
+	draw_SpectrumHann (g, 500.0, 1000.0, true, Decoration::None);
 }
 
 void manual_spectrum_init (ManPages me);
@@ -144,7 +166,7 @@ NORMAL (U"where %f__1_ is the frequency associated with the centre of the first
 	"and Δ%f is the bin width.")
 MAN_END
 
-MAN_BEGIN (U"Ltas: Get frequency of maximum...", U"ppgb", 20110701)
+MAN_BEGIN (U"Ltas: Get frequency of maximum...", U"ppgb", 20200912)
 INTRO (U"A @query to the selected @Ltas object.")
 ENTRY (U"Return value")
 NORMAL (U"the frequency (in hertz) associated with the maximum energy density.")
@@ -155,13 +177,13 @@ DEFINITION (U"the selected frequency domain. Values outside this domain are igno
 	"If ##To frequency# is not greater than ##From frequency#, "
 	"the entire frequency domain of the Ltas object is considered.")
 TAG (U"##Interpolation")
-DEFINITION (U"the interpolation method (#None, #Parabolic, #Cubic, #Sinc) of the @@vector peak interpolation@. "
-	"The standard is #None because of the usual large binning. "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is #none because of the usual large binning. "
 	"If the Ltas was computed with @@Spectrum: To Ltas (1-to-1)@, "
-	"a #Parabolic or #Cubic interpolation would be more appropriate.")
+	"a #parabolic or #cubic interpolation would be more appropriate.")
 MAN_END
 
-MAN_BEGIN (U"Ltas: Get frequency of minimum...", U"ppgb", 20030916)
+MAN_BEGIN (U"Ltas: Get frequency of minimum...", U"ppgb", 20200912)
 INTRO (U"A @query to the selected @Ltas object.")
 ENTRY (U"Return value")
 NORMAL (U"the frequency (in hertz) associated with the minimum energy density.")
@@ -170,10 +192,10 @@ TAG (U"##Time range (s)")
 DEFINITION (U"the time range (%t__1_, %t__2_). Values outside this range are ignored. "
 	"If %t__1_ is not less than %t__2_, the entire frequency domain of the Ltas is considered.")
 TAG (U"%%Interpolation")
-DEFINITION (U"the interpolation method (None, Parabolic, Cubic, Sinc) of the @@vector peak interpolation@. "
-	"The standard is None because of the usual large binning. "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc) of the @@vector peak interpolation@. "
+	"The standard is #none because of the usual large binning. "
 	"If the Ltas was computed with @@Spectrum: To Ltas (1-to-1)@, "
-	"a Parabolic or Cubic interpolation would be more appropriate.")
+	"a #parabolic or #cubic interpolation would be more appropriate.")
 MAN_END
 
 MAN_BEGIN (U"Ltas: Get highest frequency", U"ppgb", 20041122)
@@ -188,7 +210,7 @@ ENTRY (U"Return value")
 NORMAL (U"the lowest frequency, expressed in Hertz. It is usually 0 Hz.")
 MAN_END
 
-MAN_BEGIN (U"Ltas: Get maximum...", U"ppgb", 20101228)
+MAN_BEGIN (U"Ltas: Get maximum...", U"ppgb", 20200912)
 INTRO (U"A @query to the selected @Ltas object.")
 ENTRY (U"Return value")
 NORMAL (U"the maximum value (in dB) within a specified frequency range.")
@@ -199,10 +221,10 @@ DEFINITION (U"the selected frequency domain. Values outside this domain are igno
 	"If %%To frequency% is not greater than %%From frequency%, "
 	"the entire frequency domain of the Ltas object is considered.")
 TAG (U"%%Interpolation")
-DEFINITION (U"the interpolation method (#None, #Parabolic, #Cubic, #Sinc) of the @@vector peak interpolation@. "
-	"The standard is #None because of the usual large binning. "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is #none because of the usual large binning. "
 	"If the Ltas was computed with @@Spectrum: To Ltas (1-to-1)@, "
-	"a Parabolic or Cubic interpolation would be more appropriate.")
+	"a #parabolic or #cubic interpolation would be more appropriate.")
 MAN_END
 
 MAN_BEGIN (U"Ltas: Get mean...", U"ppgb", 20041122)
@@ -223,7 +245,7 @@ FORMULA (U"1/%n ∑__%i=%m..%m+%n-1_ %x__%i_")
 NORMAL (U"where %n is the number of band centres between %f__1_ and %f__2_.")
 MAN_END
 
-MAN_BEGIN (U"Ltas: Get minimum...", U"ppgb", 20030916)
+MAN_BEGIN (U"Ltas: Get minimum...", U"ppgb", 20200912)
 INTRO (U"A @query to the selected @Ltas object.")
 ENTRY (U"Return value")
 NORMAL (U"the minimum value (in dB) within a specified frequency range.")
@@ -234,10 +256,10 @@ DEFINITION (U"the selected frequency domain. Values outside this domain are igno
 	"If ##To frequency# is not greater than ##From frequency#, "
 	"the entire frequency domain of the Ltas object is considered.")
 TAG (U"%%Interpolation")
-DEFINITION (U"the interpolation method (#None, #Parabolic, #Cubic, #Sinc) of the @@vector peak interpolation@. "
-	"The standard is #None because of the usual large binning. "
+DEFINITION (U"the interpolation method (#none, #parabolic, #cubic, #sinc70, #sinc700) of the @@vector peak interpolation@. "
+	"The standard is #none because of the usual large binning. "
 	"If the Ltas was computed with @@Spectrum: To Ltas (1-to-1)@, "
-	"a #Parabolic or #Cubic interpolation would be more appropriate.")
+	"a #parabolic or #cubic interpolation would be more appropriate.")
 MAN_END
 
 MAN_BEGIN (U"Ltas: Get number of bins", U"ppgb", 20041122)
