@@ -25,6 +25,7 @@
 #include "NoulliGridEditor.h"
 
 #include "praat_TableOfReal.h"
+#include "praat_TimeFunction.h"
 
 #undef iam
 #define iam iam_LOOP
@@ -482,8 +483,7 @@ FORM (STRING_OTGrammar_getConstraint, U"Get constraint name", nullptr) {
 	OK
 DO
 	STRING_ONE (OTGrammar)
-		if (constraintNumber > my numberOfConstraints)
-			Melder_throw (U"The specified constraint number should not exceed the number of constraints.");
+		my checkConstraintNumber (constraintNumber);
 		const conststring32 result = my constraints [constraintNumber]. name.get();
 	STRING_ONE_END
 }
@@ -493,8 +493,7 @@ FORM (REAL_OTGrammar_getRankingValue, U"Get ranking value", nullptr) {
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (constraintNumber > my numberOfConstraints)
-			Melder_throw (U"The specified constraint number should not exceed the number of constraints.");
+		my checkConstraintNumber (constraintNumber);
 		const double result = my constraints [constraintNumber]. ranking;
 	NUMBER_ONE_END (U" (ranking of constraint ", constraintNumber, U")")
 }
@@ -504,8 +503,7 @@ FORM (REAL_OTGrammar_getDisharmony, U"Get disharmony", nullptr) {
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (constraintNumber > my numberOfConstraints)
-			Melder_throw (U"The specified constraint number should not exceed the number of constraints.");
+		my checkConstraintNumber (constraintNumber);
 		const double result = my constraints [constraintNumber]. disharmony;
 	NUMBER_ONE_END (U" (disharmony of constraint ", constraintNumber, U")")
 }
@@ -521,8 +519,7 @@ FORM (STRING_OTGrammar_getInput, U"Get input", nullptr) {
 	OK
 DO
 	STRING_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
+		my checkTableauNumber (tableauNumber);
 		const conststring32 result = my tableaus [tableauNumber]. input.get();
 	STRING_ONE_END
 }
@@ -532,8 +529,7 @@ FORM (INTEGER_OTGrammar_getNumberOfCandidates, U"Get number of candidates", null
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
+		my checkTableauNumber (tableauNumber);
 		const integer result = my tableaus [tableauNumber]. numberOfCandidates;
 	NUMBER_ONE_END (U" candidates in tableau ", tableauNumber)
 }
@@ -544,12 +540,8 @@ FORM (STRING_OTGrammar_getCandidate, U"Get candidate", nullptr) {
 	OK
 DO
 	STRING_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
-		OTGrammarTableau tableau = & my tableaus [tableauNumber];
-		if (candidateNumber > tableau -> numberOfCandidates)
-			Melder_throw (U"The specified candidate should not exceed the number of candidates.");
-		const conststring32 result = tableau -> candidates [candidateNumber]. output.get();
+		my checkTableauAndCandidateNumber (tableauNumber, candidateNumber);
+		const conststring32 result = my tableaus [tableauNumber]. candidates [candidateNumber]. output.get();
 	STRING_ONE_END
 }
 
@@ -560,12 +552,8 @@ FORM (INTEGER_OTGrammar_getNumberOfViolations, U"Get number of violations", null
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
-		if (candidateNumber > my tableaus [tableauNumber]. numberOfCandidates)
-			Melder_throw (U"The specified candidate should not exceed the number of candidates.");
-		if (constraintNumber > my numberOfConstraints)
-			Melder_throw (U"The specified constraint number should not exceed the number of constraints.");
+		my checkTableauAndCandidateNumber (tableauNumber, candidateNumber);
+		my checkConstraintNumber (constraintNumber);
 		const integer result = my tableaus [tableauNumber]. candidates [candidateNumber]. marks [constraintNumber];
 	NUMBER_ONE_END (U" violations")
 }
@@ -577,8 +565,7 @@ FORM (INTEGER_OTGrammar_getWinner, U"Get winner", nullptr) {
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
+		my checkTableauNumber (tableauNumber);
 		const integer result = OTGrammar_getWinner (me, tableauNumber);
 	NUMBER_ONE_END (U" (winner in tableau ", tableauNumber, U")")
 }
@@ -591,14 +578,8 @@ FORM (INTEGER_OTGrammar_compareCandidates, U"Compare candidates", nullptr) {
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber1 > my numberOfTableaus)
-			Melder_throw (U"The specified tableau (number 1) should not exceed the number of tableaus.");
-		if (candidateNumber1 > my tableaus [tableauNumber1]. numberOfCandidates)
-			Melder_throw (U"The specified candidate (number 1) should not exceed the number of candidates for this tableau.");
-		if (tableauNumber2 > my numberOfTableaus)
-			Melder_throw (U"The specified tableau (number 2) should not exceed the number of tableaus.");
-		if (candidateNumber2 > my tableaus [tableauNumber2]. numberOfCandidates)
-			Melder_throw (U"The specified candidate (number 2) should not exceed the number of candidates for this tableau.");
+		my checkTableauAndCandidateNumber (tableauNumber1, candidateNumber1);
+		my checkTableauAndCandidateNumber (tableauNumber2, candidateNumber2);
 		const integer result = OTGrammar_compareCandidates (me, tableauNumber1, candidateNumber1, tableauNumber2, candidateNumber2);
 	NUMBER_ONE_END (result == -1 ? U" (candidate 1 is better)" :
 					result == +1 ? U" (candidate 2 is better)" : U" (candidates are equally good)")
@@ -609,8 +590,7 @@ FORM (INTEGER_OTGrammar_getNumberOfOptimalCandidates, U"Get number of optimal ca
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
+		my checkTableauNumber (tableauNumber);
 		const integer result = OTGrammar_getNumberOfOptimalCandidates (me, tableauNumber);
 	NUMBER_ONE_END (U" optimal candidates in tableau ", tableauNumber)
 }
@@ -621,10 +601,7 @@ FORM (BOOLEAN_OTGrammar_isCandidateGrammatical, U"Is candidate grammatical?", nu
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
-		if (candidateNumber > my tableaus [tableauNumber]. numberOfCandidates)
-			Melder_throw (U"The specified candidate should not exceed the number of candidates.");
+		my checkTableauAndCandidateNumber (tableauNumber, candidateNumber);
 		const integer result = OTGrammar_isCandidateGrammatical (me, tableauNumber, candidateNumber);
 	NUMBER_ONE_END (result ? U" (grammatical)" : U" (ungrammatical)")
 }
@@ -635,10 +612,7 @@ FORM (BOOLEAN_OTGrammar_isCandidateSinglyGrammatical, U"Is candidate singly gram
 	OK
 DO
 	NUMBER_ONE (OTGrammar)
-		if (tableauNumber > my numberOfTableaus)
-			Melder_throw (U"The specified tableau number should not exceed the number of tableaus.");
-		if (candidateNumber > my tableaus [tableauNumber]. numberOfCandidates)
-			Melder_throw (U"The specified candidate should not exceed the number of candidates.");
+		my checkTableauAndCandidateNumber (tableauNumber, candidateNumber);
 		const integer result = OTGrammar_isCandidateSinglyGrammatical (me, tableauNumber, candidateNumber);
 	NUMBER_ONE_END (result ? U" (singly grammatical)" : U" (not singly grammatical)")
 }
@@ -1756,6 +1730,17 @@ DIRECT (WINDOW_NoulliGrid_viewAndEdit) {
 	END
 }
 
+FORM (NUMVEC_NoulliGrid_getAverageProbabilities, U"NoulliGrid: Get average probabilities", nullptr) {
+	NATURAL (tierNumber, U"Tier number", U"1")
+	REAL (fromTime, U"From time (s)", U"0")
+	REAL (toTime, U"To time (s)", U"0 (= all)")
+	OK
+DO
+	NUMVEC_ONE (NoulliGrid)
+		autoVEC result = NoulliGrid_getAverageProbabilities (me, tierNumber, fromTime, toTime);
+	NUMVEC_ONE_END
+}
+
 // MARK: - buttons
 
 void praat_uvafon_gram_init ();
@@ -1947,6 +1932,9 @@ void praat_uvafon_gram_init () {
 	praat_addAction2 (classNet, 1, classPatternList, 1, U"To ActivationList", nullptr, 0, NEW1_Net_PatternList_to_ActivationList);
 
 	praat_addAction1 (classNoulliGrid, 1, U"View & Edit", nullptr, praat_ATTRACTIVE, WINDOW_NoulliGrid_viewAndEdit);
+	praat_addAction1 (classNoulliGrid, 0, U"Query -", nullptr, 0, nullptr);
+	praat_TimeFunction_query_init (classNoulliGrid);
+	praat_addAction1 (classNoulliGrid, 1, U"Get average probabilities...", nullptr, 1, NUMVEC_NoulliGrid_getAverageProbabilities);
 	praat_addAction2 (classNoulliGrid, 1, classSound, 1, U"View & Edit", nullptr, praat_ATTRACTIVE, WINDOW_NoulliGrid_viewAndEdit);
 }
 
