@@ -44,8 +44,10 @@ struct MelderArg {
 	*/
 	MelderArg (constVECVU const&         arg) : _arg (Melder_VEC             (arg)) { }
 	MelderArg (constMATVU const&         arg) : _arg (Melder_MAT             (arg)) { }
+	MelderArg (constSTRVEC const&        arg) : _arg (Melder_STRVEC          (arg)) { }
 	MelderArg (VECVU const&              arg) : _arg (Melder_VEC             (arg)) { }
 	MelderArg (MATVU const&              arg) : _arg (Melder_MAT             (arg)) { }
+	MelderArg (STRVEC const&             arg) : _arg (Melder_STRVEC          (arg)) { }
 	MelderArg (Thing                     arg) : _arg (Thing_messageName      (arg)) { }
 	MelderArg (MelderFile                arg) : _arg (MelderFile_messageName (arg)) { }
 	/*
@@ -58,7 +60,7 @@ struct MelderArg {
 	*/
 };
 
-inline static integer MelderArg__length (const MelderArg& arg) {
+inline integer MelderArg__length (const MelderArg& arg) {
 	return arg._arg ? str32len (arg._arg) : 0;
 }
 template <typename... Args>
