@@ -27,16 +27,16 @@
 		- automatically convert numbers, objects, file names, vectors, and matrices to strings
 */
 
-typedef struct {
+struct MelderString16 {
 	int64 length = 0;
 	int64 bufferSize = 0;
 	char16 *string = nullptr;   // a growing buffer, rarely shrunk (can only be freed by MelderString16_free)
-} MelderString16;
-typedef struct {
+};
+struct MelderString {
 	int64 length = 0;
 	int64 bufferSize = 0;
 	char32 *string = nullptr;   // a growing buffer, rarely shrunk (can only be freed by MelderString_free)
-} MelderString;
+};
 
 void MelderString16_free (MelderString16 *me);   // frees the buffer (and sets other attributes to zero)
 void MelderString_free (MelderString *me);   // frees the buffer (and sets other attributes to zero)
@@ -45,7 +45,7 @@ void MelderString_empty (MelderString *me);   // sets to empty string (buffer sh
 void MelderString_expand (MelderString *me, int64 sizeNeeded);   // increases the buffer size; there's normally no need to call this
 void MelderString_ncopy (MelderString *me, conststring32 source, int64 n);
 
-inline static void _recursiveTemplate_MelderString_append (MelderString *me, const MelderArg& arg) {
+inline void _recursiveTemplate_MelderString_append (MelderString *me, const MelderArg& arg) {
 	if (arg._arg) {
 		const char32 *newEndOfStringLocation = stp32cpy (& my string [my length], arg._arg);   // this will append a null character
 		my length = newEndOfStringLocation - & my string [0];
