@@ -30,7 +30,7 @@
 	#include <fcntl.h>
 	#include <unistd.h>
 	#if defined HAVE_PULSEAUDIO
-		#include <pulse/pulseaudio.h>
+		#include "melder_audio_pulse.h"
 	#endif
 	#if ! defined (NO_AUDIO)
 		#if defined (__OpenBSD__) || defined (__NetBSD__)
@@ -142,39 +142,6 @@ bool MelderAudio_hasBeenInitialized;
 
 static double theStartingTime = 0.0;
 
-#define PA_GETTINGINFO 1
-#define PA_GETTINGINFO_DONE 2
-#define PA_WRITING 4
-#define PA_WRITING_DONE 8
-#define PA_RECORDING 16
-#define PA_RECORDING_DONE 32
-#define PA_QUERY_NUMBEROFCHANNELS 64
-#define PA_QUERY_NUMBEROFCHANNELS_DONE 128
-
-#ifdef HAVE_PULSEAUDIO
-typedef struct pulseAudio {
-	pa_sample_spec sample_spec;
-	pa_threaded_mainloop *mainloop = nullptr;
-	pa_mainloop_api *mainloop_api = nullptr;
-	pa_context *context = nullptr;
-	pa_stream *stream = nullptr;
-	pa_operation *operation_drain = nullptr;
-	pa_operation *operation_info = nullptr;
-	pa_stream_flags_t stream_flags;
-	const pa_timing_info *timing_info = nullptr;
-	struct timeval startTime = {0, 0};
-	pa_usec_t timer_event_usec = 50000; // 50 ms
-	pa_time_event *timer_event = nullptr;
-	const pa_channel_map *channel_map = nullptr;
-	pa_usec_t r_usec;
-	pa_buffer_attr buffer_attr;
-	uint32 latency = 0; // in bytes of buffer
-	int32 latency_msec = 20;
-	bool pulseAudioInitialized = false;
-	unsigned int occupation = PA_WRITING;
-} pulseAudioStruct;
-#endif
-
 static struct MelderPlay {
 	int16 *playBuffer;
 	integer sampleRate, numberOfSamples, samplesLeft, samplesSent, samplesPlayed;
@@ -663,7 +630,7 @@ void pulseAudio_server_info_cb (pa_context *context, const pa_server_info *info,
 }
 
 void pulseAudio_serverReport () {
-	// TODO: initiaize context
+	// TODO: initialize context
 	struct MelderPlay *me = & thePlay;
 	if (my pulseAudio.mainloop) {
 		pa_threaded_mainloop_lock (my pulseAudio.mainloop);
@@ -687,8 +654,8 @@ void pulseAudio_serverReport () {
 		my pulseAudio.occupation |= PA_GETTINGINFO;
 		pulseAudio_initialize ();
 		/*
-		 * First acquire a lock because the operation to get server info (in context_state_cb) may not have started yet.
-		 * We therefore use our own signaling and wait until information has been acquired.
+			First acquire a lock because the operation to get server info (in context_state_cb) may not have started yet.
+			We therefore use our own signaling and wait until information has been acquired.
 		 */
 		pa_threaded_mainloop_lock (my pulseAudio.mainloop);
 
