@@ -69,7 +69,7 @@ the behaviour of Praat will temporarily change in the following ways:
 37: debug autoThing
 39: debug autostring
 40: debug Thing_new
-41: OTGrammar_getWinner: always first choice rather than random choice 
+41: OTGrammar_getWinner: always first choice rather than random choice
 42: OTGrammar_getWinner: always last choice rather than random choice
 43: trace class table initialization
 44: trace Collection
@@ -82,6 +82,9 @@ the behaviour of Praat will temporarily change in the following ways:
 51: compute sum, mean, stdev with two cycles, as in R (80 bits)
 (other numbers than 48-51: compute sum, mean, stdev with simple pairwise algorithm, base case 64 [80 bits])
 52: debug Discriminant_TableOfReal_to_ClassificationTable
+53: trace running cursor
+54: ignore gdk_cairo_reset_clip
+55: trace Gui init, draw, destroy
 181: read and write native-endian real64
 900: use DG Meta Serif Science instead of Palatino
 1264: Mac: Sound_record_fixedTime uses microphone "FW Solo (1264)"
