@@ -1,6 +1,6 @@
-/* NUMsort.cpp
+/* melder_sort.cpp
  *
- * Copyright (C) 1992-2011,2015,2017-2019 Paul Boersma
+ * Copyright (C) 1992-2011,2015,2017-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,27 @@
 
 #include "melder.h"
 
-void VECsort_inplace (VECVU const& x) noexcept {
+void shuffle_VEC_inout (VECVU const& x) noexcept {
+	for (integer i = 1; i < x.size; i ++)
+		std::swap (x [i], x [NUMrandomInteger (i, x.size)]);
+}
+
+void shuffle_INTVEC_inout (INTVECVU const& x) noexcept {
+	for (integer i = 1; i < x.size; i ++)
+		std::swap (x [i], x [NUMrandomInteger (i, x.size)]);
+}
+
+void shuffle_STRVEC_inout (STRVEC const& x) noexcept {
+	for (integer i = 1; i < x.size; i ++)
+		std::swap (x [i], x [NUMrandomInteger (i, x.size)]);
+}
+autoSTRVEC shuffle_STRVEC (STRVEC const& x) {
+	autoSTRVEC result = newSTRVECcopy (x);
+	shuffle_STRVEC_inout (result.get());
+	return result;
+}
+
+void sort_VEC_inout (VECVU const& x) noexcept {
 	std::sort (x.begin(), x.end(),
 		[] (double first, double last) {
 			return first < last;
@@ -26,7 +46,7 @@ void VECsort_inplace (VECVU const& x) noexcept {
 	);
 }
 
-void INTVECsort_inplace (INTVECVU const& x) noexcept {
+void sort_INTVEC_inout (INTVECVU const& x) noexcept {
 	std::sort (x.begin(), x.end(),
 		[] (integer first, integer last) {
 			return first < last;
@@ -34,13 +54,18 @@ void INTVECsort_inplace (INTVECVU const& x) noexcept {
 	);
 }
 
-void STRVECsort_inplace (STRVEC const& array) {
+void sort_STRVEC_inout (STRVEC const& array) noexcept {
 	std::sort (array.begin(), array.end(),
 		[] (conststring32 first, conststring32 last) {
 			return str32cmp (first, last) < 0;
 		}
 	);
 }
+autoSTRVEC sort_STRVEC (STRVEC const& x) {
+	autoSTRVEC result = newSTRVECcopy (x);
+	sort_STRVEC_inout (result.get());
+	return result;
+}
 
 double NUMquantile (integer n, double a [], double factor) {
 	double place = factor * n + 0.5;
@@ -64,4 +89,4 @@ double NUMquantile (constVECVU const& a, double factor) noexcept {
 	return a [left] + (place - left) * (a [left + 1] - a [left]);
 }
 
-/* End of file NUMsort.cpp */
+/* End of file melder_sort.cpp */
