@@ -1,6 +1,6 @@
 /* praat_TableOfReal.cpp
  *
- * Copyright (C) 1992-2012,2013,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ DO
 	STRING_ONE (TableOfReal)
 		if (columnNumber > my numberOfColumns)
 			Melder_throw (me, U": your column number should not be greater than the number of columns.");
-		const char32 *result = my columnLabels ? my columnLabels [columnNumber] : U"";
+		conststring32 result = my columnLabels ? my columnLabels [columnNumber].get() : U"";
 	STRING_ONE_END
 }
 	
@@ -212,7 +212,7 @@ DO
 	STRING_ONE (TableOfReal)
 		if (rowNumber > my numberOfRows)
 			Melder_throw (me, U": your row number should not be greater than the number of rows.");
-		const char32 *result = my rowLabels ? my rowLabels [rowNumber] : U"";
+		conststring32 result = my rowLabels ? my rowLabels [rowNumber].get() : U"";
 	STRING_ONE_END
 }
 
@@ -361,7 +361,7 @@ DO
 DIRECT (NEW_TableOfReal_extractColumnLabelsAsStrings) {
 	CONVERT_EACH (TableOfReal)
 		autoStrings result = TableOfReal_extractColumnLabelsAsStrings (me);
-	CONVERT_EACH_END (my name)
+	CONVERT_EACH_END (my name.get())
 }
 
 FORM (NEW_TableOfReal_extractColumnRanges, U"Extract column ranges", nullptr) {
@@ -371,7 +371,7 @@ FORM (NEW_TableOfReal_extractColumnRanges, U"Extract column ranges", nullptr) {
 DO
 	CONVERT_EACH (TableOfReal)
 		autoTableOfReal result = TableOfReal_extractColumnRanges (me, ranges);
-	CONVERT_EACH_END (my name, U"_cols")
+	CONVERT_EACH_END (my name.get(), U"_cols")
 }
 
 FORM (NEW_TableOfReal_extractColumnsWhere, U"Extract columns where", nullptr) {
@@ -380,34 +380,35 @@ FORM (NEW_TableOfReal_extractColumnsWhere, U"Extract columns where", nullptr) {
 DO
 	CONVERT_EACH (TableOfReal)
 		autoTableOfReal result = TableOfReal_extractColumnsWhere (me, condition, interpreter);
-	CONVERT_EACH_END (my name, U"_cols")
+	CONVERT_EACH_END (my name.get(), U"_cols")
 }
 
 FORM (NEW_TableOfReal_extractColumnsWhereLabel, U"Extract column where label", nullptr) {
-	OPTIONMENU_ENUM (extractAllColumnsWhoseLabel, U"Extract all columns whose label...", kMelder_string, DEFAULT)
+	OPTIONMENU_ENUM (kMelder_string, extractAllColumnsWhoseLabel,
+			U"Extract all columns whose label...", kMelder_string::DEFAULT)
 	SENTENCE (___theText, U"...the text", U"a")
 	OK
 DO
 	CONVERT_EACH (TableOfReal)
-		autoTableOfReal result = TableOfReal_extractColumnsWhereLabel (me, (kMelder_string) extractAllColumnsWhoseLabel, ___theText);
-	CONVERT_EACH_END (my name, U"_", ___theText)
+		autoTableOfReal result = TableOfReal_extractColumnsWhereLabel (me, extractAllColumnsWhoseLabel, ___theText);
+	CONVERT_EACH_END (my name.get(), U"_", ___theText)
 }
 
 FORM (NEW_TableOfReal_extractColumnsWhereRow, U"Extract columns where row", nullptr) {
 	NATURAL (extractAllColumnsWhereRow, U"Extract all columns where row...", U"1")
-	OPTIONMENU_ENUM (___is___, U"...is...", kMelder_number, DEFAULT)
+	OPTIONMENU_ENUM (kMelder_number, ___is___, U"...is...", kMelder_number::DEFAULT)
 	REAL (___theValue, U"...the value", U"0.0")
 	OK
 DO
 	CONVERT_EACH (TableOfReal)
-		autoTableOfReal result = TableOfReal_extractColumnsWhereRow (me, extractAllColumnsWhereRow, (kMelder_number) ___is___, ___theValue);
-	CONVERT_EACH_END (my name, U"_", extractAllColumnsWhereRow, U"_", Melder_iround (___theValue))
+		autoTableOfReal result = TableOfReal_extractColumnsWhereRow (me, extractAllColumnsWhereRow, ___is___, ___theValue);
+	CONVERT_EACH_END (my name.get(), U"_", extractAllColumnsWhereRow, U"_", Melder_iround (___theValue))
 }
 
 DIRECT (NEW_TableOfReal_extractRowLabelsAsStrings) {
 	CONVERT_EACH (TableOfReal)
 		autoStrings result = TableOfReal_extractRowLabelsAsStrings (me);
-	CONVERT_EACH_END (my name)
+	CONVERT_EACH_END (my name.get())
 }
 
 FORM (NEW_TableOfReal_extractRowRanges, U"Extract row ranges", nullptr) {
@@ -417,7 +418,7 @@ FORM (NEW_TableOfReal_extractRowRanges, U"Extract row ranges", nullptr) {
 DO
 	CONVERT_EACH (TableOfReal)
 		autoTableOfReal result = TableOfReal_extractRowRanges (me, ranges);
-	CONVERT_EACH_END (my name, U"_rows")
+	CONVERT_EACH_END (my name.get(), U"_rows")
 }
 
 FORM (NEW_TableOfReal_extractRowsWhere, U"Extract rows where", nullptr) {
@@ -426,28 +427,29 @@ FORM (NEW_TableOfReal_extractRowsWhere, U"Extract rows where", nullptr) {
 DO
 	CONVERT_EACH (TableOfReal)
 		autoTableOfReal result = TableOfReal_extractRowsWhere (me, condition, interpreter);
-	CONVERT_EACH_END (my name, U"_rows")
+	CONVERT_EACH_END (my name.get(), U"_rows")
 }
 
 FORM (NEW_TableOfReal_extractRowsWhereColumn, U"Extract rows where column", nullptr) {
 	NATURAL (extractAllRowsWhereColumn, U"Extract all rows where column...", U"1")
-	OPTIONMENU_ENUM (___is___, U"...is...", kMelder_number, DEFAULT)
+	OPTIONMENU_ENUM (kMelder_number, ___is___, U"...is...", kMelder_number::DEFAULT)
 	REAL (___theValue, U"...the value", U"0.0")
 	OK
 DO
 	CONVERT_EACH (TableOfReal)
-		autoTableOfReal result = TableOfReal_extractRowsWhereColumn (me, extractAllRowsWhereColumn, (kMelder_number) ___is___, ___theValue);
-	CONVERT_EACH_END (my name, U"_", extractAllRowsWhereColumn, U"_", Melder_iround (___theValue))
+		autoTableOfReal result = TableOfReal_extractRowsWhereColumn (me, extractAllRowsWhereColumn, ___is___, ___theValue);
+	CONVERT_EACH_END (my name.get(), U"_", extractAllRowsWhereColumn, U"_", Melder_iround (___theValue))
 }
 
 FORM (NEW_TableOfReal_extractRowsWhereLabel, U"Extract rows where label", nullptr) {
-	OPTIONMENU_ENUM (extractAllRowsWhoseLabel, U"Extract all rows whose label...", kMelder_string, DEFAULT)
+	OPTIONMENU_ENUM (kMelder_string, extractAllRowsWhoseLabel,
+			U"Extract all rows whose label...", kMelder_string::DEFAULT)
 	SENTENCE (___theText, U"...the text", U"a")
 	OK
 DO
 	CONVERT_EACH (TableOfReal)
-		autoTableOfReal result = TableOfReal_extractRowsWhereLabel (me, (kMelder_string) extractAllRowsWhoseLabel, ___theText);
-	CONVERT_EACH_END (my name, U"_", ___theText)
+		autoTableOfReal result = TableOfReal_extractRowsWhereLabel (me, extractAllRowsWhoseLabel, ___theText);
+	CONVERT_EACH_END (my name.get(), U"_", ___theText)
 }
 
 // MARK: Convert
@@ -462,7 +464,7 @@ DIRECT (NEW1_TablesOfReal_append) {
 DIRECT (NEW_TableOfReal_to_Matrix) {
 	CONVERT_EACH (TableOfReal)
 		autoMatrix result = TableOfReal_to_Matrix (me);
-	CONVERT_EACH_END (my name)
+	CONVERT_EACH_END (my name.get())
 }
 
 FORM (NEW_TableOfReal_to_Table, U"TableOfReal: To Table", nullptr) {
@@ -471,7 +473,7 @@ FORM (NEW_TableOfReal_to_Table, U"TableOfReal: To Table", nullptr) {
 DO
 	CONVERT_EACH (TableOfReal)
 		autoTable result = TableOfReal_to_Table (me, labelOfFirstColumn);
-	CONVERT_EACH_END (my name)
+	CONVERT_EACH_END (my name.get())
 }
 
 FORM_SAVE (SAVE_TableOfReal_writeToHeaderlessSpreadsheetFile, U"Save TableOfReal as spreadsheet", 0, U"txt") {
