@@ -1,6 +1,6 @@
 /* DemoEditor.cpp
  *
- * Copyright (C) 2009-2019 Paul Boersma
+ * Copyright (C) 2009-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,11 +41,10 @@ void structDemoEditor :: v_info () {
 }
 
 void structDemoEditor :: v_goAway () {
-	if (waitingForInput) {
+	if (waitingForInput)
 		userWantsToClose = true;
-	} else {
+	else
 		DemoEditor_Parent :: v_goAway ();
-	}
 }
 
 void structDemoEditor :: v_createMenus () {
@@ -53,21 +52,19 @@ void structDemoEditor :: v_createMenus () {
 }
 
 static void gui_drawingarea_cb_expose (DemoEditor me, GuiDrawingArea_ExposeEvent /* event */) {
-	if (! my graphics) return;   // could be the case in the very beginning
-	/*
-	 * Erase the background. Don't record this erasure!
-	 */
-	Graphics_stopRecording (my graphics.get());   // the only place in Praat (the Picture window has a separate Graphics for erasing)?
-	Graphics_setColour (my graphics.get(), Melder_WHITE);
-	Graphics_setWindow (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
-	Graphics_fillRectangle (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
-	Graphics_setColour (my graphics.get(), Melder_BLACK);
-	Graphics_startRecording (my graphics.get());
+	if (! my graphics)
+		return;   // could be the case in the very beginning
+static integer count=0;
+//Melder_casual(U"gui_drawingarea_cb_expose ", ++count);
+	//Graphics_clearWs (my foregroundGraphics.get());
 	Graphics_play (my graphics.get(), my graphics.get());
 }
 
-static void gui_drawingarea_cb_click (DemoEditor me, GuiDrawingArea_ClickEvent event) {
-	if (! my graphics) return;   // could be the case in the very beginning
+static void gui_drawingarea_cb_mouse (DemoEditor me, GuiDrawingArea_MouseEvent event) {
+	if (! my graphics)
+		return;   // could be the case in the very beginning
+	if (! event -> isClick())
+		return;
 	my clicked = true;
 	my keyPressed = false;
 	my x = event -> x;
@@ -76,11 +73,11 @@ static void gui_drawingarea_cb_click (DemoEditor me, GuiDrawingArea_ClickEvent e
 	my shiftKeyPressed = event -> shiftKeyPressed;
 	my commandKeyPressed = event -> commandKeyPressed;
 	my optionKeyPressed = event -> optionKeyPressed;
-	my extraControlKeyPressed = event -> extraControlKeyPressed;
 }
 
 static void gui_drawingarea_cb_key (DemoEditor me, GuiDrawingArea_KeyEvent event) {
-	if (! my graphics) return;   // could be the case in the very beginning
+	if (! my graphics)
+		return;   // could be the case in the very beginning
 	my clicked = false;
 	my keyPressed = true;
 	my x = 0;
@@ -90,11 +87,11 @@ static void gui_drawingarea_cb_key (DemoEditor me, GuiDrawingArea_KeyEvent event
 	my shiftKeyPressed = event -> shiftKeyPressed;
 	my commandKeyPressed = event -> commandKeyPressed;
 	my optionKeyPressed = event -> optionKeyPressed;
-	my extraControlKeyPressed = event -> extraControlKeyPressed;
 }
 
 static void gui_drawingarea_cb_resize (DemoEditor me, GuiDrawingArea_ResizeEvent event) {
-	if (! my graphics) return;   // could be the case in the very beginning
+	if (! my graphics)
+		return;   // could be the case in the very beginning
 	trace (event -> width, U" ", event -> height);
 	Graphics_setWsViewport (my graphics.get(), 0.0, event -> width, 0.0, event -> height);
 	Graphics_setWsWindow (my graphics.get(), 0.0, 100.0, 0.0, 100.0);
@@ -103,22 +100,27 @@ static void gui_drawingarea_cb_resize (DemoEditor me, GuiDrawingArea_ResizeEvent
 }
 
 void structDemoEditor :: v_createChildren () {
-	drawingArea = GuiDrawingArea_createShown (our windowForm, 0, 0, 0, 0,
-		gui_drawingarea_cb_expose, gui_drawingarea_cb_click, gui_drawingarea_cb_key, gui_drawingarea_cb_resize, this, 0);
+	our drawingArea = GuiDrawingArea_createShown (our windowForm, 0, 0, 0, 0,
+		gui_drawingarea_cb_expose, gui_drawingarea_cb_mouse,
+		gui_drawingarea_cb_key, gui_drawingarea_cb_resize, this, 0
+	);
 }
 
 void DemoEditor_init (DemoEditor me) {
 	Editor_init (me, 0, 0, 1344, 756, U"", nullptr);   // 70 percent of the standard 1920x1080 screen
+
 	my graphics = Graphics_create_xmdrawingarea (my drawingArea);
+	Graphics_setWsWindow (my graphics.get(), 0.0, 100.0, 0.0, 100.0);
+	Graphics_setWsViewport (my graphics.get(),
+		0.0, GuiControl_getWidth (my drawingArea),
+		0.0, GuiControl_getHeight (my drawingArea)
+	);
+	Graphics_startRecording (my graphics.get());
+	Graphics_setViewport (my graphics.get(), 0.0, 100.0, 0.0, 100.0);
 	Graphics_setColour (my graphics.get(), Melder_WHITE);
 	Graphics_setWindow (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
 	Graphics_fillRectangle (my graphics.get(), 0.0, 1.0, 0.0, 1.0);
 	Graphics_setColour (my graphics.get(), Melder_BLACK);
-	Graphics_startRecording (my graphics.get());
-	Graphics_setWsViewport (my graphics.get(), 0.0, GuiControl_getWidth  (my drawingArea),
-	                                           0.0, GuiControl_getHeight (my drawingArea));
-	Graphics_setWsWindow (my graphics.get(), 0.0, 100.0, 0.0, 100.0);
-	Graphics_setViewport (my graphics.get(), 0.0, 100.0, 0.0, 100.0);
 	Graphics_updateWs (my graphics.get());
 }
 
@@ -135,8 +137,8 @@ autoDemoEditor DemoEditor_create () {
 void Demo_open () {
 	if (Melder_batch) {
 		/*
-		 * Batch scripts have to be able to run demos.
-		 */
+			Batch scripts have to be able to run demos.
+		*/
 		//Melder_batch = false;
 	}
 	if (! theReferenceToTheOnlyDemoEditor) {
@@ -168,6 +170,7 @@ void Demo_open () {
 
 void Demo_close () {
 	theCurrentPraatPicture = & theForegroundPraatPicture;
+	Graphics_updateWs (theReferenceToTheOnlyDemoEditor -> graphics.get());
 }
 
 int Demo_windowTitle (conststring32 title) {
@@ -177,9 +180,11 @@ int Demo_windowTitle (conststring32 title) {
 }
 
 int Demo_show () {
-	if (! theReferenceToTheOnlyDemoEditor) return 0;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return 0;
 	autoDemoOpen demo;
 	GuiThing_show (theReferenceToTheOnlyDemoEditor -> windowForm);
+	Graphics_updateWs (theReferenceToTheOnlyDemoEditor -> graphics.get());
 	GuiShell_drain (theReferenceToTheOnlyDemoEditor -> windowForm);
 	return 1;
 }
@@ -210,7 +215,8 @@ void Demo_timer (double duration) {
 }
 
 void Demo_waitForInput (Interpreter interpreter) {
-	if (! theReferenceToTheOnlyDemoEditor) return;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -222,7 +228,8 @@ void Demo_waitForInput (Interpreter interpreter) {
 	{// scope
 		autoMelderSaveDefaultDir saveDir;
 		bool wasBackgrounding = Melder_backgrounding;
-		if (wasBackgrounding) praat_foreground ();
+		if (wasBackgrounding)
+			praat_foreground ();
 		try {
 			#if gtk
 				do {
@@ -260,7 +267,8 @@ void Demo_waitForInput (Interpreter interpreter) {
 		} catch (MelderError) {
 			Melder_flushError (U"An error made it to the outer level in the Demo window; should not occur! Please write to paul.boersma@uva.nl");
 		}
-		if (wasBackgrounding) praat_background ();
+		if (wasBackgrounding)
+			praat_background ();
 	}
 	theReferenceToTheOnlyDemoEditor -> waitingForInput = false;
 	if (theReferenceToTheOnlyDemoEditor -> userWantsToClose) {
@@ -285,7 +293,6 @@ void Demo_peekInput (Interpreter interpreter) {
 	theReferenceToTheOnlyDemoEditor -> shiftKeyPressed = false;
 	theReferenceToTheOnlyDemoEditor -> commandKeyPressed = false;
 	theReferenceToTheOnlyDemoEditor -> optionKeyPressed = false;
-	theReferenceToTheOnlyDemoEditor -> extraControlKeyPressed = false;
 	theReferenceToTheOnlyDemoEditor -> waitingForInput = true;
 	{// scope
 		autoMelderSaveDefaultDir saveDir;
@@ -330,7 +337,8 @@ void Demo_peekInput (Interpreter interpreter) {
 }
 
 bool Demo_clicked () {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -339,7 +347,8 @@ bool Demo_clicked () {
 }
 
 double Demo_x () {
-	if (! theReferenceToTheOnlyDemoEditor) return undefined;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return undefined;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -356,7 +365,8 @@ double Demo_x () {
 }
 
 double Demo_y () {
-	if (! theReferenceToTheOnlyDemoEditor) return undefined;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return undefined;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -369,7 +379,8 @@ double Demo_y () {
 }
 
 bool Demo_keyPressed () {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -378,7 +389,8 @@ bool Demo_keyPressed () {
 }
 
 char32 Demo_key () {
-	if (! theReferenceToTheOnlyDemoEditor) return U'\0';
+	if (! theReferenceToTheOnlyDemoEditor)
+		return U'\0';
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -387,7 +399,8 @@ char32 Demo_key () {
 }
 
 bool Demo_shiftKeyPressed () {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -396,7 +409,8 @@ bool Demo_shiftKeyPressed () {
 }
 
 bool Demo_commandKeyPressed () {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -405,7 +419,8 @@ bool Demo_commandKeyPressed () {
 }
 
 bool Demo_optionKeyPressed () {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -413,17 +428,9 @@ bool Demo_optionKeyPressed () {
 	return theReferenceToTheOnlyDemoEditor -> optionKeyPressed;
 }
 
-bool Demo_extraControlKeyPressed () {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
-	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
-		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
-			U"Please click or type into the Demo window or close it.");
-	}
-	return theReferenceToTheOnlyDemoEditor -> extraControlKeyPressed;
-}
-
 bool Demo_input (conststring32 keys) {
-	if (! theReferenceToTheOnlyDemoEditor) return false;
+	if (! theReferenceToTheOnlyDemoEditor)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
@@ -432,12 +439,14 @@ bool Demo_input (conststring32 keys) {
 }
 
 bool Demo_clickedIn (double left, double right, double bottom, double top) {
-	if (! theReferenceToTheOnlyDemoEditor || ! theReferenceToTheOnlyDemoEditor -> clicked) return false;
+	if (! theReferenceToTheOnlyDemoEditor || ! theReferenceToTheOnlyDemoEditor -> clicked)
+		return false;
 	if (theReferenceToTheOnlyDemoEditor -> waitingForInput) {
 		Melder_throw (U"You cannot work with the Demo window while it is waiting for input. "
 			U"Please click or type into the Demo window or close it.");
 	}
-	if (! theReferenceToTheOnlyDemoEditor -> clicked) return false;
+	if (! theReferenceToTheOnlyDemoEditor -> clicked)
+		return false;
 	double xWC = Demo_x (), yWC = Demo_y ();
 	return xWC >= left && xWC < right && yWC >= bottom && yWC < top;
 }
