@@ -1,6 +1,6 @@
 /* Editor_enums.h
  *
- * Copyright (C) 1992-2007,2013,2015 Paul Boersma
+ * Copyright (C) 1992-2007,2013,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
  */
 
 enums_begin (kEditor_writeNameAtTop, 0)
-	enums_add (kEditor_writeNameAtTop, 0, NO, U"no")
-	enums_add (kEditor_writeNameAtTop, 1, FAR, U"far")
-	enums_add (kEditor_writeNameAtTop, 2, NEAR, U"near")
-enums_end (kEditor_writeNameAtTop, 2, FAR)
+	enums_add (kEditor_writeNameAtTop, 0, NO_, U"no")
+	enums_add (kEditor_writeNameAtTop, 1, FAR_, U"far")
+	enums_add (kEditor_writeNameAtTop, 2, NEAR_, U"near")
+enums_end (kEditor_writeNameAtTop, 2, FAR_)
 
 /* End of file Editor_enums.h */
