@@ -2,7 +2,7 @@
 #define _Formula_h_
 /* Formula.h
  *
- * Copyright (C) 1990-2005,2007,2008,2011-2019 Paul Boersma
+ * Copyright (C) 1990-2005,2007,2008,2011-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,13 @@
 
 Thing_declare (InterpreterVariable);
 
+/*
+	A stack element may be 32 bytes large, so with a stack size of 1'000'000
+	we have 32 MB for the stack. A formula instruction may be 16 bytes large,
+	so we have 16 MB for lexical analysis and 16 MB for the parse.
+*/
+#define Formula_MAXIMUM_STACK_SIZE  1'000'000
+
 typedef struct structStackel {
 	#define Stackel_NUMBER  0
 	#define Stackel_STRING  1
@@ -43,7 +50,7 @@ typedef struct structStackel {
 	#define Stackel_VARIABLE  -1
 	#define Stackel_OBJECT  -2
 	int which;   // 0 or negative = no clean-up required, positive = requires clean-up
-	bool owned;   // relevant only to numeric vector/matrix/tensor3/tensor4
+	bool owned;   // relevant only to numeric vector/matrix/tensor3/tensor4/strvec/strmat
 	/*
 		The following member of structStackel can either be a struct or a union.
 		The struct option is the easy option: no special care will have to be taken when assigning to its members.
@@ -63,6 +70,7 @@ typedef struct structStackel {
 		Daata object;
 		VEC numericVector;
 		MAT numericMatrix;
+		STRVEC stringArray;
 		InterpreterVariable variable;
 	};
 	structStackel () {
@@ -94,6 +102,14 @@ typedef struct structStackel {
 				}
 				our numericMatrix = MAT ();   // undangle
 			}
+		} else if (our which == Stackel_STRING_ARRAY) {
+			if (our owned) {
+				{// scope
+					autoSTRVEC removable;
+					removable. adoptFromAmbiguousOwner (our stringArray);
+				}
+				our stringArray = STRVEC ();   // undangle
+			}
 		}
 	}
 	~structStackel () {   // union-safe destruction: test which variant we have
@@ -130,6 +146,7 @@ struct Formula_Result {
 	autostring32 stringResult;
 	VEC numericVectorResult;
 	MAT numericMatrixResult;
+	STRVEC stringArrayResult;
 	bool owned;
 	Formula_Result () {
 		our expressionType = kFormula_EXPRESSION_TYPE_NUMERIC;
@@ -137,6 +154,7 @@ struct Formula_Result {
 		our stringResult = autostring32();
 		our numericVectorResult = VEC ();
 		our numericMatrixResult = MAT ();
+		our stringArrayResult = STRVEC ();
 		our owned = false;
 	}
 	void reset () {
@@ -148,10 +166,15 @@ struct Formula_Result {
 			}
 			our numericVectorResult = VEC ();   // undangle
 			{// scope
-				autoMAT mat;
-				mat. adoptFromAmbiguousOwner (our numericMatrixResult);
+				autoMAT removable;
+				removable. adoptFromAmbiguousOwner (our numericMatrixResult);
 			}
 			our numericMatrixResult = MAT ();   // undangle
+			{// scope
+				autoSTRVEC removable;
+				removable. adoptFromAmbiguousOwner (our stringArrayResult);
+			}
+			our stringArrayResult = STRVEC ();   // undangle
 		}
 	}
 	~ Formula_Result () {
