@@ -2,7 +2,7 @@
 #define _Graphics_h_
 /* Graphics.h
  *
- * Copyright (C) 1992-2005,2007-2019 Paul Boersma
+ * Copyright (C) 1992-2005,2007-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -104,8 +104,8 @@ Thing_define (Graphics, Thing) {
 	kGraphics_font font;
 	double fontSize;
 	int fontStyle;
-	int percentSignIsItalic, numberSignIsBold, circumflexIsSuperscript, underscoreIsSubscript;
-	int dollarSignIsCode, atSignIsLink;
+	bool percentSignIsItalic, numberSignIsBold, circumflexIsSuperscript, underscoreIsSubscript;
+	bool dollarSignIsCode, atSignIsLink;
 	bool recording, duringXor;
 	integer irecord, nrecord;
 	double *record;
@@ -132,9 +132,6 @@ Thing_define (Graphics, Thing) {
 	virtual void v_roundedRectangle (double x1DC, double x2DC, double y1DC, double y2DC, double r);
 	virtual void v_fillRoundedRectangle (double x1DC, double x2DC, double y1DC, double y2DC, double r);
 	virtual void v_arrowHead (double xDC, double yDC, double angle);
-	virtual bool v_mouseStillDown () { return false; }
-	virtual void v_getMouseLocation (double *xWC, double *yWC) { *xWC = *yWC = undefined; }
-	virtual void v_flushWs () { }
 	virtual void v_clearWs () { }
 	virtual void v_updateWs () { }
 };
@@ -157,18 +154,12 @@ autoGraphics Graphics_create_xmdrawingarea (GuiDrawingArea drawingArea);
 
 int Graphics_getResolution (Graphics me);
 
-#if defined (macintosh)
-	#define SUPPORT_DIRECT_DRAWING  1
-#else
-	#define SUPPORT_DIRECT_DRAWING  1
-#endif
 void Graphics_setWsViewport (Graphics me, integer x1DC, integer x2DC, integer y1DC, integer y2DC);
 void Graphics_resetWsViewport (Graphics me, integer x1DC, integer x2DC, integer y1DC, integer y2DC);
 void Graphics_setWsWindow (Graphics me, double x1NDC, double x2NDC, double y1NDC, double y2NDC);
 void Graphics_inqWsViewport (Graphics me, integer *x1DC, integer *x2DC, integer *y1DC, integer *y2DC);
 void Graphics_inqWsWindow (Graphics me, double *x1NDC, double *x2NDC, double *y1NDC, double *y2NDC);
 void Graphics_clearWs (Graphics me);
-void Graphics_flushWs (Graphics me);
 void Graphics_updateWs (Graphics me);
 void Graphics_beginMovieFrame (Graphics me, MelderColour *colour);
 void Graphics_endMovieFrame (Graphics me, double frameDuration);
@@ -180,8 +171,8 @@ Graphics_Viewport Graphics_insetViewport (Graphics me, double x1rel, double x2re
 void Graphics_resetViewport (Graphics me, Graphics_Viewport viewport);
 void Graphics_setWindow (Graphics me, double x1, double x2, double y1, double y2);
 
-void Graphics_polyline (Graphics me, integer numberOfPoints, double *x, double *y);
-void Graphics_polyline_closed (Graphics me, integer numberOfPoints, double *x, double *y);
+void Graphics_polyline (Graphics me, integer numberOfPoints, const double *x, const double *y);
+void Graphics_polyline_closed (Graphics me, integer numberOfPoints, const double *x, const double *y);
 
 void Graphics_text (Graphics me, double xWC, double yWC, conststring32 txt);
 template <typename... Args>
@@ -238,11 +229,8 @@ void Graphics_setGrey (Graphics me, double grey);
 void Graphics_xorOn (Graphics me, MelderColour colour);
 void Graphics_xorOff (Graphics me);
 void Graphics_highlight (Graphics me, double x1, double x2, double y1, double y2);
-void Graphics_unhighlight (Graphics me, double x1, double x2, double y1, double y2);
 void Graphics_highlight2 (Graphics me, double x1, double x2, double y1, double y2,
 	double innerX1, double innerX2, double innerY1, double innerY2);
-void Graphics_unhighlight2 (Graphics me, double x1, double x2, double y1, double y2,
-	double innerX1, double innerX2, double innerY1, double innerY2);
 
 #define Graphics_NOCHANGE  -1
 #define Graphics_LEFT  kGraphics_horizontalAlignment::LEFT
@@ -346,10 +334,6 @@ void Graphics_marksRightEvery  (Graphics me, double units, double distance, bool
 void Graphics_marksBottomEvery (Graphics me, double units, double distance, bool haveNumbers, bool haveTicks, bool haveDottedLines);
 void Graphics_marksTopEvery    (Graphics me, double units, double distance, bool haveNumbers, bool haveTicks, bool haveDottedLines);
 
-void *Graphics_x_getCR (Graphics me);
-void Graphics_x_setCR (Graphics me, void *cr);
-void *Graphics_x_getGC (Graphics me);
-
 bool Graphics_startRecording (Graphics me);
 bool Graphics_stopRecording (Graphics me);
 void Graphics_clearRecording (Graphics me);
@@ -365,10 +349,6 @@ double Graphics_distanceWCtoMM (Graphics me, double x1WC, double y1WC, double x2
 double Graphics_dxWCtoMM (Graphics me, double dxWC);
 double Graphics_dyWCtoMM (Graphics me, double dyWC);
 
-bool Graphics_mouseStillDown (Graphics me);
-void Graphics_waitMouseUp (Graphics me);
-void Graphics_getMouseLocation (Graphics me, double *xWC, double *yWC);
-
 void Graphics_nextSheetOfPaper (Graphics me);
 
 void Graphics_prefs ();
