@@ -1,6 +1,6 @@
 /* GraphicsScreen.cpp
  *
- * Copyright (C) 1992-2012,2014,2015,2016,2017 Paul Boersma, 2013 Tom Naughton
+ * Copyright (C) 1992-2020 Paul Boersma, 2013 Tom Naughton
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,6 @@
 	}
 #elif quartz
 	#include "macport_on.h"
-	static RGBColor theBlackColour = { 0, 0, 0 };
 	static bool _GraphicsMacintosh_tryToInitializeQuartz () {
 		return _GraphicsMac_tryToInitializeFonts ();
 	}
@@ -48,12 +47,6 @@ Thing_implement (GraphicsScreen, Graphics, 0);
 
 void structGraphicsScreen :: v_destroy () noexcept {
 	#if cairo
-		#if ALLOW_GDK_DRAWING
-			if (d_gdkGraphicsContext) {
-				g_object_unref (d_gdkGraphicsContext);			
-				d_gdkGraphicsContext = nullptr;
-			}
-		#endif
 		if (d_cairoGraphicsContext) {
 			cairo_destroy (d_cairoGraphicsContext);
 			d_cairoGraphicsContext = nullptr;
@@ -66,7 +59,7 @@ void structGraphicsScreen :: v_destroy () noexcept {
 				#else
 					unsigned char *bitmap = cairo_image_surface_get_data (my d_cairoSurface);   // peeking into the internal bits
 					// copy bitmap to PNG structure created with the PNG library
-					// save the PNG tructure to a file
+					// save the PNG structure to a file
 				#endif
 			}
 			cairo_surface_destroy (d_cairoSurface);
@@ -87,8 +80,8 @@ void structGraphicsScreen :: v_destroy () noexcept {
 		if (d_isPng && d_gdiBitmap) {
 			trace (U"saving the filled bitmap to a PNG file");
 			/*
-			 * Deselect the bitmap from the device context (otherwise GetDIBits won't work).
-			 */
+				Deselect the bitmap from the device context (otherwise GetDIBits won't work).
+			*/
 			//SelectBitmap (d_gdiGraphicsContext, nullptr);
 			//SelectBitmap (d_gdiGraphicsContext, CreateCompatibleBitmap (nullptr, 1, 1));
 
@@ -99,8 +92,8 @@ void structGraphicsScreen :: v_destroy () noexcept {
 			trace (U"width ", width, U", height ", height);
 
 			/*
-			 * Get the bits from the HBITMAP;
-			 */
+				Get the bits from the HBITMAP;
+			*/
 			struct { BITMAPINFOHEADER header; } bitmapInfo;
 			bitmapInfo. header.biSize = sizeof (BITMAPINFOHEADER);
 			bitmapInfo. header.biWidth = width;
@@ -162,9 +155,9 @@ void structGraphicsScreen :: v_destroy () noexcept {
 			DeleteDC (d_gdiGraphicsContext);   // this was a memory leak before 5.3.83
 		}
 		/*
-		 * No ReleaseDC here, because we have not created it ourselves,
-		 * not even with GetDC. Is this a BUG?
-		 */
+			No ReleaseDC here, because we have not created it ourselves,
+			not even with GetDC. Is this a BUG?
+		*/
 		d_gdiGraphicsContext = nullptr;
 	#elif quartz
 		if (! d_macView && ! d_isPng) {
@@ -173,14 +166,14 @@ void structGraphicsScreen :: v_destroy () noexcept {
 		}
 		if (d_isPng && d_macGraphicsContext) {
 			/*
-			 * Turn the offscreen bitmap into an image.
-			 */
+				Turn the offscreen bitmap into an image.
+			*/
 			CGImageRef image = CGBitmapContextCreateImage (d_macGraphicsContext);
 			Melder_assert (image);
 			//CGContextRelease (d_macGraphicsContext);
 			/*
-			 * Create a dictionary with resolution properties.
-			 */
+				Create a dictionary with resolution properties.
+			*/
 			CFTypeRef keys [2], values [2];
 			keys [0] = kCGImagePropertyDPIWidth;
 			keys [1] = kCGImagePropertyDPIHeight;
@@ -190,8 +183,7 @@ void structGraphicsScreen :: v_destroy () noexcept {
 				(const void **) keys, (const void **) values, 2,
 				& kCFTypeDictionaryKeyCallBacks, & kCFTypeDictionaryValueCallBacks);
 			Melder_assert (properties);
-			/*
-			 */
+
 			CFURLRef url = CFURLCreateWithFileSystemPath (nullptr,
 				(CFStringRef) Melder_peek32toCfstring (d_file. path), kCFURLPOSIXPathStyle, false);
 			CGImageDestinationRef imageDestination = CGImageDestinationCreateWithURL (url, kUTTypePNG, 1, nullptr);
@@ -211,36 +203,6 @@ void structGraphicsScreen :: v_destroy () noexcept {
 	trace (U"exit");
 }
 
-void structGraphicsScreen :: v_flushWs () {
-	#if cairo && gtk
-		// Ik weet niet of dit is wat het zou moeten zijn ;)
-		//gdk_window_process_updates (d_window, true);   // this "works" but is incorrect because it's not the expose events that have to be carried out
-		//gdk_window_flush (d_window);
-		gdk_flush ();
-		// TODO: een aanroep die de eventuele grafische buffer ledigt,
-		// zodat de gebruiker de grafica ziet ook al blijft Praat in hetzelfde event zitten
-	#elif gdi
-		/*GdiFlush ();*/
-	#elif quartz
-		if (d_drawingArea) {
-			GuiShell shell = d_drawingArea -> d_shell;
-			Melder_assert (shell);
-			Melder_assert (shell -> d_cocoaShell);
-			[shell -> d_cocoaShell   flushWindow];
-			NSEvent *nsEvent = [[d_macView window]
-				nextEventMatchingMask: NSAnyEventMask
-				untilDate: [NSDate distantPast]
-				inMode: NSDefaultRunLoopMode
-				dequeue: NO
-				];
-		}
-	#endif
-}
-
-void Graphics_flushWs (Graphics me) {
-	my v_flushWs ();
-}
-
 void structGraphicsScreen :: v_clearWs () {
 	#if cairo && gtk
 		GdkRectangle rect;
@@ -258,12 +220,7 @@ void structGraphicsScreen :: v_clearWs () {
 			rect.y = our d_y2DC;
 			rect.height = our d_y1DC - our d_y2DC;
 		}
-		if (! d_cairoGraphicsContext) {
-			trace (U"clear and null");
-			//gdk_window_clear (our window);
-			//gdk_window_invalidate_rect (our window, & rect, true);   // BUG: it seems weird that this is necessary.
-		} else {
-			trace (U"clear and not null");
+		if (d_cairoGraphicsContext) {
 			cairo_set_source_rgb (d_cairoGraphicsContext, 1.0, 1.0, 1.0);
 			cairo_rectangle (d_cairoGraphicsContext, rect.x, rect.y, rect.width, rect.height);
 			cairo_fill (d_cairoGraphicsContext);
@@ -277,66 +234,34 @@ void structGraphicsScreen :: v_clearWs () {
 		FillRect (d_gdiGraphicsContext, & rect, GetStockBrush (WHITE_BRUSH));
 		/*if (d_winWindow) SendMessage (d_winWindow, WM_ERASEBKGND, (WPARAM) d_gdiGraphicsContext, 0);*/
 	#elif quartz
-        GuiCocoaDrawingArea *cocoaDrawingArea = (GuiCocoaDrawingArea *) d_drawingArea -> d_widget;
-        if (cocoaDrawingArea && ! [cocoaDrawingArea isHiddenOrHasHiddenAncestor]) {   // can be called at destruction time
-            NSRect rect;
-            if (our d_x1DC < our d_x2DC) {
-                rect.origin.x = our d_x1DC;
-                rect.size.width = our d_x2DC - our d_x1DC;
-            } else {
-                rect.origin.x = our d_x2DC;
-                rect.size.width = our d_x1DC - our d_x2DC;
-            }
-            if (our d_y1DC < our d_y2DC) {
-                rect.origin.y = our d_y1DC;
-                rect.size.height = our d_y2DC - our d_y1DC;
-            } else {
-                rect.origin.y = our d_y2DC;
-                rect.size.height = our d_y1DC - our d_y2DC;
-            }
-			if (SUPPORT_DIRECT_DRAWING) {
-				[cocoaDrawingArea lockFocus];
-				CGContextRef context = (CGContextRef) [[NSGraphicsContext currentContext] graphicsPort];
-				Melder_assert (context);
-				CGContextSaveGState (context);
-				CGContextSetAlpha (context, 1.0);
-				CGContextSetBlendMode (context, kCGBlendModeNormal);
-				CGContextSetRGBFillColor (context, 1.0, 1.0, 1.0, 1.0);
-				//rect.origin.x -= 1000;
-				//rect.origin.y -= 1000;
-				//rect.size.width += 2000;
-				//rect.size.height += 2000;
-				trace (U"clearing ", rect.origin.x, U" ", rect.origin.y, U" ", rect.size.width, U" ", rect.size.height);
-				//CGContextTranslateCTM (context, 0, cocoaDrawingArea.bounds.size.height);
-				//CGContextScaleCTM (context, 1.0, -1.0);
-				CGContextFillRect (context, rect);
-				//CGContextSynchronize (context);
-				CGContextRestoreGState (context);
-				[cocoaDrawingArea unlockFocus];
-				[cocoaDrawingArea setNeedsDisplay: YES];
-			} else {
-				/*
-					Just redraw, and hope that the redraw method erases.
-				*/
-				[cocoaDrawingArea setNeedsDisplay: YES];
-			}
-			//[cocoaDrawingArea display];
-        }
+		GuiCocoaDrawingArea *cocoaDrawingArea = (GuiCocoaDrawingArea *) d_drawingArea -> d_widget;
+		if (cocoaDrawingArea && ! [cocoaDrawingArea isHiddenOrHasHiddenAncestor]) {   // can be called at destruction time
+			Melder_assert (!! our d_macGraphicsContext);
+			CGContextSetAlpha (our d_macGraphicsContext, 1.0);
+			CGContextSetRGBFillColor (our d_macGraphicsContext, 1.0, 1.0, 1.0, 1.0);
+			CGContextFillRect (d_macGraphicsContext, CGRectMake (our d_x1DC, our d_y2DC, our d_x2DC - our d_x1DC, our d_y1DC - our d_y2DC));
+		}
 	#endif
 }
 
 void Graphics_clearWs (Graphics me) {
-	my v_clearWs ();
+	if (my recording) {
+		op (CLEAR_WS, 0);
+	} else
+		my v_clearWs ();
 }
 
 void structGraphicsScreen :: v_updateWs () {
 	/*
-	 * A function that invalidates the graphics.
-	 * This function is typically called by the owner of the drawing area
-	 * whenever the data to be displayed in the drawing area has changed;
-	 * the idea is to generate an expose event to which the drawing area will
-	 * respond by redrawing its contents from the (changed) data.
-	 */
+		A function that invalidates the graphics.
+		This function is typically called by the owner of the drawing area
+		whenever the data to be displayed in the drawing area has changed;
+		the idea is to generate an expose event to which the drawing area will
+		respond by redrawing its contents from the (changed) data.
+		(last checked 2020-07-12)
+	*/
+	if (! our d_drawingArea)
+		return;
 	#if cairo && gtk
 		//GdkWindow *window = gtk_widget_get_parent_window (GTK_WIDGET (our d_drawingArea -> d_widget));
 		GdkRectangle rect;
@@ -356,43 +281,34 @@ void structGraphicsScreen :: v_updateWs () {
 			rect.y = our d_y2DC;
 			rect.height = our d_y1DC - our d_y2DC;
 		}
-
-		if (our d_cairoGraphicsContext && our d_drawingArea) {  // update clipping rectangle to new graphics size
-			cairo_reset_clip (our d_cairoGraphicsContext);
-			cairo_rectangle (our d_cairoGraphicsContext, rect.x, rect.y, rect.width, rect.height);
-			cairo_clip (our d_cairoGraphicsContext);
-		}
-		#if ALLOW_GDK_DRAWING
-			gdk_window_clear (our d_window);
-		#endif
-		gdk_window_invalidate_rect (our d_window, & rect, true);
-		//gdk_window_process_updates (our d_window, true);
+		//gdk_window_invalidate_rect (our d_window, & rect, true);
+		gtk_widget_queue_draw_area (GTK_WIDGET (our d_drawingArea -> d_widget), rect.x, rect.y, rect.width, rect.height);
+		//gdk_window_invalidate_rect (our d_window, nullptr, true);
+		//gdk_window_process_updates (our d_window, true);   // TODO: this one seems to be for draining instead
 	#elif gdi
 		//clear (this); // lll
-		if (our d_winWindow) InvalidateRect (our d_winWindow, nullptr, true);
+		if (our d_winWindow)
+			InvalidateRect (our d_winWindow, nullptr, true);
 	#elif quartz
-        NSView *view = our d_macView;
+		NSView *view = our d_macView;
 		Melder_assert (!! view);
-        NSRect rect;
-    
-        if (our d_x1DC < our d_x2DC) {
-            rect.origin.x = our d_x1DC;
-            rect.size.width = our d_x2DC - our d_x1DC;
-        } else {
-            rect.origin.x = our d_x2DC;
-            rect.size.width = our d_x1DC - our d_x2DC;
-        }
-        
-        if (our d_y1DC < our d_y2DC) {
-            rect.origin.y = our d_y1DC;
-            rect.size.height = our d_y2DC - our d_y1DC;
-        } else {
-            rect.origin.y = our d_y2DC;
-            rect.size.height = our d_y1DC - our d_y2DC;
-        }
-    
-        //[view setNeedsDisplayInRect: rect];
-        [view setNeedsDisplay: YES];
+		NSRect rect;
+		if (our d_x1DC < our d_x2DC) {
+			rect.origin.x = our d_x1DC;
+			rect.size.width = our d_x2DC - our d_x1DC;
+		} else {
+			rect.origin.x = our d_x2DC;
+			rect.size.width = our d_x1DC - our d_x2DC;
+		}
+		if (our d_y1DC < our d_y2DC) {
+			rect.origin.y = our d_y1DC;
+			rect.size.height = our d_y2DC - our d_y1DC;
+		} else {
+			rect.origin.y = our d_y2DC;
+			rect.size.height = our d_y1DC - our d_y2DC;
+		}
+		//[view setNeedsDisplayInRect: rect];
+		[view setNeedsDisplay: YES];
 	#endif
 }
 
@@ -404,9 +320,9 @@ void Graphics_updateWs (Graphics me) {
 void Graphics_beginMovieFrame (Graphics any, MelderColour *p_colour) {
 	if (any -> classInfo == classGraphicsScreen) {
 		GraphicsScreen me = (GraphicsScreen) any;
-		Graphics_clearRecording (me);
 		Graphics_startRecording (me);
 		if (p_colour) {
+			Graphics_clearRecording (me);
 			Graphics_setViewport (me, 0.0, 1.0, 0.0, 1.0);
 			Graphics_setColour (me, *p_colour);
 			Graphics_setWindow (me, 0.0, 1.0, 0.0, 1.0);
@@ -420,12 +336,8 @@ void Graphics_endMovieFrame (Graphics any, double frameDuration) {
 	if (any -> classInfo == classGraphicsScreen) {
 		GraphicsScreen me = (GraphicsScreen) any;
 		Graphics_stopRecording (me);
-		#if cairo || gdi
-			my v_flushWs ();
-		#elif quartz
-			my v_updateWs ();
-			GuiShell_drain (my d_drawingArea -> d_shell);
-		#endif
+		my v_updateWs ();
+		GuiShell_drain (my d_drawingArea -> d_shell);
 		Melder_sleep (frameDuration);
 	}
 }
@@ -437,15 +349,9 @@ static int GraphicsScreen_init (GraphicsScreen me, void *voidDisplay, void *void
 	#if cairo && gtk
 		my d_display = (GdkDisplay *) gdk_display_get_default ();
 		_GraphicsScreen_text_init (me);
-		#if ALLOW_GDK_DRAWING
-			trace (U"retrieving window");
-			my d_window = GDK_DRAWABLE (GTK_WIDGET (voidDisplay) -> window);
-			trace (U"retrieved window");
-			my d_gdkGraphicsContext = gdk_gc_new (my d_window);
-		#else
+		if (voidDisplay)
 			my d_window = gtk_widget_get_window (GTK_WIDGET (voidDisplay));
-		#endif
-		my d_cairoGraphicsContext = gdk_cairo_create (my d_window);
+		my d_cairoGraphicsContext = nullptr;   // will be created and destroyed at expose time or during Graphics_textWidth(); 2020-11-11
 	#elif gdi
 		if (my printer) {
 			my d_gdiGraphicsContext = (HDC) voidWindow;
@@ -457,10 +363,10 @@ static int GraphicsScreen_init (GraphicsScreen me, void *voidDisplay, void *void
 			my d_gdiGraphicsContext = GetDC (my d_winWindow);   // window must have a constant display context; see XtInitialize ()
 		}
 		Melder_assert (my d_gdiGraphicsContext);
-		SetBkMode (my d_gdiGraphicsContext, TRANSPARENT);   // not the default!
+		SetBkMode (my d_gdiGraphicsContext, TRANSPARENT);   // not the default! text should not be drawn against a white background
 		/*
-		 * Create pens and brushes.
-		 */
+			Create pens and brushes.
+		*/
 		my d_winPen = CreatePen (PS_SOLID, 0, RGB (0, 0, 0));
 		my d_winBrush = CreateSolidBrush (RGB (0, 0, 0));
 		SelectBrush (my d_gdiGraphicsContext, GetStockBrush (NULL_BRUSH));
@@ -473,10 +379,9 @@ static int GraphicsScreen_init (GraphicsScreen me, void *voidDisplay, void *void
 			//my d_macGraphicsContext = (CGContextRef) voidWindow;   // in case we do context-based printing
 		} else {
 			my d_macView = (NSView *) voidWindow;
-			(void) my d_macGraphicsContext;   // will be retrieved from Core Graphics with every drawing command!
+			my d_macGraphicsContext = nullptr;   // will be retrieved and nullified at expose time
 		}
-		my d_macColour = theBlackColour;
-		my d_depth = my resolution > 150 ? 1 : 8;   /* BUG: replace by true depth (1=black/white) */
+		my d_depth = ( my resolution > 150 ? 1 : 8 );   // BUG: replace by true depth (1=black/white)
 		_GraphicsScreen_text_init (me);
 	#endif
 	return 1;
@@ -565,6 +470,9 @@ autoGraphics Graphics_create_xmdrawingarea (GuiDrawingArea w) {
 		GraphicsScreen_init (me.get(), my d_drawingArea -> d_widget, my d_drawingArea -> d_widget);
 	#endif
 
+	Melder_assert (w -> numberOfGraphicses < structGuiDrawingArea :: MAXIMUM_NUMBER_OF_GRAPHICSES);
+	w -> graphicses [++ w -> numberOfGraphicses] = me.get();   // refer back
+
 	#if cairo && gtk
 		// fb: is really the request meant or rather the actual size, aka allocation?
 		gtk_widget_size_request (GTK_WIDGET (my d_drawingArea -> d_widget), & realsize);
@@ -576,7 +484,7 @@ autoGraphics Graphics_create_xmdrawingarea (GuiDrawingArea w) {
 		XtVaGetValues (my d_drawingArea -> d_widget, XmNwidth, & width, XmNheight, & height, nullptr);
 		Graphics_setWsViewport (me.get(), 0.0, width, 0.0, height);
     #elif quartz
-        NSView *view = (NSView *)my d_drawingArea -> d_widget;
+        NSView *view = (NSView *) my d_drawingArea -> d_widget;
         NSRect bounds = [view bounds];
         Graphics_setWsViewport (me.get(), 0.0, bounds.size.width, 0.0, bounds.size.height);
 	#endif
@@ -610,8 +518,8 @@ autoGraphics Graphics_create_pngfile (MelderFile file, int resolution,
 		my d_cairoGraphicsContext = cairo_create (my d_cairoSurface);
 		//cairo_scale (my d_cairoGraphicsContext, 72.0 / resolution, 72.0 / resolution);
 		/*
-		 * Fill in the whole area with a white background.
-		 */
+			Fill in the whole area with a white background.
+		*/
 		cairo_set_source_rgb (my d_cairoGraphicsContext, 1.0, 1.0, 1.0);
 		cairo_rectangle (my d_cairoGraphicsContext, 0, 0, my d_x2DC, my d_y2DC);
 		cairo_fill (my d_cairoGraphicsContext);
@@ -634,8 +542,8 @@ autoGraphics Graphics_create_pngfile (MelderFile file, int resolution,
 		my d_winBrush = CreateSolidBrush (RGB (0, 0, 0));
 		SetTextAlign (my d_gdiGraphicsContext, TA_LEFT | TA_BASELINE | TA_NOUPDATECP);
 		/*
-		 * Fill in the whole area with a white background.
-		 */
+			Fill in the whole area with a white background.
+		*/
 		SelectPen (my d_gdiGraphicsContext, GetStockPen (NULL_PEN));
 		SelectBrush (my d_gdiGraphicsContext, GetStockBrush (WHITE_BRUSH));
 		Rectangle (my d_gdiGraphicsContext, 0, 0, my d_x2DC + 1, my d_y2DC + 1);   // plus 1, in order to prevent two black edges
@@ -693,7 +601,8 @@ autoGraphics Graphics_create_pdffile (MelderFile file, int resolution,
 		my d_y2DC = my d_y2DCmax = ( isdefined (y1inches) ? 11.0 : y2inches ) * resolution;
 		Graphics_setWsWindow (me.get(),
 			isdefined (x1inches) ? 0.0 : 0.0, isdefined (x1inches) ?  7.5 : x2inches,
-			isdefined (y1inches) ? 1.0 : 0.0, isdefined (y1inches) ? 12.0 : y2inches);
+			isdefined (y1inches) ? 1.0 : 0.0, isdefined (y1inches) ? 12.0 : y2inches
+		);
 		cairo_scale (my d_cairoGraphicsContext, 72.0 / resolution, 72.0 / resolution);
 	#elif quartz
 		CFURLRef url = CFURLCreateWithFileSystemPath (nullptr, (CFStringRef) Melder_peek32toCfstring (file -> path), kCFURLPOSIXPathStyle, false);
@@ -762,32 +671,4 @@ autoGraphics Graphics_create_pdf (void *context, int resolution,
 	}
 #endif
 
-#if quartz
-	void GraphicsQuartz_initDraw (GraphicsScreen me) {
-		if (my d_macView) {
-			if (SUPPORT_DIRECT_DRAWING)
-				[my d_macView lockFocus];
-			//if (! my printer) {
-			my d_macGraphicsContext = Melder_systemVersion < 101400 ?
-					(CGContextRef) [[NSGraphicsContext currentContext] graphicsPort] :
-					[[NSGraphicsContext currentContext] CGContext];
-			//}
-			//Melder_assert (my d_macGraphicsContext);
-			//Melder_casual (U"GraphicsQuartz_initDraw: 1 ", Melder_pointer (my d_macGraphicsContext));
-			//Melder_casual (U"GraphicsQuartz_initDraw: 2 ", Melder_pointer ([[NSGraphicsContext currentContext] graphicsPort]));
-			if (my printer) {
-				//CGContextTranslateCTM (my d_macGraphicsContext, 0, [my d_macView bounds]. size. height);
-				//CGContextScaleCTM (my d_macGraphicsContext, 1.0, -1.0);
-			}
-		}
-	}
-	void GraphicsQuartz_exitDraw (GraphicsScreen me) {
-		if (my d_macView) {
-			//CGContextSynchronize (my d_macGraphicsContext);   // BUG: should not be needed
-			if (SUPPORT_DIRECT_DRAWING)
-				[my d_macView unlockFocus];
-		}
-	}
-#endif
-
 /* End of file GraphicsScreen.cpp */
