@@ -80,11 +80,10 @@ static void _GraphicsScreen_cellArrayOrImage (GraphicsScreen me,
 					for (int igrey = 0; igrey <= 255; igrey ++)
 						greyBrush [igrey] = CreateSolidBrush (RGB (igrey, igrey, igrey));   // once
 			#elif quartz
-				GraphicsQuartz_initDraw (me);
 				CGContextSetAlpha (my d_macGraphicsContext, 1.0);
 				CGContextSetBlendMode (my d_macGraphicsContext, kCGBlendModeNormal);
 			#endif
-			autoINTVEC leftsBuffer = newINTVECzero (ix2 - ix1 + 2);
+			autoINTVEC leftsBuffer = zero_INTVEC (ix2 - ix1 + 2);
 			integer *lefts = & leftsBuffer [1 - ix1];
 			for (ix = ix1; ix <= ix2 + 1; ix ++)
 				lefts [ix] = x1DC + (integer) ((ix - ix1) * dx);
@@ -145,7 +144,6 @@ static void _GraphicsScreen_cellArrayOrImage (GraphicsScreen me,
 					cairo_pattern_destroy (grey [igrey]);
 			#elif quartz
 				CGContextSetRGBFillColor (my d_macGraphicsContext, 0.0, 0.0, 0.0, 1.0);
-				GraphicsQuartz_exitDraw (me);
 			#endif
 		} catch (MelderError) { }
 	} else {
@@ -271,10 +269,10 @@ static void _GraphicsScreen_cellArrayOrImage (GraphicsScreen me,
 		#endif
 		if (interpolate) {
 			try {
-				autoINTVEC ileftBuffer = newINTVECzero (clipx2 - clipx1 + 1);
-				autoINTVEC irightBuffer = newINTVECzero (clipx2 - clipx1 + 1);
-				autoVEC leftWeightBuffer = newVECzero (clipx2 - clipx1 + 1);
-				autoVEC rightWeightBuffer = newVECzero (clipx2 - clipx1 + 1);
+				autoINTVEC ileftBuffer = zero_INTVEC (clipx2 - clipx1 + 1);
+				autoINTVEC irightBuffer = zero_INTVEC (clipx2 - clipx1 + 1);
+				autoVEC leftWeightBuffer = zero_VEC (clipx2 - clipx1 + 1);
+				autoVEC rightWeightBuffer = zero_VEC (clipx2 - clipx1 + 1);
 				integer *ileft  = & ileftBuffer  [1 - clipx1];
 				integer *iright = & irightBuffer [1 - clipx1];
 				double *leftWeight  = & leftWeightBuffer  [1 - clipx1];
@@ -360,7 +358,7 @@ static void _GraphicsScreen_cellArrayOrImage (GraphicsScreen me,
 			} catch (MelderError) { Melder_clearError (); }
 		} else {
 			try {
-				autoINTVEC ixBuffer = newINTVECzero (clipx2 - clipx1 + 1);
+				autoINTVEC ixBuffer = zero_INTVEC (clipx2 - clipx1 + 1);
 				integer *ix = & ixBuffer [1 - clipx1];
 				for (xDC = clipx1; xDC < clipx2; xDC += undersampling)
 					ix [xDC] = Melder_ifloor (ix1 + (nx * (xDC - x1DC)) / (x2DC - x1DC));
@@ -439,9 +437,7 @@ static void _GraphicsScreen_cellArrayOrImage (GraphicsScreen me,
 				// release bitmap?
 			}
 			Melder_assert (image != nullptr);
-			GraphicsQuartz_initDraw (me);
 			CGContextDrawImage (my d_macGraphicsContext, CGRectMake (clipx1, clipy2, clipx2 - clipx1, clipy1 - clipy2), image);
-			GraphicsQuartz_exitDraw (me);
 			//CGColorSpaceRelease (colourSpace);
 			CGImageRelease (image);
 		#endif
@@ -664,10 +660,8 @@ static void _cellArrayOrImage (Graphics me,
 void Graphics_cellArray (Graphics me, constMATVU const& z,
 	double x1WC, double x2WC, double y1WC, double y2WC, double minimum, double maximum)
 {
-	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum) return;
-	_cellArrayOrImage (me, z, constmatrixview<MelderColour>(), constmatrixview<unsigned char>(),
-		1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
-		wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), false);
+	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum)
+		return;
 	if (my recording) {
 		op (CELL_ARRAY, 8 + z.nrow * z.ncol);
 		put (x1WC); put (x2WC); put (y1WC); put (y2WC);
@@ -676,16 +670,18 @@ void Graphics_cellArray (Graphics me, constMATVU const& z,
 		for (integer irow = 1; irow <= z.nrow; irow ++)
 			for (integer icol = 1; icol <= z.ncol; icol ++)
 				put (z [irow] [icol]);
-	}
+	} else
+		_cellArrayOrImage (me, z, constmatrixview<MelderColour>(), constmatrixview<unsigned char>(),
+			1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
+			wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), false
+		);
 }
 
 void Graphics_cellArray_colour (Graphics me, constmatrixview <MelderColour> const& z,
 	double x1WC, double x2WC, double y1WC, double y2WC, double minimum, double maximum)
 {
-	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum) return;
-	_cellArrayOrImage (me, constMATVU(), z, constmatrixview<unsigned char>(),
-		1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
-		wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), false);
+	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum)
+		return;
 	if (my recording) {
 		op (CELL_ARRAY_COLOUR, 8 + z.nrow * z.ncol * 4);
 		put (x1WC); put (x2WC); put (y1WC); put (y2WC);
@@ -700,16 +696,18 @@ void Graphics_cellArray_colour (Graphics me, constmatrixview <MelderColour> cons
 				put (row [icol]. transparency);
 			}
 		}
-	}
+	} else
+		_cellArrayOrImage (me, constMATVU(), z, constmatrixview<unsigned char>(),
+			1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
+			wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), false
+		);
 }
 
 void Graphics_cellArray8 (Graphics me, constmatrixview<unsigned char> const& z,
 	double x1WC, double x2WC, double y1WC, double y2WC, unsigned char minimum, unsigned char maximum)
 {
-	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum) return;
-	_cellArrayOrImage (me, constMATVU(), constmatrixview<MelderColour>(), z,
-		1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
-		wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), false);
+	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum)
+		return;
 	if (my recording) {
 		op (CELL_ARRAY8, 8 + z.nrow * z.ncol);
 		put (x1WC); put (x2WC); put (y1WC); put (y2WC);
@@ -718,16 +716,18 @@ void Graphics_cellArray8 (Graphics me, constmatrixview<unsigned char> const& z,
 		for (integer irow = 1; irow <= z.nrow; irow ++)
 			for (integer icol = 1; icol <= z.ncol; icol ++)
 				put (z [irow] [icol]);
-	}
+	} else
+		_cellArrayOrImage (me, constMATVU(), constmatrixview<MelderColour>(), z,
+			1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
+			wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), false
+		);
 }
 
 void Graphics_image (Graphics me, constMATVU const& z,
 	double x1WC, double x2WC, double y1WC, double y2WC, double minimum, double maximum)
 {
-	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum) return;
-	_cellArrayOrImage (me, z, constmatrixview<MelderColour>(), constmatrixview<unsigned char>(),
-		1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
-		wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), true);
+	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum)
+		return;
 	if (my recording) {
 		op (IMAGE, 8 + z.nrow * z.ncol);
 		put (x1WC); put (x2WC); put (y1WC); put (y2WC);
@@ -736,16 +736,18 @@ void Graphics_image (Graphics me, constMATVU const& z,
 		for (integer irow = 1; irow <= z.nrow; irow ++)
 			for (integer icol = 1; icol <= z.ncol; icol ++)
 				put (z [irow] [icol]);
-	}
+	} else
+		_cellArrayOrImage (me, z, constmatrixview<MelderColour>(), constmatrixview<unsigned char>(),
+			1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
+			wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), true
+		);
 }
 
 void Graphics_image_colour (Graphics me, constmatrixview <MelderColour> const& z,
 	double x1WC, double x2WC, double y1WC, double y2WC, double minimum, double maximum)
 {
-	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum) return;
-	_cellArrayOrImage (me, constMATVU(), z, constmatrixview<unsigned char>(),
-		1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
-		wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), true);
+	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum)
+		return;
 	if (my recording) {
 		op (IMAGE_COLOUR, 8 + z.nrow * z.ncol * 4);
 		put (x1WC); put (x2WC); put (y1WC); put (y2WC);
@@ -760,16 +762,18 @@ void Graphics_image_colour (Graphics me, constmatrixview <MelderColour> const& z
 				put (row [icol]. transparency);
 			}
 		}
-	}
+	} else
+		_cellArrayOrImage (me, constMATVU(), z, constmatrixview<unsigned char>(),
+			1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
+			wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), true
+		);
 }
 
 void Graphics_image8 (Graphics me, constmatrixview <unsigned char> const& z,
 	double x1WC, double x2WC, double y1WC, double y2WC, uint8 minimum, uint8 maximum)
 {
-	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum) return;
-	_cellArrayOrImage (me, constMATVU(), constmatrixview<MelderColour>(), z,
-		1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
-		wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), true);
+	if (z.nrow < 1 || z.ncol < 1 || minimum == maximum)
+		return;
 	if (my recording) {
 		op (IMAGE8, 8 + z.nrow * z.ncol);
 		put (x1WC); put (x2WC); put (y1WC); put (y2WC);
@@ -778,7 +782,11 @@ void Graphics_image8 (Graphics me, constmatrixview <unsigned char> const& z,
 		for (integer irow = 1; irow <= z.nrow; irow ++)
 			for (integer icol = 1; icol <= z.ncol; icol ++)
 				put (z [irow] [icol]);
-	}
+	} else
+		_cellArrayOrImage (me, constMATVU(), constmatrixview<MelderColour>(), z,
+			1, z.ncol, wdx (x1WC), wdx (x2WC), 1, z.nrow, wdy (y1WC), wdy (y2WC), minimum, maximum,
+			wdx (my d_x1WC), wdx (my d_x2WC), wdy (my d_y1WC), wdy (my d_y2WC), true
+		);
 }
 
 static void _GraphicsScreen_imageFromFile (GraphicsScreen me, conststring32 relativeFileName, double x1, double x2, double y1, double y2) {
@@ -859,16 +867,14 @@ static void _GraphicsScreen_imageFromFile (GraphicsScreen me, conststring32 rela
 					height = width * (double) CGImageGetHeight (image) / (double) CGImageGetWidth (image);
 					y2DC -= height / 2, y1DC = y2DC + height;
 				}
-				GraphicsQuartz_initDraw (me);
 				CGContextSaveGState (my d_macGraphicsContext);
                 
-                NSCAssert(my d_macGraphicsContext, @"nil context");
+                //NSCAssert(my d_macGraphicsContext, @"nil context");
 
 				CGContextTranslateCTM (my d_macGraphicsContext, 0, y1DC);
 				CGContextScaleCTM (my d_macGraphicsContext, 1.0, -1.0);
 				CGContextDrawImage (my d_macGraphicsContext, CGRectMake (x1DC, 0, width, height), image);
 				CGContextRestoreGState (my d_macGraphicsContext);
-				GraphicsQuartz_exitDraw (me);
 				CGImageRelease (image);
 			}
 		}
@@ -876,13 +882,12 @@ static void _GraphicsScreen_imageFromFile (GraphicsScreen me, conststring32 rela
 }
 
 void Graphics_imageFromFile (Graphics me, conststring32 relativeFileName, double x1, double x2, double y1, double y2) {
-	if (my screen) {
-		_GraphicsScreen_imageFromFile (static_cast <GraphicsScreen> (me), relativeFileName, x1, x2, y1, y2);
-	}
 	if (my recording) {
 		conststring8 txt_utf8 = Melder_peek32to8 (relativeFileName);
 		int length = strlen (txt_utf8) / sizeof (double) + 1;
 		op (IMAGE_FROM_FILE, 5 + length); put (x1); put (x2); put (y1); put (y2); sput (txt_utf8, length)
+	} else if (my screen) {
+		_GraphicsScreen_imageFromFile (static_cast <GraphicsScreen> (me), relativeFileName, x1, x2, y1, y2);
 	}
 }
 
