@@ -2,7 +2,7 @@
 #define _Gui_h_
 /* Gui.h
  *
- * Copyright (C) 1993-2019 Paul Boersma, 2013 Tom Naughton
+ * Copyright (C) 1993-2020 Paul Boersma, 2013 Tom Naughton
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,6 +50,13 @@
 	#define cocoa 0
 #endif
 
+constexpr bool theCommandKeyIsToTheLeftOfTheOptionKey =
+	#if defined (macintosh)
+		false;
+	#else
+		true;
+	#endif
+
 #include "Collection.h"
 
 #if defined (UNIX)
@@ -289,7 +296,6 @@
 	void XmToggleButtonGadgetSetState (GuiObject widget, Boolean value, Boolean notify);
 	#define XmToggleButtonSetState XmToggleButtonGadgetSetState
 
-	bool motif_win_mouseStillDown ();
 	void motif_win_setUserMessageCallback (int (*userMessageCallback) (void));
 #else
 	typedef void *GuiObject;
@@ -298,6 +304,7 @@
 int Gui_getResolution (GuiObject widget);
 void Gui_getWindowPositioningBounds (double *x, double *y, double *width, double *height);
 
+Thing_declare (GuiDrawingArea);
 Thing_declare (GuiForm);
 Thing_declare (GuiMenu);
 Thing_declare (GuiScrolledWindow);
@@ -352,6 +359,7 @@ Thing_define (GuiShell, GuiForm) {
 	#endif
 	GuiShell_GoAwayCallback d_goAwayCallback;
 	Thing d_goAwayBoss;
+	GuiDrawingArea drawingArea;
 
 	void v_destroy () noexcept
 		override;
@@ -360,7 +368,7 @@ Thing_define (GuiShell, GuiForm) {
 int GuiShell_getShellWidth  (GuiShell me);   // needed because GuiControl_getWidth yields the width of the inner form
 int GuiShell_getShellHeight (GuiShell me);
 void GuiShell_setTitle (GuiShell me, conststring32 title /* cattable */);
-void GuiShell_drain (GuiShell me);   // drain the double graphics buffer
+void GuiShell_drain (GuiShell me);   // force display of update regions (forces the handling of an expose event)
 
 /********** GuiButton **********/
 
@@ -368,7 +376,7 @@ Thing_declare (GuiButton);
 
 typedef struct structGuiButtonEvent {
 	GuiButton button;
-	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed, extraControlKeyPressed;
+	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed;
 } *GuiButtonEvent;
 
 typedef MelderCallback <void, structThing /* boss */, GuiButtonEvent> GuiButton_ActivateCallback;
@@ -384,7 +392,7 @@ Thing_define (GuiButton, GuiControl) {
 #define GuiButton_CANCEL  2
 #define GuiButton_INSENSITIVE  4
 #define GuiButton_ATTRACTIVE  8
-GuiButton GuiButton_create      (GuiForm parent,
+GuiButton GuiButton_create (GuiForm parent,
 	int left, int right, int top, int bottom,
 	conststring32 text,
 	GuiButton_ActivateCallback activateCallback, Thing boss,
@@ -417,7 +425,7 @@ Thing_define (GuiCheckButton, GuiControl) {
 /* GuiCheckButton creation flags: */
 #define GuiCheckButton_SET  1
 #define GuiCheckButton_INSENSITIVE  2
-GuiCheckButton GuiCheckButton_create      (GuiForm parent,
+GuiCheckButton GuiCheckButton_create (GuiForm parent,
 	int left, int right, int top, int bottom,
 	conststring32 text,
 	GuiCheckButton_ValueChangedCallback valueChangedCallback, Thing boss,
@@ -456,24 +464,36 @@ typedef struct structGuiDrawingArea_ExposeEvent {
 	GuiDrawingArea widget;
 	int x, y, width, height;
 } *GuiDrawingArea_ExposeEvent;
-typedef struct structGuiDrawingArea_ClickEvent {
+
+typedef struct structGuiDrawingArea_MouseEvent {
 	GuiDrawingArea widget;
 	int x, y;
-	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed, extraControlKeyPressed;
-	int button;
-} *GuiDrawingArea_ClickEvent;
+	enum class Phase { CLICK, DRAG, DROP } phase;
+	bool isClick() const { return our phase == Phase::CLICK; }
+	bool isDrag()  const { return our phase == Phase::DRAG; }
+	bool isDrop()  const { return our phase == Phase::DROP; }
+	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed;
+	bool isLeftBottomFunctionKeyPressed () const {
+		return theCommandKeyIsToTheLeftOfTheOptionKey ? our commandKeyPressed : our optionKeyPressed;
+	}
+	bool isRightBottomFunctionKeyPressed () const {
+		return theCommandKeyIsToTheLeftOfTheOptionKey ? our optionKeyPressed : our commandKeyPressed;
+	}
+} *GuiDrawingArea_MouseEvent;
+
 typedef struct structGuiDrawingArea_KeyEvent {
 	GuiDrawingArea widget;
 	char32 key;
-	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed, extraControlKeyPressed;
+	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed;
 } *GuiDrawingArea_KeyEvent;
+
 typedef struct structGuiDrawingArea_ResizeEvent {
 	GuiDrawingArea widget;
 	int width, height;
 } *GuiDrawingArea_ResizeEvent;
 
 typedef MelderCallback <void, structThing /* boss */, GuiDrawingArea_ExposeEvent> GuiDrawingArea_ExposeCallback;
-typedef MelderCallback <void, structThing /* boss */, GuiDrawingArea_ClickEvent > GuiDrawingArea_ClickCallback;
+typedef MelderCallback <void, structThing /* boss */, GuiDrawingArea_MouseEvent > GuiDrawingArea_MouseCallback;
 typedef MelderCallback <void, structThing /* boss */, GuiDrawingArea_KeyEvent   > GuiDrawingArea_KeyCallback;
 typedef MelderCallback <void, structThing /* boss */, GuiDrawingArea_ResizeEvent> GuiDrawingArea_ResizeCallback;
 
@@ -481,51 +501,57 @@ Thing_define (GuiDrawingArea, GuiControl) {
 	GuiScrollBar d_horizontalScrollBar, d_verticalScrollBar;   // for swiping
 	GuiDrawingArea_ExposeCallback d_exposeCallback;
 	Thing d_exposeBoss;
-	GuiDrawingArea_ClickCallback d_clickCallback;
-	Thing d_clickBoss;
+	GuiDrawingArea_MouseCallback mouseCallback;
+	Thing mouseBoss;
 	GuiDrawingArea_KeyCallback d_keyCallback;
 	Thing d_keyBoss;
 	GuiDrawingArea_ResizeCallback d_resizeCallback;
 	Thing d_resizeBoss;
+	integer numberOfGraphicses;
+	constexpr static integer MAXIMUM_NUMBER_OF_GRAPHICSES = 10;
+	Graphics graphicses [1+MAXIMUM_NUMBER_OF_GRAPHICSES];
+
+	void v_destroy () noexcept
+		override;
 };
 
 /* GuiDrawingArea creation flags: */
 #define GuiDrawingArea_BORDER  1
 GuiDrawingArea GuiDrawingArea_create (GuiForm parent, int left, int right, int top, int bottom,
 	GuiDrawingArea_ExposeCallback exposeCallback,
-	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_MouseCallback mouseCallback,
 	GuiDrawingArea_KeyCallback keyCallback,
 	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 flags);
 GuiDrawingArea GuiDrawingArea_createShown (GuiForm parent, int left, int right, int top, int bottom,
 	GuiDrawingArea_ExposeCallback exposeCallback,
-	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_MouseCallback mouseCallback,
 	GuiDrawingArea_KeyCallback keyCallback,
 	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 flags);
 GuiDrawingArea GuiDrawingArea_create (GuiScrolledWindow parent, int width, int height,
 	GuiDrawingArea_ExposeCallback exposeCallback,
-	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_MouseCallback mouseCallback,
 	GuiDrawingArea_KeyCallback keyCallback,
 	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 flags);
 GuiDrawingArea GuiDrawingArea_createShown (GuiScrolledWindow parent, int width, int height,
 	GuiDrawingArea_ExposeCallback exposeCallback,
-	GuiDrawingArea_ClickCallback clickCallback,
+	GuiDrawingArea_MouseCallback mouseCallback,
 	GuiDrawingArea_KeyCallback keyCallback,
 	GuiDrawingArea_ResizeCallback resizeCallback, Thing boss,
 	uint32 flags);
 
 void GuiDrawingArea_setSwipable (GuiDrawingArea me, GuiScrollBar horizontalScrollBar, GuiScrollBar verticalScrollBar);
 void GuiDrawingArea_setExposeCallback (GuiDrawingArea me, GuiDrawingArea_ExposeCallback callback, Thing boss);
-void GuiDrawingArea_setClickCallback  (GuiDrawingArea me, GuiDrawingArea_ClickCallback  callback, Thing boss);
+void GuiDrawingArea_setMouseCallback (GuiDrawingArea me, GuiDrawingArea_MouseCallback callback, Thing boss);
 void GuiDrawingArea_setResizeCallback (GuiDrawingArea me, GuiDrawingArea_ResizeCallback callback, Thing boss);
 
 /********** GuiFileSelect **********/
 
 autoStringSet GuiFileSelect_getInfileNames (GuiWindow parent, conststring32 title, bool allowMultipleFiles);
 autostring32 GuiFileSelect_getOutfileName (GuiWindow parent, conststring32 title, conststring32 defaultName);
-autostring32 GuiFileSelect_getDirectoryName (GuiWindow parent, conststring32 title);
+autostring32 GuiFileSelect_getFolderName (GuiWindow parent, conststring32 title);
 
 /********** GuiForm **********/
 
@@ -653,7 +679,7 @@ Thing_declare (GuiMenuItem);
 
 typedef struct structGuiMenuItemEvent {
 	GuiMenuItem menuItem;
-	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed, extraControlKeyPressed;
+	bool shiftKeyPressed, commandKeyPressed, optionKeyPressed;
 } *GuiMenuItemEvent;
 
 typedef MelderCallback <void, structThing /* boss */, GuiMenuItemEvent> GuiMenuItemCallback;
