@@ -31,13 +31,16 @@ void structGuiControl :: v_positionInForm (GuiObject widget, int left, int right
 		d_bottom = bottom;
 		/*
 		 */
-		if (! parent) return;
+		if (! parent)
+			return;
 		Melder_assert (parent -> d_widget);
 		Melder_assert (GTK_IS_FIXED (parent -> d_widget));
 		gint parentWidth, parentHeight;
 		gtk_widget_get_size_request (GTK_WIDGET (parent -> d_widget), & parentWidth, & parentHeight);
-		//parentWidth  = GTK_WIDGET (parent -> d_widget) -> allocation.width;
-		//parentHeight = GTK_WIDGET (parent -> d_widget) -> allocation.height;
+		//parentWidth  = gtk_widget_get_allocated_width (GTK_WIDGET (parent -> d_widget));
+		//parentHeight = gtk_widget_get_allocated_height (GTK_WIDGET (parent -> d_widget));
+		//parentWidth = parent -> d_right;
+		//parentHeight = parent -> d_top;
 		if (left   <  0) left   += parentWidth;
 		if (right  <= 0) right  += parentWidth;
         if (top    <  0) top    += parentHeight;
@@ -123,7 +126,8 @@ void structGuiControl :: v_positionInForm (GuiObject widget, int left, int right
 
 void structGuiControl :: v_positionInScrolledWindow (GuiObject widget, int width, int height, GuiScrolledWindow parent) {
 	#if gtk
-		if (! parent) return;
+		if (! parent)
+			return;
 		Melder_assert (GTK_IS_SCROLLED_WINDOW (parent -> d_widget));
 		gtk_widget_set_size_request (GTK_WIDGET (widget), width, height);
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (parent -> d_widget), GTK_WIDGET (widget));
@@ -143,7 +147,10 @@ void structGuiControl :: v_positionInScrolledWindow (GuiObject widget, int width
 
 int GuiControl_getX (GuiControl me) {
 	#if gtk
-		return GTK_WIDGET (my d_widget) -> allocation.x;
+		//return GTK_WIDGET (my d_widget) -> allocation.x;
+		GtkAllocation allocation;
+		gtk_widget_get_allocation (GTK_WIDGET (my d_widget), & allocation);
+		return allocation.x;
 	#elif motif
 		return my d_widget -> x;
 	#elif cocoa
@@ -155,7 +162,10 @@ int GuiControl_getX (GuiControl me) {
 
 int GuiControl_getY (GuiControl me) {
 	#if gtk
-		return GTK_WIDGET (my d_widget) -> allocation.y;
+		//return GTK_WIDGET (my d_widget) -> allocation.y;
+		GtkAllocation allocation;
+		gtk_widget_get_allocation (GTK_WIDGET (my d_widget), & allocation);
+		return allocation.y;
 	#elif motif
 		return my d_widget -> y;
 	#elif cocoa
@@ -167,7 +177,10 @@ int GuiControl_getY (GuiControl me) {
 
 int GuiControl_getWidth (GuiControl me) {
 	#if gtk
-		return GTK_WIDGET (my d_widget) -> allocation.width;
+		//return GTK_WIDGET (my d_widget) -> allocation.width;
+		GtkAllocation allocation;
+		gtk_widget_get_allocation (GTK_WIDGET (my d_widget), & allocation);
+		return allocation.width;
 	#elif motif
 		return my d_widget -> width;
 	#elif cocoa
@@ -179,7 +192,10 @@ int GuiControl_getWidth (GuiControl me) {
 
 int GuiControl_getHeight (GuiControl me) {
 	#if gtk
-		return GTK_WIDGET (my d_widget) -> allocation.height;
+		//return GTK_WIDGET (my d_widget) -> allocation.height;
+		GtkAllocation allocation;
+		gtk_widget_get_allocation (GTK_WIDGET (my d_widget), & allocation);
+		return allocation.height;
 	#elif motif
 		return my d_widget -> height;
 	#elif cocoa
