@@ -2,7 +2,7 @@
 #define _ManPage_h_
 /* ManPage.h
  *
- * Copyright (C) 1996-2008,2011,2012,2014-2019 Paul Boersma
+ * Copyright (C) 1996-2008,2011,2012,2014-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,9 +32,8 @@ typedef struct structManPage_Paragraph {
 Thing_define (ManPage, Thing) {
 	autostring32 title, author;
 	integer date;
-	struct structManPage_Paragraph *paragraphs;
-	integer nlinksHither, nlinksThither;
-	integer *linksHither, *linksThither;
+	autovector <structManPage_Paragraph> paragraphs;
+	autoINTVEC linksHither, linksThither;
 	double recordingTime;
 };
 
