@@ -53,13 +53,13 @@ static void menu_cb_writeOneToHtmlFile (Manual me, EDITOR_ARGS_FORM) {
 	EDITOR_END
 }
 
-static void menu_cb_writeAllToHtmlDir (Manual me, EDITOR_ARGS_FORM) {
+static void menu_cb_writeAllToHtmlFolder (Manual me, EDITOR_ARGS_FORM) {
 	EDITOR_FORM (U"Save all pages as HTML files", nullptr)
-		TEXTFIELD (directory, U"Directory:", U"")
+		TEXTFIELD (folder, U"Directory:", U"")
 	EDITOR_OK
-		SET_STRING (directory, Melder_dirToPath (& my rootDirectory))
+		SET_STRING (folder, Melder_dirToPath (& my rootDirectory))
 	EDITOR_DO
-		ManPages_writeAllToHtmlDir ((ManPages) my data, directory);
+		ManPages_writeAllToHtmlDir ((ManPages) my data, folder);
 	EDITOR_END
 }
 
@@ -78,9 +78,6 @@ static void menu_cb_searchForPageList (Manual me, EDITOR_ARGS_FORM) {
 
 void structManual :: v_draw () {
 	ManPages manPages = (ManPages) our data;
-	#if motif
-	Graphics_clearWs (our graphics.get());
-	#endif
 	if (our visiblePageNumber == SEARCH_PAGE) {
 		HyperPage_pageTitle (this, U"Best matches");
 		HyperPage_intro (this, U"The best matches to your query seem to be:");
@@ -299,7 +296,7 @@ static void search (Manual me, conststring32 query) {
 	}
 	static autoVEC goodnessOfMatch;
 	if (NUMisEmpty (goodnessOfMatch))
-		goodnessOfMatch = newVECzero (numberOfPages);
+		goodnessOfMatch = zero_VEC (numberOfPages);
 	for (integer ipage = 1; ipage <= numberOfPages; ipage ++) {
 		char32 *token = searchText.string;
 		goodnessOfMatch [ipage] = 1.0;
@@ -418,7 +415,8 @@ void structManual :: v_createMenus () {
 
 	Editor_addCommand (this, U"File", U"Print manual...", 0, menu_cb_printRange);
 	Editor_addCommand (this, U"File", U"Save page as HTML file...", 0, menu_cb_writeOneToHtmlFile);
-	Editor_addCommand (this, U"File", U"Save manual to HTML directory...", 0, menu_cb_writeAllToHtmlDir);
+	Editor_addCommand (this, U"File", U"Save manual to HTML folder...", 0, menu_cb_writeAllToHtmlFolder);
+	Editor_addCommand (this, U"File", U"Save manual to HTML directory...", praat_DEPRECATED_2020, menu_cb_writeAllToHtmlFolder);
 	Editor_addCommand (this, U"File", U"-- close --", 0, nullptr);
 
 	Editor_addCommand (this, U"Go to", U"Search for page (list)...", 0, menu_cb_searchForPageList);
