@@ -1,6 +1,6 @@
 /* Picture.cpp
  *
- * Copyright (C) 1992-2019 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brauße
+ * Copyright (C) 1992-2020 Paul Boersma, 2008 Stefan de Konink, 2010 Franz Brauße
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,161 +29,134 @@ Thing_implement (Picture, Thing, 0);
 
 static void drawMarkers (Picture me)
 /*
- * The drawing area is a square measuring 12x12 inches.
- */
+	The drawing area is a square measuring 12x12 inches.
+*/
 #define SIDE 12
 /*
- * The selection grid has a resolution of 1/2 inch.
- */
-#define SQUARES 24
+	The selection grid has a resolution of 1/2 inch.
+*/
+#define SQUARES 24_integer
 /*
- * Vertical and horizontal lines every 3 inches.
- */
+	Vertical and horizontal lines every 3 inches.
+*/
 #define YELLOW_GRID 3
 {
-	/* Fill the entire canvas with GC's background. */
-
+	/*
+		Fill the entire canvas with GC's background.
+	*/
 	Graphics_setColour (my selectionGraphics.get(), Melder_WHITE);
 	Graphics_fillRectangle (my selectionGraphics.get(), 0, SIDE, 0, SIDE);
 
-	/* Draw yellow grid lines for coarse navigation. */
-
+	/*
+		Draw yellow grid lines for coarse navigation.
+	*/
 	Graphics_setColour (my selectionGraphics.get(), Melder_YELLOW);
 	for (int i = YELLOW_GRID; i < SIDE; i += YELLOW_GRID) {
 		Graphics_line (my selectionGraphics.get(), 0, i, SIDE, i);
 		Graphics_line (my selectionGraphics.get(), i, 0, i, SIDE);
 	}
 
-	/* Draw red ticks and numbers for feedback on viewport measurement. */
-
+	/*
+		Draw red ticks and numbers for feedback on viewport measurement.
+	*/
 	Graphics_setColour (my selectionGraphics.get(), Melder_RED);
 	for (int i = 1; i < SIDE; i ++) {
-		double x = i;
+		const double x = i;
 		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_CENTRE, Graphics_TOP);
 		Graphics_text (my selectionGraphics.get(), x, SIDE, i);
 		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_CENTRE, Graphics_BOTTOM);
 		Graphics_text (my selectionGraphics.get(), x, 0, i);
 	}
 	for (int i = 1; i < SQUARES ; i ++) {   // vertical ticks
-		double x = 0.5 * i;
+		const double x = 0.5 * i;
 		Graphics_line (my selectionGraphics.get(), x, SIDE - 0.04, x, SIDE);
 		Graphics_line (my selectionGraphics.get(), x, 0, x, 0.04);
 	}
 	for (int i = 1; i < SIDE; i ++) {
-		double y = SIDE - i;
+		const double y = SIDE - i;
 		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_LEFT, Graphics_HALF);
 		Graphics_text (my selectionGraphics.get(), 0.04, y, i);
 		Graphics_setTextAlignment (my selectionGraphics.get(), Graphics_RIGHT, Graphics_HALF);
 		Graphics_text (my selectionGraphics.get(), SIDE - 0.03, y, i);
 	}
 	for (int i = 1; i < SQUARES; i ++) {   // horizontal ticks
-		double y = SIDE - 0.5 * i;
+		const double y = SIDE - 0.5 * i;
 		Graphics_line (my selectionGraphics.get(), SIDE - 0.04, y, SIDE, y);
 		Graphics_line (my selectionGraphics.get(), 0, y, 0.04, y);
 	}
-
 	Graphics_setColour (my selectionGraphics.get(), Melder_BLACK);
 }
 
-static void drawSelection (Picture me, int high) {
-	if (my backgrounding) return;
-	double dy = 2.8 * Graphics_inqFontSize (my graphics.get()) / 72.0;
-	double dx = 1.5 * dy;
-	if (dy > 0.4 * (my sely2 - my sely1)) dy = 0.4 * (my sely2 - my sely1);
-	if (dx > 0.4 * (my selx2 - my selx1)) dx = 0.4 * (my selx2 - my selx1);
-	if (high) {
-		Graphics_highlight2 (my selectionGraphics.get(), my selx1, my selx2, my sely1, my sely2,
-			my selx1 + dx, my selx2 - dx, my sely1 + dy, my sely2 - dy);
-	} else {
-		Graphics_unhighlight2 (my selectionGraphics.get(), my selx1, my selx2, my sely1, my sely2,
-			my selx1 + dx, my selx2 - dx, my sely1 + dy, my sely2 - dy);
-	}
+static void drawSelection (Picture me) {
+	const double dy = Melder_clippedRight (2.8 * Graphics_inqFontSize (my graphics.get()) / 72.0,
+			0.4 * (my sely2 - my sely1));
+	const double dx = Melder_clippedRight (1.5 * dy,
+			0.4 * (my selx2 - my selx1));
+	Graphics_highlight2 (my selectionGraphics.get(),
+		my selx1, my selx2, my sely1, my sely2,
+		my selx1 + dx, my selx2 - dx, my sely1 + dy, my sely2 - dy
+	);
 }
 
-//static double test = 0.0;
-
 static void gui_drawingarea_cb_expose (Picture me, GuiDrawingArea_ExposeEvent event) {
-	#if gtk
-		/*
-		 * The size of the viewable part of the drawing area may have changed.
-		 */
-		Melder_assert (event -> widget);
-		#if ALLOW_GDK_DRAWING
-			gdk_cairo_reset_clip ((cairo_t *) Graphics_x_getCR (my graphics.get()),          GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window));
-			gdk_cairo_reset_clip ((cairo_t *) Graphics_x_getCR (my selectionGraphics.get()), GDK_DRAWABLE (GTK_WIDGET (event -> widget -> d_widget) -> window));
-		#endif
-	#else
-		(void) event;
-	#endif
+	Melder_assert (event -> widget);
 	drawMarkers (me);
 	Graphics_play (my graphics.get(), my graphics.get());
-	drawSelection (me, 1);
+	drawSelection (me);
 }
 
-// TODO: Paul, als praat nu 100dpi zou zijn waarom zie ik hier dan nog 72.0 onder?
-// Stefan, die 72.0 is het aantal font-punten per inch,
-// gewoon een vaste verhouding die niks met pixels te maken heeft.
-// TODO: Paul, deze code is bagger :) En dient door event-model-extremisten te worden veroordeeld.
-// Stefan, zoals gezegd, er zijn goede redenen waarom sommige platforms dit synchroon oplossen;
-// misschien maar splitsen tussen die platforms en platforms die met events kunnen werken.
-
-// (Tom:) On Cocoa this leads to flashing, it definitely needs to be event based.
-
-// (Paul:) No, running this through the normal event loop with mouse-down-drag-up events and generating exposes
-// redrew the entire picture window on every change of the selection during dragging. Much too slow!
-
-static void gui_drawingarea_cb_click (Picture me, GuiDrawingArea_ClickEvent event) {
-	int xstart = event -> x;
-	int ystart = event -> y;
+static void gui_drawingarea_cb_mouse (Picture me, GuiDrawingArea_MouseEvent event) {
+	/*
+		Dragging the mouse selects an integer number of "blocks".
+	*/
+	struct Block {
+		integer ix, iy;
+	};
+	static Block anchorBlock, previousBlock;
 	double xWC, yWC;
-	int ixstart, iystart, ix, iy, oldix = 0, oldiy = 0;
-
-	Graphics_DCtoWC (my selectionGraphics.get(), xstart, ystart, & xWC, & yWC);
-	ix = ixstart = 1 + (int) floor (xWC * SQUARES / SIDE);
-	iy = iystart = SQUARES - (int) floor (yWC * SQUARES / SIDE);
-	if (ixstart < 1 || ixstart > SQUARES || iystart < 1 || iystart > SQUARES) return;
-	if (event -> shiftKeyPressed) {
-		int ix1 = 1 + (int) floor (my selx1 * SQUARES / SIDE);
-		int ix2 = (int) floor (my selx2 * SQUARES / SIDE);
-		int iy1 = SQUARES + 1 - (int) floor (my sely2 * SQUARES / SIDE);
-		int iy2 = SQUARES - (int) floor (my sely1 * SQUARES / SIDE);
-		ixstart = ix < (ix1 + ix2) / 2 ? ix2 : ix1;
-		iystart = iy < (iy1 + iy2) / 2 ? iy2 : iy1;
-	}
-	//while (Graphics_mouseStillDown (my selectionGraphics)) {
-	do {
-		Graphics_getMouseLocation (my selectionGraphics.get(), & xWC, & yWC);
-		ix = 1 + (int) floor (xWC * SQUARES / SIDE);
-		iy = SQUARES - (int) floor (yWC * SQUARES / SIDE);
-		if (ix >= 1 && ix <= SQUARES && iy >= 1 && iy <= SQUARES && (ix != oldix || iy != oldiy)) {
-			int ix1, ix2, iy1, iy2;
-			if (ix < ixstart) { ix1 = ix; ix2 = ixstart; }
-			else              { ix1 = ixstart; ix2 = ix; }
-			if (iy < iystart) { iy1 = iy; iy2 = iystart; }
-			else              { iy1 = iystart; iy2 = iy; }
-			if (my mouseSelectsInnerViewport) {
-				const double fontSize = Graphics_inqFontSize (my graphics.get());
-				double xmargin = fontSize * 4.2 / 72.0, ymargin = fontSize * 2.8 / 72.0;
-				if (xmargin > ix2 - ix1 + 1) xmargin = ix2 - ix1 + 1;
-				if (ymargin > iy2 - iy1 + 1) ymargin = iy2 - iy1 + 1;
-				Picture_setSelection (me, 0.5 * (ix1 - 1) - xmargin, 0.5 * ix2 + xmargin,
-					0.5 * (SQUARES - iy2) - ymargin, 0.5 * (SQUARES + 1 - iy1) + ymargin, false);
-			} else {
-				Picture_setSelection (me, 0.5 * (ix1 - 1), 0.5 * ix2,
-					0.5 * (SQUARES - iy2), 0.5 * (SQUARES + 1 - iy1), false);
-			}
-			oldix = ix; oldiy = iy;
+	Graphics_DCtoWC (my selectionGraphics.get(), event -> x, event -> y, & xWC, & yWC);
+	const Block currentBlock {
+		Melder_clipped (1_integer, 1 + (integer) floor (xWC * SQUARES / SIDE), SQUARES),
+		Melder_clipped (1_integer, SQUARES - (integer) floor (yWC * SQUARES / SIDE), SQUARES)
+	};
+	bool didBlockChange = false;   // optimization: don't redraw if we stay in the same block
+	if (event -> isClick()) {
+		constexpr int INVALID_BLOCK_NUMBER = 0;
+		previousBlock = { INVALID_BLOCK_NUMBER, INVALID_BLOCK_NUMBER };
+		if (event -> shiftKeyPressed) {
+			const integer ix1 = Melder_clipped (1_integer, 1 + (integer) floor (my selx1 * SQUARES / SIDE), SQUARES);   // BUG not compatible with mouseSelectsInnerViewport
+			const integer ix2 = Melder_clipped (1_integer, (integer) floor (my selx2 * SQUARES / SIDE), SQUARES);
+			const integer iy1 = Melder_clipped (1_integer, SQUARES + 1 - (integer) floor (my sely2 * SQUARES / SIDE), SQUARES);
+			const integer iy2 = Melder_clipped (1_integer, SQUARES - (integer) floor (my sely1 * SQUARES / SIDE), SQUARES);
+			anchorBlock = { currentBlock. ix < (ix1 + ix2) / 2 ? ix2 : ix1, currentBlock. iy < (iy1 + iy2) / 2 ? iy2 : iy1 };
+		} else {
+			anchorBlock = currentBlock;
 		}
-	} while (Graphics_mouseStillDown (my selectionGraphics.get()));
-	// }
-	#if cocoa
-		Graphics_updateWs (my selectionGraphics.get());   // to change the dark red back into black
-	#endif
-	if (my selectionChangedCallback) {
-		//Melder_casual (U"selectionChangedCallback from gui_drawingarea_cb_click");
+		didBlockChange = true;
+	} else if (event -> isDrag() || event -> isDrop()) {
+		didBlockChange = ( currentBlock. ix != previousBlock. ix || currentBlock. iy != previousBlock. iy );
+	}
+	if (didBlockChange) {
+		previousBlock = currentBlock;
+		const auto ix12 = std::minmax (currentBlock. ix, anchorBlock. ix);
+		const integer ix1 = ix12. first, ix2 = ix12. second;
+		const auto iy12 = std::minmax (currentBlock. iy, anchorBlock. iy);
+		const integer iy1 = iy12. first, iy2 = iy12. second;
+		double xmargin = 0.0, ymargin = 0.0;
+		if (my mouseSelectsInnerViewport) {
+			const double fontSize = Graphics_inqFontSize (my graphics.get());
+			xmargin = std::min (fontSize * 4.2 / 72.0, double (ix2 - ix1 + 1));
+			ymargin = std::min (fontSize * 2.8 / 72.0, double (iy2 - iy1 + 1));
+		}
+		Picture_setSelection (me,
+			0.5 * (ix1 - 1) - xmargin, 0.5 * ix2 + xmargin,
+			0.5 * (SQUARES - iy2) - ymargin, 0.5 * (SQUARES + 1 - iy1) + ymargin
+		);
+		Graphics_updateWs (my selectionGraphics.get());
+	}
+	if (event -> isDrop() && my selectionChangedCallback)
 		my selectionChangedCallback (me, my selectionChangedClosure,
 			my selx1, my selx2, my sely1, my sely2);
-	}
 }
 
 autoPicture Picture_create (GuiDrawingArea drawingArea, bool sensitive) {
@@ -191,29 +164,35 @@ autoPicture Picture_create (GuiDrawingArea drawingArea, bool sensitive) {
 		autoPicture me = Thing_new (Picture);
 		my drawingArea = drawingArea;
 		/*
-		 * The initial viewport is a rectangle 6 inches wide and 4 inches high.
-		 */
+			The initial viewport is a rectangle 6 inches wide and 4 inches high.
+		*/
 		my selx1 = 0.0;
 		my selx2 = 6.0;
 		my sely1 = 8.0;
 		my sely2 = 12.0;
 		my sensitive = sensitive && drawingArea;
+		/*
+			Create a Graphics to directly draw in.
+		*/
 		if (drawingArea) {
-			/* The drawing area must have been realized; see manual at XtWindow. */
+			// the drawing area must have been realized; see manual at XtWindow
 			my graphics = Graphics_create_xmdrawingarea (my drawingArea);
 			GuiDrawingArea_setExposeCallback (my drawingArea, gui_drawingarea_cb_expose, me.get());
 		} else {
 			/*
-			 * Create a dummy Graphics.
-			 */
-			my graphics = Graphics_create (600);
+				Create a dummy Graphics.
+				It does have to be a GraphicsScreen, because it has to support Graphics_textWidth().
+			*/
+			const integer dummyResolution = 600;
+			my graphics = Graphics_create_screen (nullptr, nullptr, dummyResolution);
+			Graphics_setWsViewport (my graphics.get(), 0.0, 12 * dummyResolution, 0.0, 12 * dummyResolution);
 		}
 		Graphics_setWsWindow (my graphics.get(), 0.0, 12.0, 0.0, 12.0);
 		Graphics_setViewport (my graphics.get(), my selx1, my selx2, my sely1, my sely2);
 		if (my sensitive) {
 			my selectionGraphics = Graphics_create_xmdrawingarea (my drawingArea);
-			Graphics_setWindow (my selectionGraphics.get(), 0, 12, 0, 12);
-			GuiDrawingArea_setClickCallback (my drawingArea, gui_drawingarea_cb_click, me.get());
+			Graphics_setWindow (my selectionGraphics.get(), 0.0, 12.0, 0.0, 12.0);
+			GuiDrawingArea_setMouseCallback (my drawingArea, gui_drawingarea_cb_mouse, me.get());
 		}
 		Graphics_startRecording (my graphics.get());
 		return me;
@@ -241,27 +220,16 @@ void structPicture :: v_destroy () noexcept {
 
 Graphics Picture_peekGraphics (Picture me) { return my graphics.get(); }
 
-void Picture_unhighlight (Picture me) {
-	if (my drawingArea) drawSelection (me, 0);   // unselect
-}
-
-void Picture_highlight (Picture me) {
-	if (my drawingArea) drawSelection (me, 1);   // select
-}
-
 void Picture_erase (Picture me) {
 	Graphics_clearRecording (my graphics.get());
-	Graphics_clearWs (my graphics.get());
-	if (my drawingArea) {
-		drawMarkers (me);
-		drawSelection (me, 1);
-	}
+	Graphics_updateWs (my graphics.get());
 }
 
 void Picture_writeToPraatPictureFile (Picture me, MelderFile file) {
 	try {
 		autofile f = Melder_fopen (file, "wb");
-		if (fprintf (f, "PraatPictureFile") < 0) Melder_throw (U"Write error.");
+		if (fprintf (f, "PraatPictureFile") < 0)
+			Melder_throw (U"Write error.");
 		Graphics_writeRecordings (my graphics.get(), f);
 		f.close (file);
 	} catch (MelderError) {
@@ -273,14 +241,15 @@ void Picture_readFromPraatPictureFile (Picture me, MelderFile file) {
 	try {
 		autofile f = Melder_fopen (file, "rb");
 		char line [200];
-		int n = fread (line, 1, 199, f);
+		integer n = uinteger_to_integer (fread (line, 1, 199, f));
 		line [n] = '\0';
 		const char *tag = "PraatPictureFile";
 		char *end = strstr (line, tag);
-		if (! end) Melder_throw (U"This is not a Praat picture file.");
+		if (! end)
+			Melder_throw (U"This is not a Praat picture file.");
 		*end = '\0';
 		rewind (f);
-		fread (line, 1, end - line + strlen (tag), f);
+		fread (line, 1, integer_to_uinteger (end - line + uinteger_to_integer (strlen (tag))), f);
 		Graphics_readRecordings (my graphics.get(), f);
 		Graphics_updateWs (my graphics.get());
 		f.close (file);
@@ -291,19 +260,19 @@ void Picture_readFromPraatPictureFile (Picture me, MelderFile file) {
 
 #ifdef macintosh
 static size_t appendBytes (void *info, const void *buffer, size_t count) {
-    CFDataAppendBytes ((CFMutableDataRef) info, (const UInt8 *) buffer, count);
+    CFDataAppendBytes ((CFMutableDataRef) info, (const UInt8 *) buffer, uinteger_to_integer (count));
     return count;
 }
 void Picture_copyToClipboard (Picture me) {
 	/*
-	 * Find the clipboard and clear it.
-	 */
+		Find the clipboard and clear it.
+	*/
 	PasteboardRef clipboard = nullptr;
 	PasteboardCreate (kPasteboardClipboard, & clipboard);
 	PasteboardClear (clipboard);
 	/*
-	 * Add a PDF flavour to the clipboard.
-	 */
+		Add a PDF flavour to the clipboard.
+	*/
 	static CGDataConsumerCallbacks callbacks = { appendBytes, nullptr };
 	CFDataRef data = CFDataCreateMutable (kCFAllocatorDefault, 0);
 	CGDataConsumerRef consumer = CGDataConsumerCreate ((void *) data, & callbacks);
@@ -312,14 +281,14 @@ void Picture_copyToClipboard (Picture me) {
 	CGContextRef context = CGPDFContextCreate (consumer, & rect, nullptr);
 	//my selx1 * RES, (12 - my sely2) * RES, my selx2 * RES, (12 - my sely1) * RES)
 	{// scope
-		autoGraphics graphics = Graphics_create_pdf (context, resolution, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play (my graphics.get(), graphics.get());
+		autoGraphics pdfGraphics = Graphics_create_pdf (context, resolution, my selx1, my selx2, my sely1, my sely2);
+		Graphics_play (my graphics.get(), pdfGraphics.get());
 	}
 	PasteboardPutItemFlavor (clipboard, (PasteboardItemID) 1, kUTTypePDF, data, kPasteboardFlavorNoFlags);
 	CFRelease (data);
 	/*
-	 * Forget the clipboard.
-	 */
+		Forget the clipboard.
+	*/
 	CFRelease (clipboard);
 }
 #endif
@@ -330,18 +299,17 @@ void Picture_copyToClipboard (Picture me) {
 #define WIN_WIDTH  7.5
 #define WIN_HEIGHT  11
 static HENHMETAFILE copyToMetafile (Picture me) {
-	RECT rect;
-	HDC dc;
 	PRINTDLG defaultPrinter;
-	int resolution;
 	memset (& defaultPrinter, 0, sizeof (PRINTDLG));
 	defaultPrinter. lStructSize = sizeof (PRINTDLG);
 	defaultPrinter. Flags = PD_RETURNDEFAULT | PD_RETURNDC;
 	PrintDlg (& defaultPrinter);
+	RECT rect;
 	SetRect (& rect, my selx1 * 2540, (12 - my sely2) * 2540, my selx2 * 2540, (12 - my sely1) * 2540);
-	dc = CreateEnhMetaFile (defaultPrinter. hDC, nullptr, & rect, L"Praat\0");
-	if (! dc) Melder_throw (U"Cannot create Windows metafile.");
-	resolution = GetDeviceCaps (dc, LOGPIXELSX);   // Virtual PC: 360; Parallels Desktop: 600
+	const HDC dc = CreateEnhMetaFile (defaultPrinter. hDC, nullptr, & rect, L"Praat\0");
+	if (! dc)
+		Melder_throw (U"Cannot create Windows metafile.");
+	const int resolution = GetDeviceCaps (dc, LOGPIXELSX);   // Virtual PC: 360; Parallels Desktop: 600
 	//Melder_fatal (U"resolution ", resolution);
 	if (Melder_debug == 6) {
 		DEVMODE *devMode = * (DEVMODE **) defaultPrinter. hDevMode;
@@ -388,9 +356,9 @@ void Picture_copyToClipboard (Picture me) {
 		SetClipboardData (CF_ENHMETAFILE, metafile);
 		CloseClipboard ();
 		/*
-		 * We should NOT call DeleteEnhMetaFile,
-		 * because the clipboard becomes the owner of this global memory object.
-		 */
+			We should NOT call DeleteEnhMetaFile,
+			because the clipboard becomes the owner of this global memory object.
+		*/
 	} catch (MelderError) {
 		Melder_throw (U"Picture not copied to clipboard.");
 	}
@@ -410,12 +378,12 @@ void Picture_writeToWindowsMetafile (Picture me, MelderFile file) {
 void Picture_writeToEpsFile (Picture me, MelderFile file, bool includeFonts, bool useSilipaPS) {
 	try {
 		MelderFile_delete (file);   // to kill resources as well (fopen only kills data fork)
-		/* BUG: no message if file cannot be deleted (e.g. because still open by Microsoft Word 2001 after reading). */
+		// BUG: no message if file cannot be deleted (e.g. because still open by Microsoft Word 2001 after reading)
 
 		{// scope
-			autoGraphics ps = Graphics_create_epsfile (file, 600, thePrinter. spots,
-				my selx1, my selx2, my sely1, my sely2, includeFonts, useSilipaPS);
-			Graphics_play (my graphics.get(), ps.get());
+			autoGraphics postscriptGraphics = Graphics_create_epsfile (file, 600, thePrinter. spots,
+					my selx1, my selx2, my sely1, my sely2, includeFonts, useSilipaPS);
+			Graphics_play (my graphics.get(), postscriptGraphics.get());
 		}
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to EPS file ", file);
@@ -424,8 +392,8 @@ void Picture_writeToEpsFile (Picture me, MelderFile file, bool includeFonts, boo
 
 void Picture_writeToPdfFile (Picture me, MelderFile file) {
 	try {
-		autoGraphics graphics = Graphics_create_pdffile (file, 300, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play (my graphics.get(), graphics.get());
+		autoGraphics pdfGraphics = Graphics_create_pdffile (file, 300, my selx1, my selx2, my sely1, my sely2);
+		Graphics_play (my graphics.get(), pdfGraphics.get());
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to PDF file ", file, U".");
 	}
@@ -433,8 +401,8 @@ void Picture_writeToPdfFile (Picture me, MelderFile file) {
 
 void Picture_writeToPngFile_300 (Picture me, MelderFile file) {
 	try {
-		autoGraphics graphics = Graphics_create_pngfile (file, 300, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play (my graphics.get(), graphics.get());
+		autoGraphics pngGraphics = Graphics_create_pngfile (file, 300, my selx1, my selx2, my sely1, my sely2);
+		Graphics_play (my graphics.get(), pngGraphics.get());
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to PNG file ", file, U".");
 	}
@@ -442,8 +410,8 @@ void Picture_writeToPngFile_300 (Picture me, MelderFile file) {
 
 void Picture_writeToPngFile_600 (Picture me, MelderFile file) {
 	try {
-		autoGraphics graphics = Graphics_create_pngfile (file, 600, my selx1, my selx2, my sely1, my sely2);
-		Graphics_play (my graphics.get(), graphics.get());
+		autoGraphics pngGraphics = Graphics_create_pngfile (file, 600, my selx1, my selx2, my sely1, my sely2);
+		Graphics_play (my graphics.get(), pngGraphics.get());
 	} catch (MelderError) {
 		Melder_throw (U"Picture not written to PNG file ", file, U".");
 	}
@@ -463,28 +431,14 @@ void Picture_print (Picture me) {
 }
 
 void Picture_setSelection
-	(Picture me, double x1NDC, double x2NDC, double y1NDC, double y2NDC, bool notify)
+	(Picture me, double x1NDC, double x2NDC, double y1NDC, double y2NDC)
 {
-	if (my drawingArea) {
+	if (my drawingArea)
 		Melder_assert (my drawingArea -> d_widget);
-		drawSelection (me, 0);   // unselect
-	}
 	my selx1 = x1NDC;
 	my selx2 = x2NDC;
 	my sely1 = y1NDC;
 	my sely2 = y2NDC;
-	if (my drawingArea) {
-		drawSelection (me, 1);   // select
-	}
-
-	if (notify && my selectionChangedCallback) {
-		//Melder_casual (U"selectionChangedCallback from Picture_setSelection");
-		my selectionChangedCallback (me, my selectionChangedClosure,
-			my selx1, my selx2, my sely1, my sely2);
-	}
 }
 
-void Picture_background (Picture me) { my backgrounding = true; }
-void Picture_foreground (Picture me) { my backgrounding = false; }
-
 /* End of file Picture.cpp */
