@@ -23,7 +23,7 @@
 #include "Interpreter.h"
 
 Thing_define (ScriptEditor, TextEditor) {
-	char32 *environmentName;
+	autostring32 environmentName;
 	ClassInfo editorClass;
 	autoInterpreter interpreter;
 	autoUiForm argsDialog;
@@ -44,11 +44,11 @@ Thing_define (ScriptEditor, TextEditor) {
 
 void ScriptEditor_init (ScriptEditor me,
 	Editor editor,
-	const char32 *initialText
+	conststring32 initialText
 );
 autoScriptEditor ScriptEditor_createFromText (
 	Editor editor,   // the scripting environment; if null, the scripting environment consists of the global windows
-	const char32 *initialText   // may be null
+	conststring32 initialText   // may be null
 );
 
 autoScriptEditor ScriptEditor_createFromScript_canBeNull (
