@@ -1,6 +1,6 @@
 /* oo_EQUAL.h
  *
- * Copyright (C) 1994-2007,2009,2011-2019 Paul Boersma
+ * Copyright (C) 1994-2007,2009,2011-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,13 +26,6 @@
 		if (our x [_i] != thy x [_i]) return false; \
 	}
 
-#define oo_VECTOR(type, storage, x, min, max)  \
-	{ \
-		integer _min = (min), _max = (max); \
-		if (! our x != ! thy x || \
-			(our x && ! NUMvector_equal <type> (our x, thy x, _min, _max))) return false; \
-	}
-
 #define oo_ANYVEC(type, storage, x, sizeExpression)  \
 	{ \
 		integer _size = (sizeExpression); \
@@ -66,13 +59,6 @@
 //#define oo_ENUMx_SET(kType, storage, x, setType)  \
 //	for (int _i = 0; _i <= (int) setType::MAX; _i ++) if (our x [_i] != thy x [_i]) return false;
 
-//#define oo_ENUMx_VECTOR(kType, storage, x, min, max)  \
-//	{ \
-//		integer _min = (min), _max = (max); \
-//		if (! our x != ! thy x || \
-//			(our x && ! NUMvector_equal <type> (our x, thy x, _min, _max))) return false; \
-//	}
-
 #define oo_STRINGx(storage, x)  \
 	if (! Melder_equ (our x.get(), thy x.get())) return false;
 
