@@ -1,6 +1,6 @@
 /* oo_READ_TEXT.h
  *
- * Copyright (C) 1994-2009,2011-2019 Paul Boersma
+ * Copyright (C) 1994-2009,2011-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,14 +34,6 @@
 		} \
 	}
 
-#define oo_VECTOR(type, storage, x, min, max)  \
-	{ \
-		integer _min = (min), _max = (max); \
-		if (_max >= _min) { \
-			our x = NUMvector_readText_##storage (_min, _max, _textSource_, #x); \
-		} \
-	}
-
 #define oo_ANYVEC(type, storage, x, sizeExpression)  \
 	{ \
 		integer _size = (sizeExpression); \
@@ -63,22 +55,6 @@
 #define oo_ENUMx(kType, storage, x)  \
 	our x = (kType) texget##storage (_textSource_, (enum_generic_getValue) kType##_getValue);
 
-//#define oo_ENUMx_SET(kType, storage, x, setType)  \
-//	for (int _i = 0; _i <= (int) setType::MAX; _i ++) { \
-//		our x [_i] = (kType) texget##storage (_textSource_, (enum_generic_getValue) kType##_getValue); \
-//	}
-
-//#define oo_ENUMx_VECTOR(kType, storage, x, min, max)  \
-//	{ \
-//		integer _min = (min), _max = (max); \
-//		if (_max >= _min) { \
-//			our x = NUMvector <kType> (_min, _max); \
-//			for (integer _i = _min; _i <= _max; _i ++) { \
-//				our x [_i] = (kType) texget##storage (_textSource_, (enum_generic_getValue) kType##_getValue); \
-//			} \
-//		} \
-//	}
-
 #define oo_STRINGx(storage, x)  \
 	try { \
 		our x = texget##storage (_textSource_); \
