@@ -1,6 +1,6 @@
 /* oo_undef.h
  *
- * Copyright (C) 1994-2005,2007,2011,2013,2015-2019 Paul Boersma
+ * Copyright (C) 1994-2005,2007,2011,2013,2015-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,14 +18,12 @@
 
 #undef oo_SIMPLE
 #undef oo_SET
-#undef oo_VECTOR
 #undef oo_ANYVEC
 #undef oo_ANYMAT
 #undef oo_ANYTEN3
 
 #undef oo_ENUMx
 //#undef oo_ENUMx_SET
-//#undef oo_ENUMx_VECTOR
 
 #undef oo_STRINGx
 #undef oo_STRINGx_SET
