@@ -1,6 +1,6 @@
 /* praat_picture.cpp
  *
- * Copyright (C) 1992-2019 Paul Boersma
+ * Copyright (C) 1992-2020 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,11 +45,9 @@ static GuiMenuItem praatButton_fonts [1 + (int) kGraphics_font::MAX];
 
 static void updateFontMenu () {
 	if (! theCurrentPraatApplication -> batch) {
-		if (theCurrentPraatPicture -> font < (int) kGraphics_font::MIN) theCurrentPraatPicture -> font = (int) kGraphics_font::MIN;
-		if (theCurrentPraatPicture -> font > (int) kGraphics_font::MAX) theCurrentPraatPicture -> font = (int) kGraphics_font::MAX;
-		for (int i = (int) kGraphics_font::MIN; i <= (int) kGraphics_font::MAX; i ++) {
+		Melder_clip ((int) kGraphics_font::MIN, & theCurrentPraatPicture -> font, (int) kGraphics_font::MAX);
+		for (int i = (int) kGraphics_font::MIN; i <= (int) kGraphics_font::MAX; i ++)
 			GuiMenuItem_check (praatButton_fonts [i], theCurrentPraatPicture -> font == i);
-		}
 	}
 }
 static void setFont (kGraphics_font font) {
@@ -58,9 +56,8 @@ static void setFont (kGraphics_font font) {
 		Graphics_setFont (GRAPHICS, font);
 	}
 	theCurrentPraatPicture -> font = (int) font;
-	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
+	if (theCurrentPraatPicture == & theForegroundPraatPicture)
 		updateFontMenu ();
-	}
 }
 DIRECT (GRAPHICS_Times)     { setFont (kGraphics_font::TIMES);     END }
 DIRECT (GRAPHICS_Helvetica) { setFont (kGraphics_font::HELVETICA); END }
@@ -86,9 +83,8 @@ static void setFontSize (double fontSize) {
 		Graphics_setFontSize (GRAPHICS, fontSize);
 	}
 	theCurrentPraatPicture -> fontSize = fontSize;
-	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
+	if (theCurrentPraatPicture == & theForegroundPraatPicture)
 		updateSizeMenu ();
-	}
 }
 
 DIRECT (GRAPHICS_10) { setFontSize (10.0); END }
@@ -123,7 +119,7 @@ END }
 		autoPraatPicture picture;
 		Graphics_setFontSize (GRAPHICS, praat_size = fontSize);
 	}
-	Picture_setSelection (praat_picture, x1NDC, x2NDC, y1NDC, y2NDC, False);
+	Picture_setSelection (praat_picture, x1NDC, x2NDC, y1NDC, y2NDC);
 	updateSizeMenu ();
 }*/
 
@@ -168,14 +164,12 @@ FORM (GRAPHICS_SelectInnerViewport, U"Praat picture: Select inner viewport", U"S
 	REAL (bottom, U"right Vertical range (inches)", U"6.0")
 OK
 	double xmargin = theCurrentPraatPicture -> fontSize * 4.2 / 72.0, ymargin = theCurrentPraatPicture -> fontSize * 2.8 / 72.0;
-	if (ymargin > 0.4 * (theCurrentPraatPicture -> y2NDC - theCurrentPraatPicture -> y1NDC))
-		ymargin = 0.4 * (theCurrentPraatPicture -> y2NDC - theCurrentPraatPicture -> y1NDC);
-	if (xmargin > 0.4 * (theCurrentPraatPicture -> x2NDC - theCurrentPraatPicture -> x1NDC))
-		xmargin = 0.4 * (theCurrentPraatPicture -> x2NDC - theCurrentPraatPicture -> x1NDC);
+	Melder_clipRight (& ymargin, 0.4 * (theCurrentPraatPicture -> y2NDC - theCurrentPraatPicture -> y1NDC));
+	Melder_clipRight (& xmargin, 0.4 * (theCurrentPraatPicture -> x2NDC - theCurrentPraatPicture -> x1NDC));
 	SET_REAL (left, theCurrentPraatPicture -> x1NDC + xmargin)
 	SET_REAL (right, theCurrentPraatPicture -> x2NDC - xmargin)
-	SET_REAL (top, 12 - theCurrentPraatPicture -> y2NDC + ymargin)
-	SET_REAL (bottom, 12 - theCurrentPraatPicture -> y1NDC - ymargin)
+	SET_REAL (top, 12.0 - theCurrentPraatPicture -> y2NDC + ymargin)
+	SET_REAL (bottom, 12.0 - theCurrentPraatPicture -> y1NDC - ymargin)
 DO
 	//if (theCurrentPraatObjects != & theForegroundPraatObjects) Melder_throw (U"Viewport commands are not available inside manuals.");
 	double xmargin = theCurrentPraatPicture -> fontSize * 4.2 / 72.0, ymargin = theCurrentPraatPicture -> fontSize * 2.8 / 72.0;
@@ -185,43 +179,42 @@ DO
 		Graphics_inqWsViewport (GRAPHICS, & x1DC, & x2DC, & y1DC, & y2DC);
 		double x1wNDC, x2wNDC, y1wNDC, y2wNDC;
 		Graphics_inqWsWindow (GRAPHICS, & x1wNDC, & x2wNDC, & y1wNDC, & y2wNDC);
-		double wDC = (x2DC - x1DC) / (x2wNDC - x1wNDC);
-		double hDC = integer_abs (y2DC - y1DC) / (y2wNDC - y1wNDC);
+		const double wDC = (x2DC - x1DC) / (x2wNDC - x1wNDC);
+		const double hDC = integer_abs (y2DC - y1DC) / (y2wNDC - y1wNDC);
 		xmargin *= Graphics_getResolution (GRAPHICS) / wDC;
 		ymargin *= Graphics_getResolution (GRAPHICS) / hDC;
 	}
-	if (xmargin > 2 * (right - left)) xmargin = 2 * (right - left);
-	if (ymargin > 2 * (bottom - top)) ymargin = 2 * (bottom - top);
+	Melder_clipRight (& xmargin, 2.0 * (right - left));
+	Melder_clipRight (& ymargin, 2.0 * (bottom - top));
 	trace (U"2: xmargin ", xmargin, U" ymargin ", ymargin);
-	if (left == right) {
+	if (left == right)
 		Melder_throw (U"The left and right edges of the viewport cannot be equal.\nPlease change the horizontal range.");
-	}
-	if (left > right) { double temp; temp = left; left = right; right = temp; }
-	if (top == bottom) {
+	Melder_sort (& left, & right);
+	if (top == bottom)
 		Melder_throw (U"The top and bottom edges of the viewport cannot be equal.\nPlease change the vertical range.");
-	}
 	theCurrentPraatPicture -> x1NDC = left - xmargin;
 	theCurrentPraatPicture -> x2NDC = right + xmargin;
 	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
-		if (top > bottom) { double temp; temp = top; top = bottom; bottom = temp; }
-		theCurrentPraatPicture -> y1NDC = 12-bottom - ymargin;
-		theCurrentPraatPicture -> y2NDC = 12-top + ymargin;
-		Picture_setSelection (praat_picture.get(), theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC, false);
+		Melder_sort (& top, & bottom);
+		theCurrentPraatPicture -> y1NDC = (12.0 - bottom) - ymargin;
+		theCurrentPraatPicture -> y2NDC = (12.0 - top) + ymargin;
+		Picture_setSelection (praat_picture.get(), theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 		Graphics_updateWs (GRAPHICS);
 	} else if (theCurrentPraatObjects != & theForegroundPraatObjects) {   // in manual?
-		if (top > bottom) { double temp; temp = top; top = bottom; bottom = temp; }
+		Melder_sort (& top, & bottom);
 		double x1wNDC, x2wNDC, y1wNDC, y2wNDC;
 		Graphics_inqWsWindow (GRAPHICS, & x1wNDC, & x2wNDC, & y1wNDC, & y2wNDC);
-		double height_NDC = y2wNDC - y1wNDC;
-		theCurrentPraatPicture -> y1NDC = height_NDC-bottom - ymargin;
-		theCurrentPraatPicture -> y2NDC = height_NDC-top + ymargin;
+		const double height_NDC = y2wNDC - y1wNDC;
+		theCurrentPraatPicture -> y1NDC = height_NDC - bottom - ymargin;
+		theCurrentPraatPicture -> y2NDC = height_NDC - top + ymargin;
 	} else {
-		if (top < bottom) { double temp; temp = top; top = bottom; bottom = temp; }
+		Melder_sort (& bottom, & top);
 		theCurrentPraatPicture -> y1NDC = bottom - ymargin;
 		theCurrentPraatPicture -> y2NDC = top + ymargin;
 		Graphics_setViewport (GRAPHICS,
 			theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC,
-			theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);   // to ensure that Demo_x() updates
+			theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC
+		);   // to ensure that Demo_x() updates
 	}
 	trace (U"3:"
 		U" x1NDC ", theCurrentPraatPicture -> x1NDC,
@@ -243,54 +236,50 @@ FORM (GRAPHICS_SelectOuterViewport, U"Praat picture: Select outer viewport", U"S
 OK
 	SET_REAL (left, theCurrentPraatPicture -> x1NDC)
 	SET_REAL (right, theCurrentPraatPicture -> x2NDC)
-	SET_REAL (top, 12 - theCurrentPraatPicture -> y2NDC)
-	SET_REAL (bottom, 12 - theCurrentPraatPicture -> y1NDC)
+	SET_REAL (top, 12.0 - theCurrentPraatPicture -> y2NDC)
+	SET_REAL (bottom, 12.0 - theCurrentPraatPicture -> y1NDC)
 DO
 	//if (theCurrentPraatObjects != & theForegroundPraatObjects) Melder_throw (U"Viewport commands are not available inside manuals.");
-	if (left == right) {
+	if (left == right)
 		Melder_throw (U"The left and right edges of the viewport cannot be equal.\nPlease change the horizontal range.");
-	}
-	if (left > right) { double temp; temp = left; left = right; right = temp; }
-	if (top == bottom) {
+	Melder_sort (& left, & right);
+	if (top == bottom)
 		Melder_throw (U"The top and bottom edges of the viewport cannot be equal.\nPlease change the vertical range.");
-	}
 	theCurrentPraatPicture -> x1NDC = left;
 	theCurrentPraatPicture -> x2NDC = right;
 	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
-		if (top > bottom)
-			std::swap (top, bottom);
-		theCurrentPraatPicture -> y1NDC = 12-bottom;
-		theCurrentPraatPicture -> y2NDC = 12-top;
-		Picture_setSelection (praat_picture.get(), theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC, false);
-		Graphics_updateWs (GRAPHICS);   // BUG: needed on Cocoa, but why?
+		Melder_sort (& top, & bottom);
+		theCurrentPraatPicture -> y1NDC = 12.0 - bottom;
+		theCurrentPraatPicture -> y2NDC = 12.0 - top;
+		Picture_setSelection (praat_picture.get(), theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
+		Graphics_updateWs (GRAPHICS);
 	} else if (theCurrentPraatObjects != & theForegroundPraatObjects) {   // in manual?
-		if (top > bottom)
-			std::swap (top, bottom);
+		Melder_sort (& top, & bottom);
 		double x1wNDC, x2wNDC, y1wNDC, y2wNDC;
 		Graphics_inqWsWindow (GRAPHICS, & x1wNDC, & x2wNDC, & y1wNDC, & y2wNDC);
-		double height_NDC = y2wNDC - y1wNDC;
-		theCurrentPraatPicture -> y1NDC = height_NDC-bottom;
-		theCurrentPraatPicture -> y2NDC = height_NDC-top;
+		const double height_NDC = y2wNDC - y1wNDC;
+		theCurrentPraatPicture -> y1NDC = height_NDC - bottom;
+		theCurrentPraatPicture -> y2NDC = height_NDC - top;
 	} else {
-		if (top < bottom)
-			std::swap (top, bottom);
+		Melder_sort (& bottom, & top);
 		theCurrentPraatPicture -> y1NDC = bottom;
 		theCurrentPraatPicture -> y2NDC = top;
 		Graphics_setViewport (GRAPHICS,
 			theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC,
-			theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);   // to ensure that Demo_x() updates
+			theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC
+		);   // to ensure that Demo_x() updates
 	}
 END }
 
 FORM (GRAPHICS_ViewportText, U"Praat picture: Viewport text", U"Viewport text...") {
 	RADIOx (horizontalAlignment, U"Horizontal alignment", 2, 0)
-		RADIOBUTTON (U"Left")
-		RADIOBUTTON (U"Centre")
-		RADIOBUTTON (U"Right")
+		RADIOBUTTON (U"left")
+		RADIOBUTTON (U"centre")
+		RADIOBUTTON (U"right")
 	RADIOx (verticalAlignment, U"Vertical alignment", 2, 0)
-		RADIOBUTTON (U"Bottom")
-		RADIOBUTTON (U"Half")
-		RADIOBUTTON (U"Top")
+		RADIOBUTTON (U"bottom")
+		RADIOBUTTON (U"half")
+		RADIOBUTTON (U"top")
 	REAL (rotation, U"Rotation (degrees)", U"0")
 	TEXTFIELD (text, U"Text:", U"")
 OK
@@ -396,9 +385,8 @@ static void setColour (MelderColour colour) {
 		Graphics_setColour (GRAPHICS, colour);
 	}
 	theCurrentPraatPicture -> colour = colour;
-	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
+	if (theCurrentPraatPicture == & theForegroundPraatPicture)
 		updatePenMenu ();
-	}
 }
 DIRECT (GRAPHICS_Black)   { setColour (Melder_BLACK);   END }
 DIRECT (GRAPHICS_White)   { setColour (Melder_WHITE);   END }
@@ -427,9 +415,8 @@ DO
 		Graphics_setColour (GRAPHICS, colour);
 	}
 	theCurrentPraatPicture -> colour = colour;
-	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
+	if (theCurrentPraatPicture == & theForegroundPraatPicture)
 		updatePenMenu ();
-	}
 END }
 
 /***** "File" MENU *****/
@@ -578,9 +565,6 @@ END }
 
 DIRECT (GRAPHICS_Undo) {
 	Graphics_undoGroup (GRAPHICS);
-	if (theCurrentPraatPicture != & theForegroundPraatPicture) {
-		Graphics_play (GRAPHICS, GRAPHICS);
-	}
 	Graphics_updateWs (GRAPHICS);
 END }
 
@@ -590,18 +574,6 @@ DIRECT (GRAPHICS_Erase_all) {
 	} else {
 		Graphics_clearRecording (GRAPHICS);
 		Graphics_clearWs (GRAPHICS);
-		#if 1
-		autoPraatPicture picture;
-		MelderColour colour = GRAPHICS -> colour;
-		Graphics_setColour (GRAPHICS, Melder_WHITE);
-		double x1, y1, x2, y2;
-		//Melder_casual (GRAPHICS -> d_x1DC, U" ", GRAPHICS -> d_y1DC, U" ", GRAPHICS -> d_x2DC, U" ", GRAPHICS -> d_y2DC);
-		Graphics_DCtoWC (GRAPHICS, GRAPHICS -> d_x1DC, GRAPHICS -> d_y1DC, & x1, & y1);
-		Graphics_DCtoWC (GRAPHICS, GRAPHICS -> d_x2DC, GRAPHICS -> d_y2DC, & x2, & y2);
-		//Melder_casual (x1, U" ", y1, U" ", x2, U" ", y2);
-		Graphics_fillRectangle (GRAPHICS, x1, x2, y1, y2);
-		Graphics_setColour (GRAPHICS, colour);
-		#endif
 	}
 END }
 
@@ -613,9 +585,9 @@ FORM (GRAPHICS_Text, U"Praat picture: Text", U"Text...") {
 			U"Horizontal alignment", kGraphics_horizontalAlignment::LEFT)
 	REAL (verticalPosition, U"Vertical position", U"0.0")
 	OPTIONMENUx (verticalAlignment, U"Vertical alignment", 2, 0)
-		OPTION (U"Bottom")
-		OPTION (U"Half")
-		OPTION (U"Top")
+		OPTION (U"bottom")
+		OPTION (U"half")
+		OPTION (U"top")
 	TEXTFIELD (text, U"Text:", U"")
 	OK
 DO
@@ -629,15 +601,13 @@ DO
 
 FORM (GRAPHICS_TextSpecial, U"Praat picture: Text special", nullptr) {
 	REAL (horizontalPosition, U"Horizontal position", U"0.0")
-	OPTIONMENUx (horizontalAlignment, U"Horizontal alignment", 2, 0)
-		OPTION (U"Left")
-		OPTION (U"Centre")
-		OPTION (U"Right")
+	OPTIONMENU_ENUM (kGraphics_horizontalAlignment, horizontalAlignment,
+			U"Horizontal alignment", kGraphics_horizontalAlignment::LEFT)
 	REAL (verticalPosition, U"Vertical position", U"0.0")
 	OPTIONMENUx (verticalAlignment, U"Vertical alignment", 2, 0)
-		OPTION (U"Bottom")
-		OPTION (U"Half")
-		OPTION (U"Top")
+		OPTION (U"bottom")
+		OPTION (U"half")
+		OPTION (U"top")
 	OPTIONMENU_ENUM (kGraphics_font, font, U"Font", kGraphics_font::DEFAULT)
 	POSITIVE (fontSize, U"Font size", U"10")
 	SENTENCE (rotation, U"Rotation (degrees or dx;dy)", U"0")
@@ -647,7 +617,7 @@ DO
 	kGraphics_font currentFont = Graphics_inqFont (GRAPHICS);
 	const double currentSize = Graphics_inqFontSize (GRAPHICS);
 	GRAPHICS_NONE
-		Graphics_setTextAlignment (GRAPHICS, (kGraphics_horizontalAlignment) horizontalAlignment, verticalAlignment);
+		Graphics_setTextAlignment (GRAPHICS, horizontalAlignment, verticalAlignment);
 		Graphics_setInner (GRAPHICS);
 		Graphics_setFont (GRAPHICS, (kGraphics_font) font);
 		Graphics_setFontSize (GRAPHICS, fontSize);
@@ -739,7 +709,7 @@ DO
 		fromX = x1WC;
 		toX = x2WC;
 	}
-	autoVEC y = newVECraw (numberOfHorizontalSteps);
+	autoVEC y = raw_VEC (numberOfHorizontalSteps);
 	autoPraatPictureFunction function = Thing_new (PraatPictureFunction);
 	function -> xmin = x1WC;
 	function -> xmax = x2WC;
@@ -1061,7 +1031,8 @@ FORM (GRAPHICS_MarksLeft, U"Praat picture: Marks left", U"Marks left/right/top/b
 	OK
 DO
 	GRAPHICS_NONE
-		if (numberOfMarks < 2) Melder_throw (U"The number of marks should be at least 2.");
+		if (numberOfMarks < 2)
+			Melder_throw (U"The number of marks should be at least 2.");
 		Graphics_marksLeft (GRAPHICS, numberOfMarks, writeNumbers, drawTicks, drawDottedLines);
 	GRAPHICS_NONE_END
 }
@@ -1071,7 +1042,8 @@ FORM (GRAPHICS_MarksRight, U"Praat picture: Marks right", U"Marks left/right/top
 	OK
 DO
 	GRAPHICS_NONE
-		if (numberOfMarks < 2) Melder_throw (U"The number of marks should be at least 2.");
+		if (numberOfMarks < 2)
+			Melder_throw (U"The number of marks should be at least 2.");
 		Graphics_marksRight (GRAPHICS, numberOfMarks, writeNumbers, drawTicks, drawDottedLines);
 	GRAPHICS_NONE_END
 }
@@ -1081,7 +1053,8 @@ FORM (GRAPHICS_MarksBottom, U"Praat picture: Marks bottom", U"Marks left/right/t
 	OK
 DO
 	GRAPHICS_NONE
-		if (numberOfMarks < 2) Melder_throw (U"The number of marks should be at least 2.");
+		if (numberOfMarks < 2)
+			Melder_throw (U"The number of marks should be at least 2.");
 		Graphics_marksBottom (GRAPHICS, numberOfMarks, writeNumbers, drawTicks, drawDottedLines);
 	GRAPHICS_NONE_END
 }
@@ -1091,7 +1064,8 @@ FORM (GRAPHICS_MarksTop, U"Praat picture: Marks top", U"Marks left/right/top/bot
 	OK
 DO
 	GRAPHICS_NONE
-		if (numberOfMarks < 2) Melder_throw (U"The number of marks should be at least 2.");
+		if (numberOfMarks < 2)
+			Melder_throw (U"The number of marks should be at least 2.");
 		Graphics_marksTop (GRAPHICS, numberOfMarks, writeNumbers, drawTicks, drawDottedLines);
 	GRAPHICS_NONE_END
 }
@@ -1139,9 +1113,8 @@ DO
 }
 
 static void sortBoundingBox (double *x1WC, double *x2WC, double *y1WC, double *y2WC) {
-	double temp;
-	if (*x1WC > *x2WC) temp = *x1WC, *x1WC = *x2WC, *x2WC = temp;
-	if (*y1WC > *y2WC) temp = *y1WC, *y1WC = *y2WC, *y2WC = temp;
+	Melder_sort (x1WC, x2WC);
+	Melder_sort (y1WC, y2WC);
 }
 
 FORM (GRAPHICS_OneMarkLeft, U"Praat picture: One mark left", U"One mark left/right/top/bottom...") {
@@ -1327,7 +1300,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double wc = Graphics_dxMMtoWC (GRAPHICS, distance);
+	const double wc = Graphics_dxMMtoWC (GRAPHICS, distance);
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (wc, U"(world coordinates)");
 END }
@@ -1339,7 +1312,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double mm = Graphics_dxWCtoMM (GRAPHICS, distance);
+	const double mm = Graphics_dxWCtoMM (GRAPHICS, distance);
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (mm, U"mm");
 END }
@@ -1351,7 +1324,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double wc = Graphics_dyMMtoWC (GRAPHICS, distance);
+	const double wc = Graphics_dyMMtoWC (GRAPHICS, distance);
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (wc, U"(world coordinates)");
 END }
@@ -1363,7 +1336,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double mm = Graphics_dyWCtoMM (GRAPHICS, distance);
+	const double mm = Graphics_dyWCtoMM (GRAPHICS, distance);
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (mm, U"mm");
 END }
@@ -1372,14 +1345,13 @@ FORM (GRAPHICS_TextWidth_worldCoordinates, U"Text width in world coordinates", n
 	TEXTFIELD (text, U"Text:", U"Hello world")
 	OK
 DO
-	Graphics_setFont (GRAPHICS, static_cast<kGraphics_font> (theCurrentPraatPicture -> font));
-	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
-	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
-	Graphics_setInner (GRAPHICS);
-	double wc = Graphics_textWidth (GRAPHICS, text);
-	Graphics_unsetInner (GRAPHICS);
-	Melder_informationReal (wc, U"(world coordinates)");
-END }
+	GRAPHICS_NONE
+		Graphics_setInner (GRAPHICS);
+		const double wc = Graphics_textWidth (GRAPHICS, text);
+		Graphics_unsetInner (GRAPHICS);
+		Melder_informationReal (wc, U"(world coordinates)");
+	GRAPHICS_NONE_END
+}
 
 FORM (GRAPHICS_TextWidth_mm, U"Text width in millimetres", nullptr) {
 	TEXTFIELD (text, U"Text:", U"Hello world")
@@ -1389,7 +1361,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double mm = Graphics_dxWCtoMM (GRAPHICS, Graphics_textWidth (GRAPHICS, text));
+	const double mm = Graphics_dxWCtoMM (GRAPHICS, Graphics_textWidth (GRAPHICS, text));
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (mm, U"mm");
 END }
@@ -1405,7 +1377,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double wc = Graphics_textWidth_ps (GRAPHICS, text, phoneticFont);
+	const double wc = Graphics_textWidth_ps (GRAPHICS, text, phoneticFont);
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (wc, U"(world coordinates)");
 END }
@@ -1421,7 +1393,7 @@ DO
 	Graphics_setFontSize (GRAPHICS, theCurrentPraatPicture -> fontSize);
 	Graphics_setViewport (GRAPHICS, theCurrentPraatPicture -> x1NDC, theCurrentPraatPicture -> x2NDC, theCurrentPraatPicture -> y1NDC, theCurrentPraatPicture -> y2NDC);
 	Graphics_setInner (GRAPHICS);
-	double mm = Graphics_textWidth_ps_mm (GRAPHICS, text, phoneticFont);
+	const double mm = Graphics_textWidth_ps_mm (GRAPHICS, text, phoneticFont);
 	Graphics_unsetInner (GRAPHICS);
 	Melder_informationReal (mm, U"mm");
 END }
@@ -1433,7 +1405,7 @@ DIRECT (HELP_AboutTextStyles) { HELP (U"Text styles") }
 DIRECT (HELP_PhoneticSymbols) { HELP (U"Phonetic symbols") }
 DIRECT (GRAPHICS_Picture_settings_report) {
 	MelderInfo_open ();
-	const conststring32 units = theCurrentPraatPicture == & theForegroundPraatPicture ? U" inches" : U"";
+	const conststring32 units = ( theCurrentPraatPicture == & theForegroundPraatPicture ? U" inches" : U"" );
 	MelderInfo_writeLine (U"Outer viewport left: ", theCurrentPraatPicture -> x1NDC, units);
 	MelderInfo_writeLine (U"Outer viewport right: ", theCurrentPraatPicture -> x2NDC, units);
 	MelderInfo_writeLine (U"Outer viewport top: ",
@@ -1445,7 +1417,8 @@ DIRECT (GRAPHICS_Picture_settings_report) {
 			theCurrentPraatPicture -> y2NDC :
 			12 - theCurrentPraatPicture -> y1NDC, units);
 	MelderInfo_writeLine (U"Font size: ", theCurrentPraatPicture -> fontSize, U" points");
-	double xmargin = theCurrentPraatPicture -> fontSize * 4.2 / 72.0, ymargin = theCurrentPraatPicture -> fontSize * 2.8 / 72.0;
+	double xmargin = theCurrentPraatPicture -> fontSize * 4.2 / 72.0;
+	double ymargin = theCurrentPraatPicture -> fontSize * 2.8 / 72.0;
 	if (theCurrentPraatPicture != & theForegroundPraatPicture) {
 		integer x1DC, x2DC, y1DC, y2DC;
 		Graphics_inqWsViewport (GRAPHICS, & x1DC, & x2DC, & y1DC, & y2DC);
@@ -1564,7 +1537,6 @@ void praat_picture_open () {
 		#elif cocoa
 			GuiThing_show (dialog);
 		#endif
-		Picture_unhighlight (praat_picture.get());
 	}
 	/* Foregoing drawing routines may have changed some of the output attributes */
 	/* that can be set by the user. */
@@ -1588,17 +1560,15 @@ void praat_picture_open () {
 }
 
 void praat_picture_close () {
-	if (theCurrentPraatPicture != & theForegroundPraatPicture) return;
-	if (! theCurrentPraatApplication -> batch) {
-		Picture_highlight (praat_picture.get());
-		#ifdef macintosh
-			//dialog -> f_drain ();
-		#endif
-	}
+	if (theCurrentPraatPicture != & theForegroundPraatPicture)
+		return;
+	if (! theCurrentPraatApplication -> batch)
+		Graphics_updateWs (GRAPHICS);
 }
 
 Graphics praat_picture_editor_open (bool eraseFirst) {
-	if (eraseFirst) Picture_erase (praat_picture.get());
+	if (eraseFirst)
+		Picture_erase (praat_picture.get());
 	praat_picture_open ();
 	return GRAPHICS;
 }
@@ -1608,7 +1578,8 @@ void praat_picture_editor_close () {
 }
 
 static autoDaata pictureRecognizer (integer nread, const char *header, MelderFile file) {
-	if (nread < 2) return autoDaata ();
+	if (nread < 2)
+		return autoDaata ();
 	if (strnequ (header, "PraatPictureFile", 16)) {
 		Picture_readFromPraatPictureFile (praat_picture.get(), file);
 		return Thing_new (Daata);   // a dummy
@@ -1851,7 +1822,8 @@ void praat_picture_init () {
 	if (! theCurrentPraatApplication -> batch) {
 		width = height = resolution * 12;
 		scrollWindow = GuiScrolledWindow_createShown (dialog, margin, 0, Machine_getMenuBarHeight () + margin, 0, 1, 1, 0);
-		drawingArea = GuiDrawingArea_createShown (scrollWindow, width, height, nullptr, nullptr, nullptr, nullptr, nullptr, 0);
+		drawingArea = GuiDrawingArea_createShown (scrollWindow, width, height,
+				nullptr, nullptr, nullptr, nullptr, nullptr, 0);
 		GuiThing_show (dialog);
 	}
 
@@ -1875,24 +1847,4 @@ void praat_picture_prefsChanged () {
 	Picture_setMouseSelectsInnerViewport (praat_picture.get(), praat_mouseSelectsInnerViewport);
 }
 
-void praat_picture_background () {
-	if (theCurrentPraatPicture != & theForegroundPraatPicture) return;   // Demo window and pictures ignore this
-	if (! theCurrentPraatApplication -> batch) {
-		//Picture_unhighlight (praat_picture.get());
-		#if cocoa
-			Picture_background (praat_picture.get());   // prevent Cocoa's very slow highlighting until woken up by Picture_foreground()
-		#endif
-	}
-}
-
-void praat_picture_foreground () {
-	if (theCurrentPraatPicture != & theForegroundPraatPicture) return;   // Demo window and pictures ignore this
-	if (! theCurrentPraatApplication -> batch) {
-		#if cocoa
-			Picture_foreground (praat_picture.get());   // wake up from the highlighting sleep caused by Picture_background()
-		#endif
-		//Picture_highlight (praat_picture.get());
-	}
-}
-
 /* End of file praat_picture.cpp */
