@@ -1,17 +1,17 @@
 /* praat_script.cpp
  *
  * Copyright (C) 1993-2020 Paul Boersma
- * 
+ *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -139,21 +139,23 @@ static int parseCommaSeparatedArguments (Interpreter interpreter, char32 *argume
 				case kFormula_EXPRESSION_TYPE_NUMERIC: {
 					args [narg]. which = Stackel_NUMBER;
 					args [narg]. number = result. numericResult;
-				} break;
-				case kFormula_EXPRESSION_TYPE_STRING: {
+				} break; case kFormula_EXPRESSION_TYPE_STRING: {
 					args [narg]. setString (result. stringResult.move());
-				} break;
-				case kFormula_EXPRESSION_TYPE_NUMERIC_VECTOR: {
+				} break; case kFormula_EXPRESSION_TYPE_NUMERIC_VECTOR: {
 					args [narg]. which = Stackel_NUMERIC_VECTOR;
 					args [narg]. numericVector = result. numericVectorResult;
 					args [narg]. owned = result. owned;
 					result. owned = false;
-				} break;
-				case kFormula_EXPRESSION_TYPE_NUMERIC_MATRIX: {
+				} break; case kFormula_EXPRESSION_TYPE_NUMERIC_MATRIX: {
 					args [narg]. which = Stackel_NUMERIC_MATRIX;
 					args [narg]. numericMatrix = result. numericMatrixResult;
 					args [narg]. owned = result. owned;
 					result. owned = false;
+				} break; case kFormula_EXPRESSION_TYPE_STRING_ARRAY: {
+					args [narg]. which = Stackel_STRING_ARRAY;
+					args [narg]. stringArray = result. stringArrayResult;
+					args [narg]. owned = result. owned;
+					result. owned = false;
 				} break;
 			}
 			arguments = p + 1;
@@ -546,7 +548,7 @@ void praat_executeCommandFromStandardInput (conststring32 programName) {
 		try {
 			praat_executeCommand (nullptr, command32.get());
 		} catch (MelderError) {
-			Melder_flushError (programName, U": command \"", Melder_peek8to32 (command8), U"\" not executed.");
+			Melder_flushError (programName, U": Command \"", Melder_peek8to32 (command8), U"\" not executed.");
 		}
 	}
 }
